country_of_nationality_dict = {
    "AF": {
        "name": "Afghanistan",
        "risk": "High",
        "score": 5
    },
    "AX": {
        "name": "Åland Islands",
        "risk": "High",
        "score": 5
    },
    "AL": {
        "name": "Albania",
        "risk": "High",
        "score": 5
    },
    "DZ": {
        "name": "Algeria",
        "risk": "High",
        "score": 5
    },
    "AS": {
        "name": "American Samoa",
        "risk": "Low",
        "score": 1
    },
    "AD": {
        "name": "Andorra",
        "risk": "High",
        "score": 5
    },
    "AO": {
        "name": "Angola",
        "risk": "High",
        "score": 5
    },
    "AI": {
        "name": "Anguilla",
        "risk": "Medium",
        "score": 3
    },
    "AQ": {
        "name": "Antarctica",
        "risk": "Low",
        "score": 1
    },
    "AG": {
        "name": "Antigua and Barbuda",
        "risk": "Medium",
        "score": 3
    },
    "AR": {
        "name": "Argentina",
        "risk": "Medium",
        "score": 3
    },
    "AM": {
        "name": "Armenia",
        "risk": "Low",
        "score": 1
    },
    "AW": {
        "name": "Aruba",
        "risk": "Medium",
        "score": 3
    },
    "AU": {
        "name": "Australia",
        "risk": "Low",
        "score": 1
    },
    "AT": {
        "name": "Austria",
        "risk": "Low",
        "score": 1
    },
    "AZ": {
        "name": "Azerbaijan",
        "risk": "High",
        "score": 5
    },
    "BH": {
        "name": "Bahrain",
        "risk": "Medium",
        "score": 3
    },
    "BD": {
        "name": "Bangladesh",
        "risk": "Medium",
        "score": 3
    },
    "BB": {
        "name": "Barbados",
        "risk": "Medium",
        "score": 3
    },
    "BY": {
        "name": "Belarus",
        "risk": "High",
        "score": 5
    },
    "BE": {
        "name": "Belgium",
        "risk": "Low",
        "score": 1
    },
    "BZ": {
        "name": "Belize",
        "risk": "High",
        "score": 5
    },
    "BJ": {
        "name": "Benin",
        "risk": "Medium",
        "score": 3
    },
    "BM": {
        "name": "Bermuda",
        "risk": "Medium",
        "score": 3
    },
    "BT": {
        "name": "Bhutan",
        "risk": "Low",
        "score": 1
    },
    "BA": {
        "name": "Bosnia and Herzegovina",
        "risk": "Medium",
        "score": 3
    },
    "BW": {
        "name": "Botswana",
        "risk": "Low",
        "score": 1
    },
    "BV": {
        "name": "Bouvet Island",
        "risk": "Low",
        "score": 1
    },
    "BR": {
        "name": "Brazil",
        "risk": "Medium",
        "score": 3
    },
    "BN": {
        "name": "Brunei Darussalam",
        "risk": "Low",
        "score": 1
    },
    "BG": {
        "name": "Bulgaria",
        "risk": "Low",
        "score": 1
    },
    "BF": {
        "name": "Burkina Faso",
        "risk": "Low",
        "score": 1
    },
    "BI": {
        "name": "Burundi",
        "risk": "Medium",
        "score": 3
    },
    "KH": {
        "name": "Cambodia",
        "risk": "Medium",
        "score": 3
    },
    "CM": {
        "name": "Cameroon",
        "risk": "Medium",
        "score": 3
    },
    "CA": {
        "name": "Canada",
        "risk": "Low",
        "score": 1
    },
    "TD": {
        "name": "Chad",
        "risk": "Medium",
        "score": 3
    },
    "CL": {
        "name": "Chile",
        "risk": "Low",
        "score": 1
    },
    "CN": {
        "name": "China",
        "risk": "Medium",
        "score": 3
    },
    "CX": {
        "name": "Christmas Island",
        "risk": "Low",
        "score": 1
    },
    "CO": {
        "name": "Colombia",
        "risk": "High",
        "score": 5
    },
    "KM": {
        "name": "Comoros",
        "risk": "Medium",
        "score": 3
    },
    "CG": {
        "name": "Congo",
        "risk": "Medium",
        "score": 3
    },
    "CR": {
        "name": "Costa Rica",
        "risk": "High",
        "score": 5
    },
    "HR": {
        "name": "Croatia",
        "risk": "Low",
        "score": 1
    },
    "CU": {
        "name": "Cuba",
        "risk": "High",
        "score": 5
    },
    "CY": {
        "name": "Cyprus",
        "risk": "High",
        "score": 5
    },
    "DK": {
        "name": "Denmark",
        "risk": "Low",
        "score": 1
    },
    "DJ": {
        "name": "Djibouti",
        "risk": "Low",
        "score": 1
    },
    "DM": {
        "name": "Dominica",
        "risk": "Medium",
        "score": 3
    },
    "EC": {
        "name": "Ecuador",
        "risk": "High",
        "score": 5
    },
    "EG": {
        "name": "Egypt",
        "risk": "High",
        "score": 5
    },
    "SV": {
        "name": "El Salvador",
        "risk": "High",
        "score": 5
    },
    "GQ": {
        "name": "Equatorial Guinea",
        "risk": "High",
        "score": 5
    },
    "ER": {
        "name": "Eritrea",
        "risk": "High",
        "score": 5
    },
    "EE": {
        "name": "Estonia",
        "risk": "Low",
        "score": 1
    },
    "ET": {
        "name": "Ethiopia",
        "risk": "High",
        "score": 5
    },
    "FJ": {
        "name": "Fiji",
        "risk": "Low",
        "score": 1
    },
    "FI": {
        "name": "Finland",
        "risk": "Low",
        "score": 1
    },
    "FR": {
        "name": "France",
        "risk": "Low",
        "score": 1
    },
    "GF": {
        "name": "French Guiana",
        "risk": "Low",
        "score": 1
    },
    "PF": {
        "name": "French Polynesia",
        "risk": "Low",
        "score": 1
    },
    "GA": {
        "name": "Gabon",
        "risk": "Low",
        "score": 1
    },
    "GE": {
        "name": "Georgia",
        "risk": "Low",
        "score": 1
    },
    "DE": {
        "name": "Germany",
        "risk": "Low",
        "score": 1
    },
    "GH": {
        "name": "Ghana",
        "risk": "Low",
        "score": 1
    },
    "GI": {
        "name": "Gibraltar",
        "risk": "Medium",
        "score": 3
    },
    "GR": {
        "name": "Greece",
        "risk": "Low",
        "score": 1
    },
    "GL": {
        "name": "Greenland",
        "risk": "Low",
        "score": 1
    },
    "GD": {
        "name": "Grenada",
        "risk": "High",
        "score": 5
    },
    "GP": {
        "name": "Guadeloupe",
        "risk": "Low",
        "score": 1
    },
    "GU": {
        "name": "Guam",
        "risk": "Low",
        "score": 1
    },
    "GT": {
        "name": "Guatemala",
        "risk": "High",
        "score": 5
    },
    "GG": {
        "name": "Guernsey",
        "risk": "Medium",
        "score": 3
    },
    "GN": {
        "name": "Guinea",
        "risk": "High",
        "score": 5
    },
    "GW": {
        "name": "Guinea-Bissau",
        "risk": "High",
        "score": 5
    },
    "GY": {
        "name": "Guyana",
        "risk": "Low",
        "score": 1
    },
    "HT": {
        "name": "Haiti",
        "risk": "High",
        "score": 5
    },
    "HM": {
        "name": "Heard Island and McDonald Islands",
        "risk": "Low",
        "score": 1
    },
    "HN": {
        "name": "Honduras",
        "risk": "High",
        "score": 5
    },
    "HK": {
        "name": "Hong Kong",
        "risk": "Medium",
        "score": 3
    },
    "HU": {
        "name": "Hungary",
        "risk": "Low",
        "score": 1
    },
    "IS": {
        "name": "Iceland",
        "risk": "Low",
        "score": 1
    },
    "IN": {
        "name": "India",
        "risk": "High",
        "score": 5
    },
    "ID": {
        "name": "Indonesia",
        "risk": "High",
        "score": 5
    },
    "IQ": {
        "name": "Iraq",
        "risk": "High",
        "score": 5
    },
    "IE": {
        "name": "Ireland",
        "risk": "Low",
        "score": 1
    },
    "IM": {
        "name": "Isle of Man",
        "risk": "Medium",
        "score": 3
    },
    "IL": {
        "name": "Israel",
        "risk": "Low",
        "score": 1
    },
    "IT": {
        "name": "Italy",
        "risk": "Low",
        "score": 1
    },
    "JM": {
        "name": "Jamaica",
        "risk": "High",
        "score": 5
    },
    "JP": {
        "name": "Japan",
        "risk": "Low",
        "score": 1
    },
    "JE": {
        "name": "Jersey",
        "risk": "Medium",
        "score": 3
    },
    "JO": {
        "name": "Jordan",
        "risk": "Low",
        "score": 1
    },
    "KZ": {
        "name": "Kazakhstan",
        "risk": "High",
        "score": 5
    },
    "KE": {
        "name": "Kenya",
        "risk": "High",
        "score": 5
    },
    "KI": {
        "name": "Kiribati",
        "risk": "Low",
        "score": 1
    },
    "KW": {
        "name": "Kuwait",
        "risk": "Medium",
        "score": 3
    },
    "KG": {
        "name": "Kyrgyzstan",
        "risk": "High",
        "score": 5
    },
    "LV": {
        "name": "Latvia",
        "risk": "High",
        "score": 5
    },
    "LB": {
        "name": "Lebanon",
        "risk": "High",
        "score": 5
    },
    "LS": {
        "name": "Lesotho",
        "risk": "Low",
        "score": 1
    },
    "LR": {
        "name": "Liberia",
        "risk": "High",
        "score": 5
    },
    "LI": {
        "name": "Liechtenstein",
        "risk": "High",
        "score": 5
    },
    "LT": {
        "name": "Lithuania",
        "risk": "Low",
        "score": 1
    },
    "LU": {
        "name": "Luxembourg",
        "risk": "Medium",
        "score": 3
    },
    "MO": {
        "name": "Macao",
        "risk": "High",
        "score": 5
    },
    "MG": {
        "name": "Madagascar",
        "risk": "Low",
        "score": 1
    },
    "MW": {
        "name": "Malawi",
        "risk": "Low",
        "score": 1
    },
    "MY": {
        "name": "Malaysia",
        "risk": "Medium",
        "score": 3
    },
    "MV": {
        "name": "Maldives",
        "risk": "Low",
        "score": 1
    },
    "ML": {
        "name": "Mali",
        "risk": "Low",
        "score": 1
    },
    "MT": {
        "name": "Malta",
        "risk": "Medium",
        "score": 3
    },
    "MQ": {
        "name": "Martinique",
        "risk": "Low",
        "score": 1
    },
    "MR": {
        "name": "Mauritania",
        "risk": "Low",
        "score": 1
    },
    "MU": {
        "name": "Mauritius",
        "risk": "Medium",
        "score": 3
    },
    "YT": {
        "name": "Mayotte",
        "risk": "Low",
        "score": 1
    },
    "MX": {
        "name": "Mexico",
        "risk": "High",
        "score": 5
    },
    "MC": {
        "name": "Monaco",
        "risk": "High",
        "score": 5
    },
    "MN": {
        "name": "Mongolia",
        "risk": "Low",
        "score": 1
    },
    "MS": {
        "name": "Montserrat",
        "risk": "Medium",
        "score": 3
    },
    "MA": {
        "name": "Morocco",
        "risk": "Low",
        "score": 1
    },
    "MZ": {
        "name": "Mozambique",
        "risk": "Low",
        "score": 1
    },
    "MM": {
        "name": "Myanmar",
        "risk": "High",
        "score": 5
    },
    "NA": {
        "name": "Namibia",
        "risk": "Low",
        "score": 1
    },
    "NR": {
        "name": "Nauru",
        "risk": "High",
        "score": 5
    },
    "NP": {
        "name": "Nepal",
        "risk": "Low",
        "score": 1
    },
    "NC": {
        "name": "New Caledonia",
        "risk": "Low",
        "score": 1
    },
    "NZ": {
        "name": "New Zealand",
        "risk": "Low",
        "score": 1
    },
    "NI": {
        "name": "Nicaragua",
        "risk": "High",
        "score": 5
    },
    "NG": {
        "name": "Nigeria",
        "risk": "High",
        "score": 5
    },
    "NU": {
        "name": "Niue",
        "risk": "High",
        "score": 5
    },
    "NF": {
        "name": "Norfolk Island",
        "risk": "Low",
        "score": 1
    },
    "NO": {
        "name": "Norway",
        "risk": "Low",
        "score": 1
    },
    "OM": {
        "name": "Oman",
        "risk": "Low",
        "score": 1
    },
    "PK": {
        "name": "Pakistan",
        "risk": "High",
        "score": 5
    },
    "PW": {
        "name": "Palau",
        "risk": "Medium",
        "score": 3
    },
    "PA": {
        "name": "Panama",
        "risk": "High",
        "score": 5
    },
    "PG": {
        "name": "Papua New Guinea",
        "risk": "High",
        "score": 5
    },
    "PY": {
        "name": "Paraguay",
        "risk": "Medium",
        "score": 3
    },
    "PE": {
        "name": "Peru",
        "risk": "High",
        "score": 5
    },
    "PN": {
        "name": "Pitcairn",
        "risk": "Low",
        "score": 1
    },
    "PL": {
        "name": "Poland",
        "risk": "Low",
        "score": 1
    },
    "PT": {
        "name": "Portugal",
        "risk": "Low",
        "score": 1
    },
    "PR": {
        "name": "Puerto Rico",
        "risk": "Low",
        "score": 1
    },
    "QA": {
        "name": "Qatar",
        "risk": "Low",
        "score": 1
    },
    "RO": {
        "name": "Romania",
        "risk": "Low",
        "score": 1
    },
    "RW": {
        "name": "Rwanda",
        "risk": "Low",
        "score": 1
    },
    "KN": {
        "name": "Saint Kitts and Nevis",
        "risk": "High",
        "score": 5
    },
    "LC": {
        "name": "Saint Lucia",
        "risk": "Medium",
        "score": 3
    },
    "PM": {
        "name": "Saint Pierre and Miquelon",
        "risk": "Low",
        "score": 1
    },
    "VC": {
        "name": "Saint Vincent and the Grenadines",
        "risk": "Medium",
        "score": 3
    },
    "WS": {
        "name": "Samoa",
        "risk": "Medium",
        "score": 3
    },
    "SM": {
        "name": "San Marino",
        "risk": "Low",
        "score": 1
    },
    "ST": {
        "name": "Sao Tome and Principe",
        "risk": "Medium",
        "score": 3
    },
    "SA": {
        "name": "Saudi Arabia",
        "risk": "High",
        "score": 5
    },
    "SN": {
        "name": "Senegal",
        "risk": "Low",
        "score": 1
    },
    "SC": {
        "name": "Seychelles",
        "risk": "Medium",
        "score": 3
    },
    "SL": {
        "name": "Sierra Leone",
        "risk": "Medium",
        "score": 3
    },
    "SG": {
        "name": "Singapore",
        "risk": "Medium",
        "score": 3
    },
    "SK": {
        "name": "Slovakia",
        "risk": "Low",
        "score": 1
    },
    "SI": {
        "name": "Slovenia",
        "risk": "Low",
        "score": 1
    },
    "SO": {
        "name": "Somalia",
        "risk": "High",
        "score": 5
    },
    "ZA": {
        "name": "South Africa",
        "risk": "Low",
        "score": 1
    },
    "GS": {
        "name": "South Georgia and the South Sandwich Islands",
        "risk": "Low",
        "score": 1
    },
    "ES": {
        "name": "Spain",
        "risk": "Low",
        "score": 1
    },
    "LK": {
        "name": "Sri Lanka",
        "risk": "Low",
        "score": 1
    },
    "SR": {
        "name": "Suriname",
        "risk": "Low",
        "score": 1
    },
    "SJ": {
        "name": "Svalbard and Jan Mayen",
        "risk": "Low",
        "score": 1
    },
    "SZ": {
        "name": "Swaziland",
        "risk": "Low",
        "score": 1
    },
    "SE": {
        "name": "Sweden",
        "risk": "Low",
        "score": 1
    },
    "CH": {
        "name": "Switzerland",
        "risk": "Medium",
        "score": 3
    },
    "TJ": {
        "name": "Tajikistan",
        "risk": "High",
        "score": 5
    },
    "TZ": {
        "name": "Tanzania, United Republic of",
        "risk": "High",
        "score": 5
    },
    "TH": {
        "name": "Thailand",
        "risk": "Low",
        "score": 1
    },
    "TL": {
        "name": "Timor-Leste",
        "risk": "Medium",
        "score": 3
    },
    "TG": {
        "name": "Togo",
        "risk": "Medium",
        "score": 3
    },
    "TK": {
        "name": "Tokelau",
        "risk": "Low",
        "score": 1
    },
    "TO": {
        "name": "Tonga",
        "risk": "Low",
        "score": 1
    },
    "TT": {
        "name": "Trinidad and Tobago",
        "risk": "Low",
        "score": 1
    },
    "TN": {
        "name": "Tunisia",
        "risk": "High",
        "score": 5
    },
    "TR": {
        "name": "Turkey",
        "risk": "High",
        "score": 5
    },
    "TM": {
        "name": "Turkmenistan",
        "risk": "Medium",
        "score": 3
    },
    "TV": {
        "name": "Tuvalu",
        "risk": "Low",
        "score": 1
    },
    "UG": {
        "name": "Uganda",
        "risk": "High",
        "score": 5
    },
    "UA": {
        "name": "Ukraine",
        "risk": "High",
        "score": 5
    },
    "UY": {
        "name": "Uruguay",
        "risk": "Medium",
        "score": 3
    },
    "UZ": {
        "name": "Uzbekistan",
        "risk": "High",
        "score": 5
    },
    "VU": {
        "name": "Vanuatu",
        "risk": "Medium",
        "score": 3
    },
    "VN": {
        "name": "Viet Nam",
        "risk": "Low",
        "score": 1
    },
    "WF": {
        "name": "Wallis and Futuna",
        "risk": "Low",
        "score": 1
    },
    "EH": {
        "name": "Western Sahara",
        "risk": "Low",
        "score": 1
    },
    "YE": {
        "name": "Yemen",
        "risk": "High",
        "score": 5
    },
    "ZM": {
        "name": "Zambia",
        "risk": "Low",
        "score": 1
    },
    "ZW": {
        "name": "Zimbabwe",
        "risk": "High",
        "score": 5
    },
    "GB": {
        "name": "United Kingdom",
        "risk": "Low",
        "score": 1
    },
    "US": {
        "name": "United States Of America",
        "risk": "Low",
        "score": 1
    },
     "AE": {
        "name": "United States Of America",
        "risk": "High",
        "score": 5
    }
}


country_of_residence_dict = {
    "AF": {
        "name": "Afghanistan",
        "risk": "High",
        "score": 5
    },
    "AX": {
        "name": "Åland Islands",
        "risk": "High",
        "score": 5
    },
    "AL": {
        "name": "Albania",
        "risk": "High",
        "score": 5
    },
    "DZ": {
        "name": "Algeria",
        "risk": "High",
        "score": 5
    },
    "AS": {
        "name": "American Samoa",
        "risk": "Low",
        "score": 1
    },
    "AD": {
        "name": "Andorra",
        "risk": "High",
        "score": 5
    },
    "AO": {
        "name": "Angola",
        "risk": "High",
        "score": 5
    },
    "AI": {
        "name": "Anguilla",
        "risk": "Medium",
        "score": 3
    },
    "AQ": {
        "name": "Antarctica",
        "risk": "Low",
        "score": 1
    },
    "AG": {
        "name": "Antigua and Barbuda",
        "risk": "Medium",
        "score": 3
    },
    "AR": {
        "name": "Argentina",
        "risk": "Medium",
        "score": 3
    },
    "AM": {
        "name": "Armenia",
        "risk": "Low",
        "score": 1
    },
    "AW": {
        "name": "Aruba",
        "risk": "Medium",
        "score": 3
    },
    "AU": {
        "name": "Australia",
        "risk": "Low",
        "score": 1
    },
    "AT": {
        "name": "Austria",
        "risk": "Low",
        "score": 1
    },
    "AZ": {
        "name": "Azerbaijan",
        "risk": "High",
        "score": 5
    },
    "BH": {
        "name": "Bahrain",
        "risk": "Medium",
        "score": 3
    },
    "BD": {
        "name": "Bangladesh",
        "risk": "Medium",
        "score": 3
    },
    "BB": {
        "name": "Barbados",
        "risk": "Medium",
        "score": 3
    },
    "BY": {
        "name": "Belarus",
        "risk": "High",
        "score": 5
    },
    "BE": {
        "name": "Belgium",
        "risk": "Low",
        "score": 1
    },
    "BZ": {
        "name": "Belize",
        "risk": "High",
        "score": 5
    },
    "BJ": {
        "name": "Benin",
        "risk": "Medium",
        "score": 3
    },
    "BM": {
        "name": "Bermuda",
        "risk": "Medium",
        "score": 3
    },
    "BT": {
        "name": "Bhutan",
        "risk": "Low",
        "score": 1
    },
    "BA": {
        "name": "Bosnia and Herzegovina",
        "risk": "Medium",
        "score": 3
    },
    "BW": {
        "name": "Botswana",
        "risk": "Low",
        "score": 1
    },
    "BV": {
        "name": "Bouvet Island",
        "risk": "Low",
        "score": 1
    },
    "BR": {
        "name": "Brazil",
        "risk": "Medium",
        "score": 3
    },
    "BN": {
        "name": "Brunei Darussalam",
        "risk": "Low",
        "score": 1
    },
    "BG": {
        "name": "Bulgaria",
        "risk": "Low",
        "score": 1
    },
    "BF": {
        "name": "Burkina Faso",
        "risk": "Low",
        "score": 1
    },
    "BI": {
        "name": "Burundi",
        "risk": "Medium",
        "score": 3
    },
    "KH": {
        "name": "Cambodia",
        "risk": "Medium",
        "score": 3
    },
    "CM": {
        "name": "Cameroon",
        "risk": "Medium",
        "score": 3
    },
    "CA": {
        "name": "Canada",
        "risk": "Low",
        "score": 1
    },
    "TD": {
        "name": "Chad",
        "risk": "Medium",
        "score": 3
    },
    "CL": {
        "name": "Chile",
        "risk": "Low",
        "score": 1
    },
    "CN": {
        "name": "China",
        "risk": "Medium",
        "score": 3
    },
    "CX": {
        "name": "Christmas Island",
        "risk": "Low",
        "score": 1
    },
    "CO": {
        "name": "Colombia",
        "risk": "High",
        "score": 5
    },
    "KM": {
        "name": "Comoros",
        "risk": "Medium",
        "score": 3
    },
    "CG": {
        "name": "Congo",
        "risk": "Medium",
        "score": 3
    },
    "CR": {
        "name": "Costa Rica",
        "risk": "High",
        "score": 5
    },
    "HR": {
        "name": "Croatia",
        "risk": "Low",
        "score": 1
    },
    "CU": {
        "name": "Cuba",
        "risk": "High",
        "score": 5
    },
    "CY": {
        "name": "Cyprus",
        "risk": "High",
        "score": 5
    },
    "DK": {
        "name": "Denmark",
        "risk": "Low",
        "score": 1
    },
    "DJ": {
        "name": "Djibouti",
        "risk": "Low",
        "score": 1
    },
    "DM": {
        "name": "Dominica",
        "risk": "Medium",
        "score": 3
    },
    "EC": {
        "name": "Ecuador",
        "risk": "High",
        "score": 5
    },
    "EG": {
        "name": "Egypt",
        "risk": "High",
        "score": 5
    },
    "SV": {
        "name": "El Salvador",
        "risk": "High",
        "score": 5
    },
    "GQ": {
        "name": "Equatorial Guinea",
        "risk": "High",
        "score": 5
    },
    "ER": {
        "name": "Eritrea",
        "risk": "High",
        "score": 5
    },
    "EE": {
        "name": "Estonia",
        "risk": "Low",
        "score": 1
    },
    "ET": {
        "name": "Ethiopia",
        "risk": "High",
        "score": 5
    },
    "FJ": {
        "name": "Fiji",
        "risk": "Low",
        "score": 1
    },
    "FI": {
        "name": "Finland",
        "risk": "Low",
        "score": 1
    },
    "FR": {
        "name": "France",
        "risk": "Low",
        "score": 1
    },
    "GF": {
        "name": "French Guiana",
        "risk": "Low",
        "score": 1
    },
    "PF": {
        "name": "French Polynesia",
        "risk": "Low",
        "score": 1
    },
    "GA": {
        "name": "Gabon",
        "risk": "Low",
        "score": 1
    },
    "GE": {
        "name": "Georgia",
        "risk": "Low",
        "score": 1
    },
    "DE": {
        "name": "Germany",
        "risk": "Low",
        "score": 1
    },
    "GH": {
        "name": "Ghana",
        "risk": "Low",
        "score": 1
    },
    "GI": {
        "name": "Gibraltar",
        "risk": "Medium",
        "score": 3
    },
    "GR": {
        "name": "Greece",
        "risk": "Low",
        "score": 1
    },
    "GL": {
        "name": "Greenland",
        "risk": "Low",
        "score": 1
    },
    "GD": {
        "name": "Grenada",
        "risk": "High",
        "score": 5
    },
    "GP": {
        "name": "Guadeloupe",
        "risk": "Low",
        "score": 1
    },
    "GU": {
        "name": "Guam",
        "risk": "Low",
        "score": 1
    },
    "GT": {
        "name": "Guatemala",
        "risk": "High",
        "score": 5
    },
    "GG": {
        "name": "Guernsey",
        "risk": "Medium",
        "score": 3
    },
    "GN": {
        "name": "Guinea",
        "risk": "High",
        "score": 5
    },
    "GW": {
        "name": "Guinea-Bissau",
        "risk": "High",
        "score": 5
    },
    "GY": {
        "name": "Guyana",
        "risk": "Low",
        "score": 1
    },
    "HT": {
        "name": "Haiti",
        "risk": "High",
        "score": 5
    },
    "HM": {
        "name": "Heard Island and McDonald Islands",
        "risk": "Low",
        "score": 1
    },
    "HN": {
        "name": "Honduras",
        "risk": "High",
        "score": 5
    },
    "HK": {
        "name": "Hong Kong",
        "risk": "Medium",
        "score": 3
    },
    "HU": {
        "name": "Hungary",
        "risk": "Low",
        "score": 1
    },
    "IS": {
        "name": "Iceland",
        "risk": "Low",
        "score": 1
    },
    "IN": {
        "name": "India",
        "risk": "High",
        "score": 5
    },
    "ID": {
        "name": "Indonesia",
        "risk": "High",
        "score": 5
    },
    "IQ": {
        "name": "Iraq",
        "risk": "High",
        "score": 5
    },
    "IE": {
        "name": "Ireland",
        "risk": "Low",
        "score": 1
    },
    "IM": {
        "name": "Isle of Man",
        "risk": "Medium",
        "score": 3
    },
    "IL": {
        "name": "Israel",
        "risk": "Low",
        "score": 1
    },
    "IT": {
        "name": "Italy",
        "risk": "Low",
        "score": 1
    },
    "JM": {
        "name": "Jamaica",
        "risk": "High",
        "score": 5
    },
    "JP": {
        "name": "Japan",
        "risk": "Low",
        "score": 1
    },
    "JE": {
        "name": "Jersey",
        "risk": "Medium",
        "score": 3
    },
    "JO": {
        "name": "Jordan",
        "risk": "Low",
        "score": 1
    },
    "KZ": {
        "name": "Kazakhstan",
        "risk": "High",
        "score": 5
    },
    "KE": {
        "name": "Kenya",
        "risk": "High",
        "score": 5
    },
    "KI": {
        "name": "Kiribati",
        "risk": "Low",
        "score": 1
    },
    "KW": {
        "name": "Kuwait",
        "risk": "Medium",
        "score": 3
    },
    "KG": {
        "name": "Kyrgyzstan",
        "risk": "High",
        "score": 5
    },
    "LV": {
        "name": "Latvia",
        "risk": "High",
        "score": 5
    },
    "LB": {
        "name": "Lebanon",
        "risk": "High",
        "score": 5
    },
    "LS": {
        "name": "Lesotho",
        "risk": "Low",
        "score": 1
    },
    "LR": {
        "name": "Liberia",
        "risk": "High",
        "score": 5
    },
    "LI": {
        "name": "Liechtenstein",
        "risk": "High",
        "score": 5
    },
    "LT": {
        "name": "Lithuania",
        "risk": "Low",
        "score": 1
    },
    "LU": {
        "name": "Luxembourg",
        "risk": "Medium",
        "score": 3
    },
    "MO": {
        "name": "Macao",
        "risk": "High",
        "score": 5
    },
    "MG": {
        "name": "Madagascar",
        "risk": "Low",
        "score": 1
    },
    "MW": {
        "name": "Malawi",
        "risk": "Low",
        "score": 1
    },
    "MY": {
        "name": "Malaysia",
        "risk": "Medium",
        "score": 3
    },
    "MV": {
        "name": "Maldives",
        "risk": "Low",
        "score": 1
    },
    "ML": {
        "name": "Mali",
        "risk": "Low",
        "score": 1
    },
    "MT": {
        "name": "Malta",
        "risk": "Medium",
        "score": 3
    },
    "MQ": {
        "name": "Martinique",
        "risk": "Low",
        "score": 1
    },
    "MR": {
        "name": "Mauritania",
        "risk": "Low",
        "score": 1
    },
    "MU": {
        "name": "Mauritius",
        "risk": "Medium",
        "score": 3
    },
    "YT": {
        "name": "Mayotte",
        "risk": "Low",
        "score": 1
    },
    "MX": {
        "name": "Mexico",
        "risk": "High",
        "score": 5
    },
    "MC": {
        "name": "Monaco",
        "risk": "High",
        "score": 5
    },
    "MN": {
        "name": "Mongolia",
        "risk": "Low",
        "score": 1
    },
    "MS": {
        "name": "Montserrat",
        "risk": "Medium",
        "score": 3
    },
    "MA": {
        "name": "Morocco",
        "risk": "Low",
        "score": 1
    },
    "MZ": {
        "name": "Mozambique",
        "risk": "Low",
        "score": 1
    },
    "MM": {
        "name": "Myanmar",
        "risk": "High",
        "score": 5
    },
    "NA": {
        "name": "Namibia",
        "risk": "Low",
        "score": 1
    },
    "NR": {
        "name": "Nauru",
        "risk": "High",
        "score": 5
    },
    "NP": {
        "name": "Nepal",
        "risk": "Low",
        "score": 1
    },
    "NC": {
        "name": "New Caledonia",
        "risk": "Low",
        "score": 1
    },
    "NZ": {
        "name": "New Zealand",
        "risk": "Low",
        "score": 1
    },
    "NI": {
        "name": "Nicaragua",
        "risk": "High",
        "score": 5
    },
    "NG": {
        "name": "Nigeria",
        "risk": "High",
        "score": 5
    },
    "NU": {
        "name": "Niue",
        "risk": "High",
        "score": 5
    },
    "NF": {
        "name": "Norfolk Island",
        "risk": "Low",
        "score": 1
    },
    "NO": {
        "name": "Norway",
        "risk": "Low",
        "score": 1
    },
    "OM": {
        "name": "Oman",
        "risk": "Low",
        "score": 1
    },
    "PK": {
        "name": "Pakistan",
        "risk": "High",
        "score": 5
    },
    "PW": {
        "name": "Palau",
        "risk": "Medium",
        "score": 3
    },
    "PA": {
        "name": "Panama",
        "risk": "High",
        "score": 5
    },
    "PG": {
        "name": "Papua New Guinea",
        "risk": "High",
        "score": 5
    },
    "PY": {
        "name": "Paraguay",
        "risk": "Medium",
        "score": 3
    },
    "PE": {
        "name": "Peru",
        "risk": "High",
        "score": 5
    },
    "PN": {
        "name": "Pitcairn",
        "risk": "Low",
        "score": 1
    },
    "PL": {
        "name": "Poland",
        "risk": "Low",
        "score": 1
    },
    "PT": {
        "name": "Portugal",
        "risk": "Low",
        "score": 1
    },
    "PR": {
        "name": "Puerto Rico",
        "risk": "Low",
        "score": 1
    },
    "QA": {
        "name": "Qatar",
        "risk": "Low",
        "score": 1
    },
    "RO": {
        "name": "Romania",
        "risk": "Low",
        "score": 1
    },
    "RW": {
        "name": "Rwanda",
        "risk": "Low",
        "score": 1
    },
    "KN": {
        "name": "Saint Kitts and Nevis",
        "risk": "High",
        "score": 5
    },
    "LC": {
        "name": "Saint Lucia",
        "risk": "Medium",
        "score": 3
    },
    "PM": {
        "name": "Saint Pierre and Miquelon",
        "risk": "Low",
        "score": 1
    },
    "VC": {
        "name": "Saint Vincent and the Grenadines",
        "risk": "Medium",
        "score": 3
    },
    "WS": {
        "name": "Samoa",
        "risk": "Medium",
        "score": 3
    },
    "SM": {
        "name": "San Marino",
        "risk": "Low",
        "score": 1
    },
    "ST": {
        "name": "Sao Tome and Principe",
        "risk": "Medium",
        "score": 3
    },
    "SA": {
        "name": "Saudi Arabia",
        "risk": "High",
        "score": 5
    },
    "SN": {
        "name": "Senegal",
        "risk": "Low",
        "score": 1
    },
    "SC": {
        "name": "Seychelles",
        "risk": "Medium",
        "score": 3
    },
    "SL": {
        "name": "Sierra Leone",
        "risk": "Medium",
        "score": 3
    },
    "SG": {
        "name": "Singapore",
        "risk": "Medium",
        "score": 3
    },
    "SK": {
        "name": "Slovakia",
        "risk": "Low",
        "score": 1
    },
    "SI": {
        "name": "Slovenia",
        "risk": "Low",
        "score": 1
    },
    "SO": {
        "name": "Somalia",
        "risk": "High",
        "score": 5
    },
    "ZA": {
        "name": "South Africa",
        "risk": "Low",
        "score": 1
    },
    "GS": {
        "name": "South Georgia and the South Sandwich Islands",
        "risk": "Low",
        "score": 1
    },
    "ES": {
        "name": "Spain",
        "risk": "Low",
        "score": 1
    },
    "LK": {
        "name": "Sri Lanka",
        "risk": "Low",
        "score": 1
    },
    "SR": {
        "name": "Suriname",
        "risk": "Low",
        "score": 1
    },
    "SJ": {
        "name": "Svalbard and Jan Mayen",
        "risk": "Low",
        "score": 1
    },
    "SZ": {
        "name": "Swaziland",
        "risk": "Low",
        "score": 1
    },
    "SE": {
        "name": "Sweden",
        "risk": "Low",
        "score": 1
    },
    "CH": {
        "name": "Switzerland",
        "risk": "Medium",
        "score": 3
    },
    "TJ": {
        "name": "Tajikistan",
        "risk": "High",
        "score": 5
    },
    "TZ": {
        "name": "Tanzania, United Republic of",
        "risk": "High",
        "score": 5
    },
    "TH": {
        "name": "Thailand",
        "risk": "Low",
        "score": 1
    },
    "TL": {
        "name": "Timor-Leste",
        "risk": "Medium",
        "score": 3
    },
    "TG": {
        "name": "Togo",
        "risk": "Medium",
        "score": 3
    },
    "TK": {
        "name": "Tokelau",
        "risk": "Low",
        "score": 1
    },
    "TO": {
        "name": "Tonga",
        "risk": "Low",
        "score": 1
    },
    "TT": {
        "name": "Trinidad and Tobago",
        "risk": "Low",
        "score": 1
    },
    "TN": {
        "name": "Tunisia",
        "risk": "High",
        "score": 5
    },
    "TR": {
        "name": "Turkey",
        "risk": "High",
        "score": 5
    },
    "TM": {
        "name": "Turkmenistan",
        "risk": "Medium",
        "score": 3
    },
    "TV": {
        "name": "Tuvalu",
        "risk": "Low",
        "score": 1
    },
    "UG": {
        "name": "Uganda",
        "risk": "High",
        "score": 5
    },
    "UA": {
        "name": "Ukraine",
        "risk": "High",
        "score": 5
    },
    "UY": {
        "name": "Uruguay",
        "risk": "Medium",
        "score": 3
    },
    "UZ": {
        "name": "Uzbekistan",
        "risk": "High",
        "score": 5
    },
    "VU": {
        "name": "Vanuatu",
        "risk": "Medium",
        "score": 3
    },
    "VN": {
        "name": "Viet Nam",
        "risk": "Low",
        "score": 1
    },
    "WF": {
        "name": "Wallis and Futuna",
        "risk": "Low",
        "score": 1
    },
    "EH": {
        "name": "Western Sahara",
        "risk": "Low",
        "score": 1
    },
    "YE": {
        "name": "Yemen",
        "risk": "High",
        "score": 5
    },
    "ZM": {
        "name": "Zambia",
        "risk": "Low",
        "score": 1
    },
    "ZW": {
        "name": "Zimbabwe",
        "risk": "High",
        "score": 5
    },
        "GB": {
        "name": "United Kingdom",
        "risk": "Low",
        "score": 1
    },
    "US": {
        "name": "United States Of America",
        "risk": "Low",
        "score": 1
    },
     "AE": {
        "name": "United States Of America",
        "risk": "High",
        "score": 5
    }
}

source_of_wealth_dict = {
    "employment": {
        "name": "Employment (salaried)",
        "risk": "low",
        "score": 1
    },
    "self-employed": {
        "name": "Employment (Self-employed)",
        "risk": "medium",
        "score": 3
    },
    "retired": {
        "name": "Employment (Retirement Income)",
        "risk": "low",
        "score": 1
    },
    "business-earnings": {
        "name": "Business Earnings",
        "risk": "medium",
        "score": 3
    },
    "inheritance": {
        "name": "Inheritance/Family Gift",
        "risk": "high",
        "score": 5
    },
    "insurance-settlement": {
        "name": "Insurance Proceeds/Settlement",
        "risk": "medium",
        "score": 3
    },
    "divorce-settlement": {
        "name": "Divorce Settlement",
        "risk": "low",
        "score": 1
    },
    "investment-returns": {
        "name": "Investment Income/Returns",
        "risk": "medium",
        "score": 3
    },
    "government-lottery": {
        "name": "Winnings (Government Lottery)",
        "risk": "low",
        "score": 1
    },
    "non-government-lottery": {
        "name": "Winnings (Non-Government Lottery)",
        "risk": "low",
        "score": 1
    },
    "sales-of-business": {
        "name": "Earnings (Sale of Business)",
        "risk": "low",
        "score": 1
    },
    "property-sales": {
        "name": "Earnings (Sale of Property)",
        "risk": "low",
        "score": 1
    },
    "sales-of-investments": {
        "name": "Earnings (Sale of Investments)",
        "risk": "low",
        "score": 1
    }
}


high_risk_transaction_dict = {
    "yes": {
        "name": "High",
        "risk": "high",
        "score": 5
    },
    "no": {
        "name": "High",
        "risk": "low",
        "score": 0
    },

}

industry_dict = {
    "All Other Traveler Accommodation": {
        "name": "All Other Traveler Accommodation",
        "code": 721199,
        "risk": "Medium",
        "score": 3
    },
    "Bed-and-Breakfast Inns": {
        "name": "Bed-and-Breakfast Inns",
        "code": 721191,
        "risk": "Medium",
        "score": 3
    },
    "Cafeterias, Grill Buffets, and Buffets": {
        "name": "Cafeterias, Grill Buffets, and Buffets",
        "code": 722514,
        "risk": "High",
        "score": 5
    },
    "Casino Hotels": {
        "name": "Casino Hotels",
        "code": 721120,
        "risk": "High",
        "score": 5
    },
    "Caterers": {
        "name": "Caterers",
        "code": 722320,
        "risk": "Medium",
        "score": 3
    },
    "Drinking Places (Alcoholic Beverages)": {
        "name": "Drinking Places (Alcoholic Beverages)",
        "code": 722410,
        "risk": "High",
        "score": 5
    },
    "Food Service Contractors": {
        "name": "Food Service Contractors",
        "code": 722310,
        "risk": "Medium",
        "score": 3
    },
    "Full-Service Restaurants": {
        "name": "Full-Service Restaurants",
        "code": 722511,
        "risk": "High",
        "score": 5
    },
    "Hotels (except Casio Hotels) and Motels": {
        "name": "Hotels (except Casio Hotels) and Motels",
        "code": 721110,
        "risk": "Medium",
        "score": 3
    },
    "Limited-Service Restaurants": {
        "name": "Limited-Service Restaurants",
        "code": 722513,
        "risk": "High",
        "score": 5
    },
    "Mobile Food Services": {
        "name": "Mobile Food Services",
        "code": 722330,
        "risk": "High",
        "score": 5
    },
    "Recreational and Vacation Camps (except Campgrounds)": {
        "name": "Recreational and Vacation Camps (except Campgrounds)",
        "code": 721214,
        "risk": "Medium",
        "score": 3
    },
    "Rooming and Boarding Houses": {
        "name": "Rooming and Boarding Houses",
        "code": 721310,
        "risk": "Medium",
        "score": 3
    },
    "RV (Recreational Vehicle) Parks and Campgrounds": {
        "name": "RV (Recreational Vehicle) Parks and Campgrounds",
        "code": 721211,
        "risk": "Medium",
        "score": 3
    },
    "Snack and Nonalcoholic Beverage Bars": {
        "name": "Snack and Nonalcoholic Beverage Bars",
        "code": 722515,
        "risk": "High",
        "score": 5
    },
    "All Other Business Support Services": {
        "name": "All Other Business Support Services",
        "code": 561499,
        "risk": "Medium",
        "score": 3
    },
    "All Other Miscellaneous Waste Management Services": {
        "name": "All Other Miscellaneous Waste Management Services",
        "code": 562998,
        "risk": "Medium",
        "score": 3
    },
    "All Other Support Services": {
        "name": "All Other Support Services",
        "code": 561990,
        "risk": "Low",
        "score": 1
    },
    "All Other Travel Arrangement and Reservation Services": {
        "name": "All Other Travel Arrangement and Reservation Services",
        "code": 561599,
        "risk": "High",
        "score": 5
    },
    "Armored Car Services": {
        "name": "Armored Car Services",
        "code": 561613,
        "risk": "Medium",
        "score": 3
    },
    "Carpet and Upholstery Cleaning Services": {
        "name": "Carpet and Upholstery Cleaning Services",
        "code": 561740,
        "risk": "Low",
        "score": 1
    },
    "Collection Agencies": {
        "name": "Collection Agencies",
        "code": 561440,
        "risk": "Medium",
        "score": 3
    },
    "Convention and Trade Show Organizers": {
        "name": "Convention and Trade Show Organizers",
        "code": 561920,
        "risk": "Low",
        "score": 1
    },
    "Convention and Visitors Bureaus": {
        "name": "Convention and Visitors Bureaus",
        "code": 561591,
        "risk": "Medium",
        "score": 3
    },
    "Court Reporting and Stenotype Services": {
        "name": "Court Reporting and Stenotype Services",
        "code": 561492,
        "risk": "Medium",
        "score": 3
    },
    "Credit Bureaus": {
        "name": "Credit Bureaus",
        "code": 561450,
        "risk": "Medium",
        "score": 3
    },
    "Document Preparation Services": {
        "name": "Document Preparation Services",
        "code": 561410,
        "risk": "Medium",
        "score": 3
    },
    "Employment Placement Agencies": {
        "name": "Employment Placement Agencies",
        "code": 561311,
        "risk": "Medium",
        "score": 3
    },
    "Executive Search Services": {
        "name": "Executive Search Services",
        "code": 561312,
        "risk": "Medium",
        "score": 3
    },
    "Exterminating and Pest Control Services": {
        "name": "Exterminating and Pest Control Services",
        "code": 561710,
        "risk": "Low",
        "score": 1
    },
    "Facilities Support Services": {
        "name": "Facilities Support Services",
        "code": 561210,
        "risk": "Medium",
        "score": 3
    },
    "Hazardous Waste Collection": {
        "name": "Hazardous Waste Collection",
        "code": 562112,
        "risk": "High",
        "score": 5
    },
    "Hazardous Waste Treatment and Disposal": {
        "name": "Hazardous Waste Treatment and Disposal",
        "code": 562211,
        "risk": "High",
        "score": 5
    },
    "Investigation Services": {
        "name": "Investigation Services",
        "code": 561611,
        "risk": "Medium",
        "score": 3
    },
    "Janitorial Services": {
        "name": "Janitorial Services",
        "code": 561720,
        "risk": "Low",
        "score": 1
    },
    "Landscaping Services": {
        "name": "Landscaping Services",
        "code": 561730,
        "risk": "Low",
        "score": 1
    },
    "Locksmiths": {
        "name": "Locksmiths",
        "code": 561622,
        "risk": "Medium",
        "score": 3
    },
    "Materials Recovery Facilities": {
        "name": "Materials Recovery Facilities",
        "code": 562920,
        "risk": "Medium",
        "score": 3
    },
    "Office Administrative Services": {
        "name": "Office Administrative Services",
        "code": 561110,
        "risk": "Medium",
        "score": 3
    },
    "Other Business Service Centers (including Copy Shops)": {
        "name": "Other Business Service Centers (including Copy Shops)",
        "code": 561439,
        "risk": "Medium",
        "score": 3
    },
    "Other Nonhazardous Waste Treatment and Disposal": {
        "name": "Other Nonhazardous Waste Treatment and Disposal",
        "code": 562219,
        "risk": "High",
        "score": 5
    },
    "Other Services to Buildings and Dwellings": {
        "name": "Other Services to Buildings and Dwellings",
        "code": 561790,
        "risk": "Low",
        "score": 1
    },
    "Other Waste Collection": {
        "name": "Other Waste Collection",
        "code": 562119,
        "risk": "High",
        "score": 5
    },
    "Packaging and Labeling Services": {
        "name": "Packaging and Labeling Services",
        "code": 561910,
        "risk": "Low",
        "score": 1
    },
    "Private Mail Centers": {
        "name": "Private Mail Centers",
        "code": 561431,
        "risk": "Medium",
        "score": 3
    },
    "Professional Employer Organizations": {
        "name": "Professional Employer Organizations",
        "code": 561330,
        "risk": "Medium",
        "score": 3
    },
    "Remediation Services": {
        "name": "Remediation Services",
        "code": 562910,
        "risk": "Medium",
        "score": 3
    },
    "Repossession Services": {
        "name": "Repossession Services",
        "code": 561491,
        "risk": "Medium",
        "score": 3
    },
    "Security Guards and Patrol Services": {
        "name": "Security Guards and Patrol Services",
        "code": 561612,
        "risk": "Medium",
        "score": 3
    },
    "Security Systems Services (except Locksmiths)": {
        "name": "Security Systems Services (except Locksmiths)",
        "code": 561621,
        "risk": "Medium",
        "score": 3
    },
    "Septic Tank and Related Services": {
        "name": "Septic Tank and Related Services",
        "code": 562991,
        "risk": "Medium",
        "score": 3
    },
    "Solid Waste Collection": {
        "name": "Solid Waste Collection",
        "code": 562111,
        "risk": "High",
        "score": 5
    },
    "Solid Waste Combustors and Incinerators": {
        "name": "Solid Waste Combustors and Incinerators",
        "code": 562213,
        "risk": "High",
        "score": 5
    },
    "Solid Waste Landfill": {
        "name": "Solid Waste Landfill",
        "code": 562212,
        "risk": "High",
        "score": 5
    },
    "Telemarketing Bureaus and Other Contact Centers": {
        "name": "Telemarketing Bureaus and Other Contact Centers",
        "code": 561422,
        "risk": "High",
        "score": 5
    },
    "Telephone Answering Services": {
        "name": "Telephone Answering Services",
        "code": 561421,
        "risk": "Medium",
        "score": 3
    },
    "Temporary Help Services": {
        "name": "Temporary Help Services",
        "code": 561320,
        "risk": "Medium",
        "score": 3
    },
    "Tour Operators": {
        "name": "Tour Operators",
        "code": 561520,
        "risk": "High",
        "score": 5
    },
    "Travel Agencies": {
        "name": "Travel Agencies",
        "code": 561510,
        "risk": "High",
        "score": 5
    },
    "All Other Animal Production": {
        "name": "All Other Animal Production",
        "code": 112990,
        "risk": "Low",
        "score": 1
    },
    "All Other Grain Farming": {
        "name": "All Other Grain Farming",
        "code": 111199,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous Crop Farming": {
        "name": "All Other Miscellaneous Crop Farming",
        "code": 111998,
        "risk": "Low",
        "score": 1
    },
    "Apiculture": {
        "name": "Apiculture",
        "code": 112910,
        "risk": "Low",
        "score": 1
    },
    "Apple Orchards": {
        "name": "Apple Orchards",
        "code": 111331,
        "risk": "Low",
        "score": 1
    },
    "Beef Cattle Ranching and Farming": {
        "name": "Beef Cattle Ranching and Farming",
        "code": 112111,
        "risk": "Low",
        "score": 1
    },
    "Berry (except Strawberry) Farming": {
        "name": "Berry (except Strawberry) Farming",
        "code": 111334,
        "risk": "Low",
        "score": 1
    },
    "Broilers and Other Meat Type Chicken Production": {
        "name": "Broilers and Other Meat Type Chicken Production",
        "code": 112320,
        "risk": "Low",
        "score": 1
    },
    "Cattle Feedlots": {
        "name": "Cattle Feedlots",
        "code": 112112,
        "risk": "Low",
        "score": 1
    },
    "Chicken Egg Production": {
        "name": "Chicken Egg Production",
        "code": 112310,
        "risk": "Low",
        "score": 1
    },
    "Citrus (except Orange) Groves": {
        "name": "Citrus (except Orange) Groves",
        "code": 111320,
        "risk": "Low",
        "score": 1
    },
    "Corn Farming": {
        "name": "Corn Farming",
        "code": 111150,
        "risk": "Low",
        "score": 1
    },
    "Cotton Farming": {
        "name": "Cotton Farming",
        "code": 111920,
        "risk": "Low",
        "score": 1
    },
    "Cotton Ginning": {
        "name": "Cotton Ginning",
        "code": 115111,
        "risk": "Low",
        "score": 1
    },
    "Crop Harvesting, Primarily by Machine": {
        "name": "Crop Harvesting, Primarily by Machine",
        "code": 115113,
        "risk": "Low",
        "score": 1
    },
    "Dairy Cattle and Milk Production": {
        "name": "Dairy Cattle and Milk Production",
        "code": 112120,
        "risk": "Low",
        "score": 1
    },
    "Dry Pea and Bean Farming": {
        "name": "Dry Pea and Bean Farming",
        "code": 111130,
        "risk": "Low",
        "score": 1
    },
    "Dual-Purpose Cattle Ranching and Farming": {
        "name": "Dual-Purpose Cattle Ranching and Farming",
        "code": 112130,
        "risk": "Low",
        "score": 1
    },
    "Farm Labor Contractors and Crew Leaders": {
        "name": "Farm Labor Contractors and Crew Leaders",
        "code": 115115,
        "risk": "Low",
        "score": 1
    },
    "Farm Management Services": {
        "name": "Farm Management Services",
        "code": 115116,
        "risk": "Low",
        "score": 1
    },
    "Finfish Farming and Fish Hatcheries": {
        "name": "Finfish Farming and Fish Hatcheries",
        "code": 112511,
        "risk": "Low",
        "score": 1
    },
    "Finfish Fishing": {
        "name": "Finfish Fishing",
        "code": 114111,
        "risk": "Low",
        "score": 1
    },
    "Floriculture Production": {
        "name": "Floriculture Production",
        "code": 111422,
        "risk": "Low",
        "score": 1
    },
    "Forest Nurseries and Gathering of Forest Products": {
        "name": "Forest Nurseries and Gathering of Forest Products",
        "code": 113210,
        "risk": "Low",
        "score": 1
    },
    "Fruit and Tree Nut Combination Farming": {
        "name": "Fruit and Tree Nut Combination Farming",
        "code": 111336,
        "risk": "Low",
        "score": 1
    },
    "Fur-Bearing Animal and Rabbit Production": {
        "name": "Fur-Bearing Animal and Rabbit Production",
        "code": 112930,
        "risk": "Low",
        "score": 1
    },
    "Goat Farming": {
        "name": "Goat Farming",
        "code": 112420,
        "risk": "Low",
        "score": 1
    },
    "Grape Vineyards": {
        "name": "Grape Vineyards",
        "code": 111332,
        "risk": "Low",
        "score": 1
    },
    "Hay Farming": {
        "name": "Hay Farming",
        "code": 111940,
        "risk": "Low",
        "score": 1
    },
    "Hog and Pig Farming": {
        "name": "Hog and Pig Farming",
        "code": 112210,
        "risk": "Low",
        "score": 1
    },
    "Horse and Other Equine Production": {
        "name": "Horse and Other Equine Production",
        "code": 112920,
        "risk": "Low",
        "score": 1
    },
    "Hunting and Trapping": {
        "name": "Hunting and Trapping",
        "code": 114210,
        "risk": "Low",
        "score": 1
    },
    "Logging": {
        "name": "Logging",
        "code": 113310,
        "risk": "Low",
        "score": 1
    },
    "Mushroom Production": {
        "name": "Mushroom Production",
        "code": 111411,
        "risk": "Low",
        "score": 1
    },
    "Nursery and Tree Production": {
        "name": "Nursery and Tree Production",
        "code": 111421,
        "risk": "Low",
        "score": 1
    },
    "Oilseed (except Soybean) Farming": {
        "name": "Oilseed (except Soybean) Farming",
        "code": 111120,
        "risk": "Low",
        "score": 1
    },
    "Oilseed and Grain Combination Farming": {
        "name": "Oilseed and Grain Combination Farming",
        "code": 111191,
        "risk": "Low",
        "score": 1
    },
    "Orange Groves": {
        "name": "Orange Groves",
        "code": 111310,
        "risk": "Low",
        "score": 1
    },
    "Other Aquaculture": {
        "name": "Other Aquaculture",
        "code": 112519,
        "risk": "Low",
        "score": 1
    },
    "Other Food Crops Grown Under Cover": {
        "name": "Other Food Crops Grown Under Cover",
        "code": 111419,
        "risk": "Low",
        "score": 1
    },
    "Other Marine Fishing": {
        "name": "Other Marine Fishing",
        "code": 114119,
        "risk": "Low",
        "score": 1
    },
    "Other Noncitrus Fruit Farming": {
        "name": "Other Noncitrus Fruit Farming",
        "code": 111339,
        "risk": "Low",
        "score": 1
    },
    "Other Poultry Production": {
        "name": "Other Poultry Production",
        "code": 112390,
        "risk": "Low",
        "score": 1
    },
    "Other Vegetable (except Potato) and Melon Farming": {
        "name": "Other Vegetable (except Potato) and Melon Farming",
        "code": 111219,
        "risk": "Low",
        "score": 1
    },
    "Peanut Farming": {
        "name": "Peanut Farming",
        "code": 111992,
        "risk": "Low",
        "score": 1
    },
    "Post Harvest Crop Activities (except Cotton Ginning)": {
        "name": "Post Harvest Crop Activities (except Cotton Ginning)",
        "code": 115114,
        "risk": "Low",
        "score": 1
    },
    "Potato Farming": {
        "name": "Potato Farming",
        "code": 111211,
        "risk": "Low",
        "score": 1
    },
    "Poultry Hatcheries": {
        "name": "Poultry Hatcheries",
        "code": 112340,
        "risk": "Low",
        "score": 1
    },
    "Rice Farming": {
        "name": "Rice Farming",
        "code": 111160,
        "risk": "Low",
        "score": 1
    },
    "Sheep Farming": {
        "name": "Sheep Farming",
        "code": 112410,
        "risk": "Low",
        "score": 1
    },
    "Shellfish Farming": {
        "name": "Shellfish Farming",
        "code": 112512,
        "risk": "Low",
        "score": 1
    },
    "Shellfish Fishing": {
        "name": "Shellfish Fishing",
        "code": 114112,
        "risk": "Low",
        "score": 1
    },
    "Soil Preparation, Planting, and Cultivating": {
        "name": "Soil Preparation, Planting, and Cultivating",
        "code": 115112,
        "risk": "Low",
        "score": 1
    },
    "Soybean Farming": {
        "name": "Soybean Farming",
        "code": 111110,
        "risk": "Low",
        "score": 1
    },
    "Strawberry Farming": {
        "name": "Strawberry Farming",
        "code": 111333,
        "risk": "Low",
        "score": 1
    },
    "Sugar Beet Farming": {
        "name": "Sugar Beet Farming",
        "code": 111991,
        "risk": "Low",
        "score": 1
    },
    "Sugarcane Farming": {
        "name": "Sugarcane Farming",
        "code": 111930,
        "risk": "Low",
        "score": 1
    },
    "Support Activities for Animal Production": {
        "name": "Support Activities for Animal Production",
        "code": 115210,
        "risk": "Low",
        "score": 1
    },
    "Support Activities for Forestry": {
        "name": "Support Activities for Forestry",
        "code": 115310,
        "risk": "Low",
        "score": 1
    },
    "Timber Tract Operations": {
        "name": "Timber Tract Operations",
        "code": 113110,
        "risk": "Low",
        "score": 1
    },
    "Tobacco Farming": {
        "name": "Tobacco Farming",
        "code": 111910,
        "risk": "Low",
        "score": 1
    },
    "Tree Nut Farming": {
        "name": "Tree Nut Farming",
        "code": 111335,
        "risk": "Low",
        "score": 1
    },
    "Turkey Production": {
        "name": "Turkey Production",
        "code": 112330,
        "risk": "Low",
        "score": 1
    },
    "Wheat Farming": {
        "name": "Wheat Farming",
        "code": 111140,
        "risk": "Low",
        "score": 1
    },
    "Agents and Managers for Artists, Athletes, Entertainers, and Other Public Figures": {
        "name": "Agents and Managers for Artists, Athletes, Entertainers, and Other Public Figures",
        "code": 711410,
        "risk": "Medium",
        "score": 3
    },
    "All Other Amusement and Recreation Industries": {
        "name": "All Other Amusement and Recreation Industries",
        "code": 713990,
        "risk": "Medium",
        "score": 3
    },
    "Amusement and Theme Parks": {
        "name": "Amusement and Theme Parks",
        "code": 713110,
        "risk": "Medium",
        "score": 3
    },
    "Amusement Arcades": {
        "name": "Amusement Arcades",
        "code": 713120,
        "risk": "Medium",
        "score": 3
    },
    "Bowling Centers": {
        "name": "Bowling Centers",
        "code": 713950,
        "risk": "Medium",
        "score": 3
    },
    "Casinos (except Casino Hotels)": {
        "name": "Casinos (except Casino Hotels)",
        "code": 713210,
        "risk": "High",
        "score": 5
    },
    "Dance Companies": {
        "name": "Dance Companies",
        "code": 711120,
        "risk": "Low",
        "score": 1
    },
    "Fitness and Recreational Sports Centers": {
        "name": "Fitness and Recreational Sports Centers",
        "code": 713940,
        "risk": "Medium",
        "score": 3
    },
    "Golf Courses and Country Clubs": {
        "name": "Golf Courses and Country Clubs",
        "code": 713910,
        "risk": "Medium",
        "score": 3
    },
    "Historical Sites": {
        "name": "Historical Sites",
        "code": 712120,
        "risk": "Medium",
        "score": 3
    },
    "Independent Artists, Writers, and Performers": {
        "name": "Independent Artists, Writers, and Performers",
        "code": 711510,
        "risk": "Medium",
        "score": 3
    },
    "Marinas": {
        "name": "Marinas",
        "code": 713930,
        "risk": "Medium",
        "score": 3
    },
    "Museums": {
        "name": "Museums",
        "code": 712110,
        "risk": "Medium",
        "score": 3
    },
    "Musical Groups and Artists": {
        "name": "Musical Groups and Artists",
        "code": 711130,
        "risk": "Low",
        "score": 1
    },
    "Nature Parks and Other Similar Institutions": {
        "name": "Nature Parks and Other Similar Institutions",
        "code": 712190,
        "risk": "Medium",
        "score": 3
    },
    "Other Gambling Industries": {
        "name": "Other Gambling Industries",
        "code": 713290,
        "risk": "High",
        "score": 5
    },
    "Other Performing Arts Companies": {
        "name": "Other Performing Arts Companies",
        "code": 711190,
        "risk": "Low",
        "score": 1
    },
    "Other Spectator Sports": {
        "name": "Other Spectator Sports",
        "code": 711219,
        "risk": "High",
        "score": 5
    },
    "Promoters of Performing Arts, Sports, and Similar Events with Facilities": {
        "name": "Promoters of Performing Arts, Sports, and Similar Events with Facilities",
        "code": 711310,
        "risk": "Medium",
        "score": 3
    },
    "Promoters of Performing Arts, Sports, and Similar Events without Facilities": {
        "name": "Promoters of Performing Arts, Sports, and Similar Events without Facilities",
        "code": 711320,
        "risk": "Medium",
        "score": 3
    },
    "Racetracks": {
        "name": "Racetracks",
        "code": 711212,
        "risk": "High",
        "score": 5
    },
    "Skiing Facilities": {
        "name": "Skiing Facilities",
        "code": 713920,
        "risk": "Medium",
        "score": 3
    },
    "Sports Teams and Clubs": {
        "name": "Sports Teams and Clubs",
        "code": 711211,
        "risk": "Low",
        "score": 1
    },
    "Theater Companies and Dinner Theaters": {
        "name": "Theater Companies and Dinner Theaters",
        "code": 711110,
        "risk": "Low",
        "score": 1
    },
    "Zoos and Botanical Gardens": {
        "name": "Zoos and Botanical Gardens",
        "code": 712130,
        "risk": "Medium",
        "score": 3
    },
    "All Other Specialty Trade Contractors": {
        "name": "All Other Specialty Trade Contractors",
        "code": 238990,
        "risk": "Medium",
        "score": 3
    },
    "Commercial and Institutional Building Construction": {
        "name": "Commercial and Institutional Building Construction",
        "code": 236220,
        "risk": "Medium",
        "score": 3
    },
    "Drywall and Insulation Contractors": {
        "name": "Drywall and Insulation Contractors",
        "code": 238310,
        "risk": "Medium",
        "score": 3
    },
    "Electrical Contractors": {
        "name": "Electrical Contractors",
        "code": 238210,
        "risk": "Medium",
        "score": 3
    },
    "Finish Carpentry Contractors": {
        "name": "Finish Carpentry Contractors",
        "code": 238350,
        "risk": "Medium",
        "score": 3
    },
    "Flooring Contractors": {
        "name": "Flooring Contractors",
        "code": 238330,
        "risk": "Medium",
        "score": 3
    },
    "Framing Contractors": {
        "name": "Framing Contractors",
        "code": 238130,
        "risk": "Medium",
        "score": 3
    },
    "Glass and Glazing Contractors": {
        "name": "Glass and Glazing Contractors",
        "code": 238150,
        "risk": "Medium",
        "score": 3
    },
    "Highway, Street, and Bridge Construction": {
        "name": "Highway, Street, and Bridge Construction",
        "code": 237310,
        "risk": "Medium",
        "score": 3
    },
    "Industrial Building Construction": {
        "name": "Industrial Building Construction",
        "code": 236210,
        "risk": "Medium",
        "score": 3
    },
    "Land Subdivision": {
        "name": "Land Subdivision",
        "code": 237210,
        "risk": "Medium",
        "score": 3
    },
    "Masonry Contractors": {
        "name": "Masonry Contractors",
        "code": 238140,
        "risk": "Medium",
        "score": 3
    },
    "New Housing For-Sale Builders": {
        "name": "New Housing For-Sale Builders",
        "code": 236117,
        "risk": "Medium",
        "score": 3
    },
    "New Multifamily Housing Construction (except For-Sale Builders)": {
        "name": "New Multifamily Housing Construction (except For-Sale Builders)",
        "code": 236116,
        "risk": "Medium",
        "score": 3
    },
    "New Single-Family Housing (except For-Sale Builders)": {
        "name": "New Single-Family Housing (except For-Sale Builders)",
        "code": 236115,
        "risk": "Medium",
        "score": 3
    },
    "Oil and Gas Pipeline and Related Structures Construction": {
        "name": "Oil and Gas Pipeline and Related Structures Construction",
        "code": 237120,
        "risk": "Medium",
        "score": 3
    },
    "Other Building Equipment Contractors": {
        "name": "Other Building Equipment Contractors",
        "code": 238290,
        "risk": "Medium",
        "score": 3
    },
    "Other Building Finishing Contractors": {
        "name": "Other Building Finishing Contractors",
        "code": 238390,
        "risk": "Medium",
        "score": 3
    },
    "Other Foundation, Structure, and Building Exterior Contractors": {
        "name": "Other Foundation, Structure, and Building Exterior Contractors",
        "code": 238190,
        "risk": "Medium",
        "score": 3
    },
    "Other Heavy and Civil Engineering Construction": {
        "name": "Other Heavy and Civil Engineering Construction",
        "code": 237990,
        "risk": "Medium",
        "score": 3
    },
    "Painting and Wall Covering Contractors": {
        "name": "Painting and Wall Covering Contractors",
        "code": 238320,
        "risk": "Medium",
        "score": 3
    },
    "Plumbing, Heating, and Air-Conditioning Contractors": {
        "name": "Plumbing, Heating, and Air-Conditioning Contractors",
        "code": 238220,
        "risk": "Medium",
        "score": 3
    },
    "Poured Concrete Foundation and Structure Contractors": {
        "name": "Poured Concrete Foundation and Structure Contractors",
        "code": 238110,
        "risk": "Medium",
        "score": 3
    },
    "Power and Communication Line and Related Structures Construction": {
        "name": "Power and Communication Line and Related Structures Construction",
        "code": 237130,
        "risk": "Medium",
        "score": 3
    },
    "Residential Remodelers": {
        "name": "Residential Remodelers",
        "code": 236118,
        "risk": "Medium",
        "score": 3
    },
    "Roofing Contractors": {
        "name": "Roofing Contractors",
        "code": 238160,
        "risk": "Medium",
        "score": 3
    },
    "Siding Contractors": {
        "name": "Siding Contractors",
        "code": 238170,
        "risk": "Medium",
        "score": 3
    },
    "Site Preparation Contractors": {
        "name": "Site Preparation Contractors",
        "code": 238910,
        "risk": "Medium",
        "score": 3
    },
    "Structural Steel and Precast Concrete Contractors": {
        "name": "Structural Steel and Precast Concrete Contractors",
        "code": 238120,
        "risk": "Medium",
        "score": 3
    },
    "Tile and Terrazzo Contractors": {
        "name": "Tile and Terrazzo Contractors",
        "code": 238340,
        "risk": "Medium",
        "score": 3
    },
    "Water and Sewer Line and Related Structures Construction": {
        "name": "Water and Sewer Line and Related Structures Construction",
        "code": 237110,
        "risk": "Medium",
        "score": 3
    },
    "All Other Miscellaneous Schools and Instruction": {
        "name": "All Other Miscellaneous Schools and Instruction",
        "code": 611699,
        "risk": "Low",
        "score": 1
    },
    "Apprenticeship Training": {
        "name": "Apprenticeship Training",
        "code": 611513,
        "risk": "Low",
        "score": 1
    },
    "Automobile Driving Schools": {
        "name": "Automobile Driving Schools",
        "code": 611692,
        "risk": "Low",
        "score": 1
    },
    "Business and Secretarial Schools": {
        "name": "Business and Secretarial Schools",
        "code": 611410,
        "risk": "Low",
        "score": 1
    },
    "Colleges, Universities, and Professional Schools": {
        "name": "Colleges, Universities, and Professional Schools",
        "code": 611310,
        "risk": "Low",
        "score": 1
    },
    "Computer Training": {
        "name": "Computer Training",
        "code": 611420,
        "risk": "Low",
        "score": 1
    },
    "Cosmetology and Barber Schools": {
        "name": "Cosmetology and Barber Schools",
        "code": 611511,
        "risk": "Low",
        "score": 1
    },
    "Educational Support Services": {
        "name": "Educational Support Services",
        "code": 611710,
        "risk": "Low",
        "score": 1
    },
    "Elementary and Secondary Schools": {
        "name": "Elementary and Secondary Schools",
        "code": 611110,
        "risk": "Low",
        "score": 1
    },
    "Exam Preparation and Tutoring": {
        "name": "Exam Preparation and Tutoring",
        "code": 611691,
        "risk": "Low",
        "score": 1
    },
    "Fine Arts Schools": {
        "name": "Fine Arts Schools",
        "code": 611610,
        "risk": "Low",
        "score": 1
    },
    "Flight Training": {
        "name": "Flight Training",
        "code": 611512,
        "risk": "High",
        "score": 5
    },
    "Junior Colleges": {
        "name": "Junior Colleges",
        "code": 611210,
        "risk": "Low",
        "score": 1
    },
    "Language Schools": {
        "name": "Language Schools",
        "code": 611630,
        "risk": "Low",
        "score": 1
    },
    "Other Technical and Trade Schools": {
        "name": "Other Technical and Trade Schools",
        "code": 611519,
        "risk": "Low",
        "score": 1
    },
    "Professional and Management Development Training": {
        "name": "Professional and Management Development Training",
        "code": 611430,
        "risk": "Low",
        "score": 1
    },
    "Sports and Recreation Instruction": {
        "name": "Sports and Recreation Instruction",
        "code": 611620,
        "risk": "Low",
        "score": 1
    },
    "All Other Insurance Related Activities": {
        "name": "All Other Insurance Related Activities",
        "code": 524298,
        "risk": "Medium",
        "score": 3
    },
    "All Other Nondepository Credit Intermediation": {
        "name": "All Other Nondepository Credit Intermediation",
        "code": 522298,
        "risk": "High",
        "score": 5
    },
    "Claims Adjusting": {
        "name": "Claims Adjusting",
        "code": 524291,
        "risk": "Medium",
        "score": 3
    },
    "Commercial Banking": {
        "name": "Commercial Banking",
        "code": 522110,
        "risk": "High",
        "score": 5
    },
    "Commodity Contracts Brokerage": {
        "name": "Commodity Contracts Brokerage",
        "code": 523140,
        "risk": "High",
        "score": 5
    },
    "Commodity Contracts Dealing": {
        "name": "Commodity Contracts Dealing",
        "code": 523130,
        "risk": "High",
        "score": 5
    },
    "Consumer Lending": {
        "name": "Consumer Lending",
        "code": 522291,
        "risk": "High",
        "score": 5
    },
    "Credit Card Issuing": {
        "name": "Credit Card Issuing",
        "code": 522210,
        "risk": "High",
        "score": 5
    },
    "Credit Unions": {
        "name": "Credit Unions",
        "code": 522130,
        "risk": "High",
        "score": 5
    },
    "Direct Health and Medical Insurance Carriers": {
        "name": "Direct Health and Medical Insurance Carriers",
        "code": 524114,
        "risk": "Medium",
        "score": 3
    },
    "Direct Life Insurance Carriers": {
        "name": "Direct Life Insurance Carriers",
        "code": 524113,
        "risk": "Medium",
        "score": 3
    },
    "Direct Property and Causality Insurance Carriers": {
        "name": "Direct Property and Causality Insurance Carriers",
        "code": 524126,
        "risk": "Medium",
        "score": 3
    },
    "Direct Title Insurance Carriers": {
        "name": "Direct Title Insurance Carriers",
        "code": 524127,
        "risk": "High",
        "score": 5
    },
    "Financial Transactions Processing, Reserve, and Clearinghouse Activities": {
        "name": "Financial Transactions Processing, Reserve, and Clearinghouse Activities",
        "code": 522320,
        "risk": "High",
        "score": 5
    },
    "Health and Welfare Funds": {
        "name": "Health and Welfare Funds",
        "code": 525120,
        "risk": "Medium",
        "score": 3
    },
    "Insurance Agencies and Brokerages": {
        "name": "Insurance Agencies and Brokerages",
        "code": 524210,
        "risk": "High",
        "score": 5
    },
    "International Trade Financing": {
        "name": "International Trade Financing",
        "code": 522293,
        "risk": "High",
        "score": 5
    },
    "Investment Advice": {
        "name": "Investment Advice",
        "code": 523930,
        "risk": "High",
        "score": 5
    },
    "Investment Banking and Securities Dealing": {
        "name": "Investment Banking and Securities Dealing",
        "code": 523110,
        "risk": "High",
        "score": 5
    },
    "Miscellaneous Financial Investment Activities": {
        "name": "Miscellaneous Financial Investment Activities",
        "code": 523999,
        "risk": "High",
        "score": 5
    },
    "Miscellaneous Intermediation": {
        "name": "Miscellaneous Intermediation",
        "code": 523910,
        "risk": "High",
        "score": 5
    },
    "Monetary Authorities-Central Bank": {
        "name": "Monetary Authorities-Central Bank",
        "code": 521110,
        "risk": "Medium",
        "score": 3
    },
    "Mortgage and Nonmortgage Loan Brokers": {
        "name": "Mortgage and Nonmortgage Loan Brokers",
        "code": 522310,
        "risk": "High",
        "score": 5
    },
    "Open-End Investment Funds": {
        "name": "Open-End Investment Funds",
        "code": 525910,
        "risk": "Medium",
        "score": 3
    },
    "Other Activities Related to Credit Intermediation": {
        "name": "Other Activities Related to Credit Intermediation",
        "code": 522390,
        "risk": "High",
        "score": 5
    },
    "Other Depository Credit Intermediation": {
        "name": "Other Depository Credit Intermediation",
        "code": 522190,
        "risk": "High",
        "score": 5
    },
    "Other Direct Insurance (except Life, Health, and Medical) Carriers": {
        "name": "Other Direct Insurance (except Life, Health, and Medical) Carriers",
        "code": 524128,
        "risk": "High",
        "score": 5
    },
    "Other Financial Vehicles": {
        "name": "Other Financial Vehicles",
        "code": 525990,
        "risk": "High",
        "score": 5
    },
    "Other Insurance Funds": {
        "name": "Other Insurance Funds",
        "code": 525190,
        "risk": "Medium",
        "score": 3
    },
    "Pension Funds": {
        "name": "Pension Funds",
        "code": 525110,
        "risk": "Medium",
        "score": 3
    },
    "Portfolio Management": {
        "name": "Portfolio Management",
        "code": 523920,
        "risk": "High",
        "score": 5
    },
    "Real Estate Credit": {
        "name": "Real Estate Credit",
        "code": 522292,
        "risk": "High",
        "score": 5
    },
    "Reinsurance Carriers": {
        "name": "Reinsurance Carriers",
        "code": 524130,
        "risk": "Medium",
        "score": 3
    },
    "Sales Financing": {
        "name": "Sales Financing",
        "code": 522220,
        "risk": "High",
        "score": 5
    },
    "Savings Institutions": {
        "name": "Savings Institutions",
        "code": 522120,
        "risk": "High",
        "score": 5
    },
    "Secondary Market Financing": {
        "name": "Secondary Market Financing",
        "code": 522294,
        "risk": "High",
        "score": 5
    },
    "Securities and Commodity Exchanges": {
        "name": "Securities and Commodity Exchanges",
        "code": 523210,
        "risk": "Medium",
        "score": 3
    },
    "Securities Brokerage": {
        "name": "Securities Brokerage",
        "code": 523120,
        "risk": "High",
        "score": 5
    },
    "Third Party Administration of Insurance and Pension Funds": {
        "name": "Third Party Administration of Insurance and Pension Funds",
        "code": 524292,
        "risk": "Medium",
        "score": 3
    },
    "Trust, Fiduciary, and Custody Activities": {
        "name": "Trust, Fiduciary, and Custody Activities",
        "code": 523991,
        "risk": "High",
        "score": 5
    },
    "Trusts, Estates, and Agency Accounts": {
        "name": "Trusts, Estates, and Agency Accounts",
        "code": 525920,
        "risk": "High",
        "score": 5
    },
    "All Other Miscellaneous Ambulatory Health Care Services": {
        "name": "All Other Miscellaneous Ambulatory Health Care Services",
        "code": 621999,
        "risk": "Low",
        "score": 1
    },
    "All Other Outpatient Care Centers": {
        "name": "All Other Outpatient Care Centers",
        "code": 621498,
        "risk": "Low",
        "score": 1
    },
    "Ambulance Services": {
        "name": "Ambulance Services",
        "code": 621910,
        "risk": "Low",
        "score": 1
    },
    "Assisted Living Facilities for the Elderly": {
        "name": "Assisted Living Facilities for the Elderly",
        "code": 623312,
        "risk": "Low",
        "score": 1
    },
    "Blood and Organ Banks": {
        "name": "Blood and Organ Banks",
        "code": 621991,
        "risk": "Low",
        "score": 1
    },
    "Child and Youth Services": {
        "name": "Child and Youth Services",
        "code": 624110,
        "risk": "Low",
        "score": 1
    },
    "Child Day Care Services": {
        "name": "Child Day Care Services",
        "code": 624410,
        "risk": "Low",
        "score": 1
    },
    "Community Food Services": {
        "name": "Community Food Services",
        "code": 624210,
        "risk": "Low",
        "score": 1
    },
    "Continuing Care Retirement Communities": {
        "name": "Continuing Care Retirement Communities",
        "code": 623311,
        "risk": "Low",
        "score": 1
    },
    "Diagnostic Imaging Centers": {
        "name": "Diagnostic Imaging Centers",
        "code": 621512,
        "risk": "Low",
        "score": 1
    },
    "Emergency and Other Relief Services": {
        "name": "Emergency and Other Relief Services",
        "code": 624230,
        "risk": "Low",
        "score": 1
    },
    "Family Planning Centers": {
        "name": "Family Planning Centers",
        "code": 621410,
        "risk": "Low",
        "score": 1
    },
    "Freestanding Ambulatory Surgical and Emergency Centers": {
        "name": "Freestanding Ambulatory Surgical and Emergency Centers",
        "code": 621493,
        "risk": "Low",
        "score": 1
    },
    "General Medical and Surgical Hospitals": {
        "name": "General Medical and Surgical Hospitals",
        "code": 622110,
        "risk": "Low",
        "score": 1
    },
    "HMO Medical Centers": {
        "name": "HMO Medical Centers",
        "code": 621491,
        "risk": "Low",
        "score": 1
    },
    "Home Health Care Services": {
        "name": "Home Health Care Services",
        "code": 621610,
        "risk": "Low",
        "score": 1
    },
    "Kidney Dialysis Centers": {
        "name": "Kidney Dialysis Centers",
        "code": 621492,
        "risk": "Low",
        "score": 1
    },
    "Medical Laboratories": {
        "name": "Medical Laboratories",
        "code": 621511,
        "risk": "Low",
        "score": 1
    },
    "Nursing Care Facilities (Skilled Nursing Facilities)": {
        "name": "Nursing Care Facilities (Skilled Nursing Facilities)",
        "code": 623110,
        "risk": "Low",
        "score": 1
    },
    "Offices of All Other Miscellaneous Health Practitioners": {
        "name": "Offices of All Other Miscellaneous Health Practitioners",
        "code": 621399,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Chiropractors": {
        "name": "Offices of Chiropractors",
        "code": 621310,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Dentists": {
        "name": "Offices of Dentists",
        "code": 621210,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Mental Health Practitioners (except Physicians)": {
        "name": "Offices of Mental Health Practitioners (except Physicians)",
        "code": 621330,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Optometrists": {
        "name": "Offices of Optometrists",
        "code": 621320,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Physical, Occupational and Speech Therapists, and Audiologists": {
        "name": "Offices of Physical, Occupational and Speech Therapists, and Audiologists",
        "code": 621340,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Physicians (Except Mental Health Specialists)": {
        "name": "Offices of Physicians (Except Mental Health Specialists)",
        "code": 621111,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Physicians, Mental Health Specialists": {
        "name": "Offices of Physicians, Mental Health Specialists",
        "code": 621112,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Podiatrists": {
        "name": "Offices of Podiatrists",
        "code": 621391,
        "risk": "Medium",
        "score": 3
    },
    "Other Community Housing Services": {
        "name": "Other Community Housing Services",
        "code": 624229,
        "risk": "Low",
        "score": 1
    },
    "Other Individual and Family Services": {
        "name": "Other Individual and Family Services",
        "code": 624190,
        "risk": "Low",
        "score": 1
    },
    "Other Residential Care Facilities": {
        "name": "Other Residential Care Facilities",
        "code": 623990,
        "risk": "Low",
        "score": 1
    },
    "Outpatient Mental Health and Substance Abuse Centers": {
        "name": "Outpatient Mental Health and Substance Abuse Centers",
        "code": 621420,
        "risk": "Low",
        "score": 1
    },
    "Psychiatric and Substance Abuse Hospitals": {
        "name": "Psychiatric and Substance Abuse Hospitals",
        "code": 622210,
        "risk": "Low",
        "score": 1
    },
    "Residential Intellectual and Developmental Disability Facilities": {
        "name": "Residential Intellectual and Developmental Disability Facilities",
        "code": 623210,
        "risk": "Low",
        "score": 1
    },
    "Residential Mental Health and Substance Abuse Facilities": {
        "name": "Residential Mental Health and Substance Abuse Facilities",
        "code": 623220,
        "risk": "Low",
        "score": 1
    },
    "Services for the Elderly and Persons with Disabilities": {
        "name": "Services for the Elderly and Persons with Disabilities",
        "code": 624120,
        "risk": "Low",
        "score": 1
    },
    "Specialty (except Psychiatric and Substance Abuse) Hospitals": {
        "name": "Specialty (except Psychiatric and Substance Abuse) Hospitals",
        "code": 622310,
        "risk": "Low",
        "score": 1
    },
    "Temporary Shelters": {
        "name": "Temporary Shelters",
        "code": 624221,
        "risk": "Low",
        "score": 1
    },
    "Vocational Rehabilitation Services": {
        "name": "Vocational Rehabilitation Services",
        "code": 624310,
        "risk": "Low",
        "score": 1
    },
    "All Other Information Services": {
        "name": "All Other Information Services",
        "code": 519190,
        "risk": "Low",
        "score": 1
    },
    "All Other Publishers": {
        "name": "All Other Publishers",
        "code": 511199,
        "risk": "Low",
        "score": 1
    },
    "All Other Telecommunications": {
        "name": "All Other Telecommunications",
        "code": 517919,
        "risk": "Medium",
        "score": 3
    },
    "Book Publishers": {
        "name": "Book Publishers",
        "code": 511130,
        "risk": "Low",
        "score": 1
    },
    "Cable and Other Subscription Programming": {
        "name": "Cable and Other Subscription Programming",
        "code": 515210,
        "risk": "Low",
        "score": 1
    },
    "Data Processing, Hosting, and Related Services": {
        "name": "Data Processing, Hosting, and Related Services",
        "code": 518210,
        "risk": "Low",
        "score": 1
    },
    "Directory and Mailing List Publishers": {
        "name": "Directory and Mailing List Publishers",
        "code": 511140,
        "risk": "Low",
        "score": 1
    },
    "Drive-In Motion Picture Theaters": {
        "name": "Drive-In Motion Picture Theaters",
        "code": 512132,
        "risk": "Low",
        "score": 1
    },
    "Greeting Card Publishers": {
        "name": "Greeting Card Publishers",
        "code": 511191,
        "risk": "Low",
        "score": 1
    },
    "Integrated Record Production/Distribution": {
        "name": "Integrated Record Production/Distribution",
        "code": 512220,
        "risk": "Low",
        "score": 1
    },
    "Internet Publishing and Broadcasting and Web Search Portals": {
        "name": "Internet Publishing and Broadcasting and Web Search Portals",
        "code": 519130,
        "risk": "Low",
        "score": 1
    },
    "Libraries and Archives": {
        "name": "Libraries and Archives",
        "code": 519120,
        "risk": "Low",
        "score": 1
    },
    "Motion Picture and Video Distribution": {
        "name": "Motion Picture and Video Distribution",
        "code": 512120,
        "risk": "Low",
        "score": 1
    },
    "Motion Picture and Video Production": {
        "name": "Motion Picture and Video Production",
        "code": 512110,
        "risk": "Low",
        "score": 1
    },
    "Motion Picture Theaters (except Drive-Ins)": {
        "name": "Motion Picture Theaters (except Drive-Ins)",
        "code": 512131,
        "risk": "Low",
        "score": 1
    },
    "Music Publishers": {
        "name": "Music Publishers",
        "code": 512230,
        "risk": "Low",
        "score": 1
    },
    "News Syndicates": {
        "name": "News Syndicates",
        "code": 519110,
        "risk": "Low",
        "score": 1
    },
    "Newspaper Publishers": {
        "name": "Newspaper Publishers",
        "code": 511110,
        "risk": "Low",
        "score": 1
    },
    "Other Motion Picture and Video Industries": {
        "name": "Other Motion Picture and Video Industries",
        "code": 512199,
        "risk": "Low",
        "score": 1
    },
    "Other Sound Recording Industries": {
        "name": "Other Sound Recording Industries",
        "code": 512290,
        "risk": "Low",
        "score": 1
    },
    "Periodical Publishers": {
        "name": "Periodical Publishers",
        "code": 511120,
        "risk": "Low",
        "score": 1
    },
    "Radio Networks": {
        "name": "Radio Networks",
        "code": 515111,
        "risk": "Low",
        "score": 1
    },
    "Radio Stations": {
        "name": "Radio Stations",
        "code": 515112,
        "risk": "Low",
        "score": 1
    },
    "Record Production": {
        "name": "Record Production",
        "code": 512210,
        "risk": "Low",
        "score": 1
    },
    "Satellite Telecommunications": {
        "name": "Satellite Telecommunications",
        "code": 517410,
        "risk": "Low",
        "score": 1
    },
    "Software Publishers": {
        "name": "Software Publishers",
        "code": 511210,
        "risk": "Low",
        "score": 1
    },
    "Sound Recording Studios": {
        "name": "Sound Recording Studios",
        "code": 512240,
        "risk": "Low",
        "score": 1
    },
    "Telecommunications Resellers": {
        "name": "Telecommunications Resellers",
        "code": 517911,
        "risk": "Medium",
        "score": 3
    },
    "Teleproduction and Other Postproduction Services": {
        "name": "Teleproduction and Other Postproduction Services",
        "code": 512191,
        "risk": "Low",
        "score": 1
    },
    "Television Broadcasting": {
        "name": "Television Broadcasting",
        "code": 515120,
        "risk": "Low",
        "score": 1
    },
    "Wired Telecommunications Carriers": {
        "name": "Wired Telecommunications Carriers",
        "code": 517110,
        "risk": "Low",
        "score": 1
    },
    "Wireless Telecommunications Carriers (except Satellite)": {
        "name": "Wireless Telecommunications Carriers (except Satellite)",
        "code": 517210,
        "risk": "Low",
        "score": 1
    },
    "Corporate, Subsidiary, and Regional Managing Offices": {
        "name": "Corporate, Subsidiary, and Regional Managing Offices",
        "code": 551114,
        "risk": "Low",
        "score": 1
    },
    "Offices of Bank Holding Companies": {
        "name": "Offices of Bank Holding Companies",
        "code": 551111,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Other Holding Companies": {
        "name": "Offices of Other Holding Companies",
        "code": 551112,
        "risk": "Medium",
        "score": 3
    },
    "Abrasive Product Manufacturing": {
        "name": "Abrasive Product Manufacturing",
        "code": 327910,
        "risk": "Low",
        "score": 1
    },
    "Adhesive Manufacturing": {
        "name": "Adhesive Manufacturing",
        "code": 325520,
        "risk": "Low",
        "score": 1
    },
    "Air and Gas Compressor Manufacturing": {
        "name": "Air and Gas Compressor Manufacturing",
        "code": 333912,
        "risk": "Low",
        "score": 1
    },
    "Air-Conditioning and Warm Air Heating Equipment and Commercial and Industrial Refrigeration Equipment Manufacturing": {
        "name": "Air-Conditioning and Warm Air Heating Equipment and Commercial and Industrial Refrigeration Equipment Manufacturing",
        "code": 333415,
        "risk": "Low",
        "score": 1
    },
    "Aircraft Engine and Engine Parts Manufacturing": {
        "name": "Aircraft Engine and Engine Parts Manufacturing",
        "code": 336412,
        "risk": "Low",
        "score": 1
    },
    "Aircraft Manufacturing": {
        "name": "Aircraft Manufacturing",
        "code": 336411,
        "risk": "Low",
        "score": 1
    },
    "All Other Basic Organic Chemical Manufacturing": {
        "name": "All Other Basic Organic Chemical Manufacturing",
        "code": 325199,
        "risk": "Low",
        "score": 1
    },
    "All Other Converted Paper Product Manufacturing": {
        "name": "All Other Converted Paper Product Manufacturing",
        "code": 322299,
        "risk": "Low",
        "score": 1
    },
    "All Other Leather Good and Allied Product Manufacturing": {
        "name": "All Other Leather Good and Allied Product Manufacturing",
        "code": 316998,
        "risk": "Medium",
        "score": 3
    },
    "All Other Miscellaneous Chemical Product and Preparation Manufacturing": {
        "name": "All Other Miscellaneous Chemical Product and Preparation Manufacturing",
        "code": 325998,
        "risk": "Medium",
        "score": 3
    },
    "All Other Miscellaneous Electrical Equipment and Component Manufacturing": {
        "name": "All Other Miscellaneous Electrical Equipment and Component Manufacturing",
        "code": 335999,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous Fabricated Metal Product Manufacturing": {
        "name": "All Other Miscellaneous Fabricated Metal Product Manufacturing",
        "code": 332999,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous Food Manufacturing": {
        "name": "All Other Miscellaneous Food Manufacturing",
        "code": 311999,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous General Purpose Machinery Manufacturing": {
        "name": "All Other Miscellaneous General Purpose Machinery Manufacturing",
        "code": 333999,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous Manufacturing": {
        "name": "All Other Miscellaneous Manufacturing",
        "code": 339999,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous Nonmetallic Mineral Product Manufacturing": {
        "name": "All Other Miscellaneous Nonmetallic Mineral Product Manufacturing",
        "code": 327999,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous Textile Product Mills": {
        "name": "All Other Miscellaneous Textile Product Mills",
        "code": 314999,
        "risk": "Low",
        "score": 1
    },
    "All Other Miscellaneous Wood Product Manufacturing": {
        "name": "All Other Miscellaneous Wood Product Manufacturing",
        "code": 321999,
        "risk": "Medium",
        "score": 3
    },
    "All Other Petroleum and Coal Products Manufacturing": {
        "name": "All Other Petroleum and Coal Products Manufacturing",
        "code": 324199,
        "risk": "Low",
        "score": 1
    },
    "All Other Plastics Product Manufacturing": {
        "name": "All Other Plastics Product Manufacturing",
        "code": 326199,
        "risk": "Low",
        "score": 1
    },
    "All Other Rubber Product Manufacturing": {
        "name": "All Other Rubber Product Manufacturing",
        "code": 326299,
        "risk": "Low",
        "score": 1
    },
    "All Other Transportation Equipment Manufacturing": {
        "name": "All Other Transportation Equipment Manufacturing",
        "code": 336999,
        "risk": "Medium",
        "score": 3
    },
    "Alumina Refining and Primary Aluminum Production": {
        "name": "Alumina Refining and Primary Aluminum Production",
        "code": 331313,
        "risk": "Low",
        "score": 1
    },
    "Aluminum Foundries (except Die-Casting)": {
        "name": "Aluminum Foundries (except Die-Casting)",
        "code": 331524,
        "risk": "Low",
        "score": 1
    },
    "Aluminum Sheet, Plate, and Foil Manufacturing": {
        "name": "Aluminum Sheet, Plate, and Foil Manufacturing",
        "code": 331315,
        "risk": "Low",
        "score": 1
    },
    "Ammunition (except Small Arms) Manufacturing": {
        "name": "Ammunition (except Small Arms) Manufacturing",
        "code": 332993,
        "risk": "Medium",
        "score": 3
    },
    "Analytical Laboratory Instrument Manufacturing": {
        "name": "Analytical Laboratory Instrument Manufacturing",
        "code": 334516,
        "risk": "Low",
        "score": 1
    },
    "Animal (except Poultry) Slaughtering": {
        "name": "Animal (except Poultry) Slaughtering",
        "code": 311611,
        "risk": "Low",
        "score": 1
    },
    "Apparel Accessories and Other Apparel Manufacturing": {
        "name": "Apparel Accessories and Other Apparel Manufacturing",
        "code": 315990,
        "risk": "Medium",
        "score": 3
    },
    "Artificial and Synthetic Fibers and Filaments Manufacturing": {
        "name": "Artificial and Synthetic Fibers and Filaments Manufacturing",
        "code": 325220,
        "risk": "Low",
        "score": 1
    },
    "Asphalt Paving Mixture and Block Manufacturing": {
        "name": "Asphalt Paving Mixture and Block Manufacturing",
        "code": 324121,
        "risk": "Low",
        "score": 1
    },
    "Asphalt Shingle and Coating Materials Manufacturing": {
        "name": "Asphalt Shingle and Coating Materials Manufacturing",
        "code": 324122,
        "risk": "Low",
        "score": 1
    },
    "Audio and Video Equipment Manufacturing": {
        "name": "Audio and Video Equipment Manufacturing",
        "code": 334310,
        "risk": "Low",
        "score": 1
    },
    "Automatic Environmental Control Manufacturing for Residential, Commercial, and Appliance Use": {
        "name": "Automatic Environmental Control Manufacturing for Residential, Commercial, and Appliance Use",
        "code": 334512,
        "risk": "Low",
        "score": 1
    },
    "Automobile Manufacturing": {
        "name": "Automobile Manufacturing",
        "code": 336111,
        "risk": "Medium",
        "score": 3
    },
    "Ball and Roller Bearing Manufacturing": {
        "name": "Ball and Roller Bearing Manufacturing",
        "code": 332991,
        "risk": "Low",
        "score": 1
    },
    "Bare Printed Circuit Board Manufacturing": {
        "name": "Bare Printed Circuit Board Manufacturing",
        "code": 334412,
        "risk": "Low",
        "score": 1
    },
    "Beet Sugar Manufacturing": {
        "name": "Beet Sugar Manufacturing",
        "code": 311313,
        "risk": "Low",
        "score": 1
    },
    "Biological Product (except Diagnostic) Manufacturing": {
        "name": "Biological Product (except Diagnostic) Manufacturing",
        "code": 325414,
        "risk": "Medium",
        "score": 3
    },
    "Blank Magnetic and Optical Recording Media Manufacturing": {
        "name": "Blank Magnetic and Optical Recording Media Manufacturing",
        "code": 334613,
        "risk": "Low",
        "score": 1
    },
    "Blind and Shade Manufacturing": {
        "name": "Blind and Shade Manufacturing",
        "code": 337920,
        "risk": "Low",
        "score": 1
    },
    "Boat Building": {
        "name": "Boat Building",
        "code": 336612,
        "risk": "Medium",
        "score": 3
    },
    "Bolt, Nut, Screw, Rivet, and Washer Manufacturing": {
        "name": "Bolt, Nut, Screw, Rivet, and Washer Manufacturing",
        "code": 332722,
        "risk": "Low",
        "score": 1
    },
    "Books Printing": {
        "name": "Books Printing",
        "code": 323117,
        "risk": "Low",
        "score": 1
    },
    "Bottled Water Manufacturing": {
        "name": "Bottled Water Manufacturing",
        "code": 312112,
        "risk": "Medium",
        "score": 3
    },
    "Breakfast Cereal Manufacturing": {
        "name": "Breakfast Cereal Manufacturing",
        "code": 311230,
        "risk": "Low",
        "score": 1
    },
    "Breweries": {
        "name": "Breweries",
        "code": 312120,
        "risk": "Medium",
        "score": 3
    },
    "Broadwoven Fabric Mills": {
        "name": "Broadwoven Fabric Mills",
        "code": 313210,
        "risk": "Low",
        "score": 1
    },
    "Broom, Brush, and Mop Manufacturing": {
        "name": "Broom, Brush, and Mop Manufacturing",
        "code": 339994,
        "risk": "Low",
        "score": 1
    },
    "Burial Casket Manufacturing": {
        "name": "Burial Casket Manufacturing",
        "code": 339995,
        "risk": "Low",
        "score": 1
    },
    "Cane Sugar Manufacturing": {
        "name": "Cane Sugar Manufacturing",
        "code": 311314,
        "risk": "Low",
        "score": 1
    },
    "Capacitor, Resistor, Coil, Transformer, and Other Inductor Manufacturing": {
        "name": "Capacitor, Resistor, Coil, Transformer, and Other Inductor Manufacturing",
        "code": 334416,
        "risk": "Low",
        "score": 1
    },
    "Carbon and Graphite Product Manufacturing": {
        "name": "Carbon and Graphite Product Manufacturing",
        "code": 335991,
        "risk": "Low",
        "score": 1
    },
    "Carpet and Rug Mills": {
        "name": "Carpet and Rug Mills",
        "code": 314110,
        "risk": "Low",
        "score": 1
    },
    "Cement Manufacturing": {
        "name": "Cement Manufacturing",
        "code": 327310,
        "risk": "Medium",
        "score": 3
    },
    "Cheese Manufacturing": {
        "name": "Cheese Manufacturing",
        "code": 311513,
        "risk": "Low",
        "score": 1
    },
    "Chocolate and Confectionery Manufacturing from Cacao Beans": {
        "name": "Chocolate and Confectionery Manufacturing from Cacao Beans",
        "code": 311351,
        "risk": "Low",
        "score": 1
    },
    "Clay Building Material and Refractories Manufacturing": {
        "name": "Clay Building Material and Refractories Manufacturing",
        "code": 327120,
        "risk": "Low",
        "score": 1
    },
    "Coffee and Tea Manufacturing": {
        "name": "Coffee and Tea Manufacturing",
        "code": 311920,
        "risk": "Low",
        "score": 1
    },
    "Commercial Bakeries": {
        "name": "Commercial Bakeries",
        "code": 311812,
        "risk": "Low",
        "score": 1
    },
    "Commercial Printing (except Screen and Books)": {
        "name": "Commercial Printing (except Screen and Books)",
        "code": 323111,
        "risk": "Low",
        "score": 1
    },
    "Commercial Screen Printing": {
        "name": "Commercial Screen Printing",
        "code": 323113,
        "risk": "Low",
        "score": 1
    },
    "Commercial, Industrial, and Institutional Electric Lighting Fixture Manufacturing": {
        "name": "Commercial, Industrial, and Institutional Electric Lighting Fixture Manufacturing",
        "code": 335122,
        "risk": "Low",
        "score": 1
    },
    "Computer Storage Device Manufacturing": {
        "name": "Computer Storage Device Manufacturing",
        "code": 334112,
        "risk": "Low",
        "score": 1
    },
    "Computer Terminal and Other Computer Peripheral Equipment Manufacturing": {
        "name": "Computer Terminal and Other Computer Peripheral Equipment Manufacturing",
        "code": 334118,
        "risk": "Low",
        "score": 1
    },
    "Concrete Block and Brick Manufacturing": {
        "name": "Concrete Block and Brick Manufacturing",
        "code": 327331,
        "risk": "Medium",
        "score": 3
    },
    "Concrete Pipe Manufacturing": {
        "name": "Concrete Pipe Manufacturing",
        "code": 327332,
        "risk": "Medium",
        "score": 3
    },
    "Confectionery Manufacturing from Purchased Chocolate": {
        "name": "Confectionery Manufacturing from Purchased Chocolate",
        "code": 311352,
        "risk": "Low",
        "score": 1
    },
    "Construction Machinery Manufacturing": {
        "name": "Construction Machinery Manufacturing",
        "code": 333120,
        "risk": "Low",
        "score": 1
    },
    "Conveyor and Conveying Equipment Manufacturing": {
        "name": "Conveyor and Conveying Equipment Manufacturing",
        "code": 333922,
        "risk": "Low",
        "score": 1
    },
    "Cookie and Cracker Manufacturing": {
        "name": "Cookie and Cracker Manufacturing",
        "code": 311821,
        "risk": "Low",
        "score": 1
    },
    "Copper Rolling, Drawing, Extruding, and Alloying": {
        "name": "Copper Rolling, Drawing, Extruding, and Alloying",
        "code": 331420,
        "risk": "Low",
        "score": 1
    },
    "Corrugated and Solid Fiber Box Manufacturing": {
        "name": "Corrugated and Solid Fiber Box Manufacturing",
        "code": 322211,
        "risk": "Low",
        "score": 1
    },
    "Creamery Butter Manufacturing": {
        "name": "Creamery Butter Manufacturing",
        "code": 311512,
        "risk": "Low",
        "score": 1
    },
    "Current-Carrying Wiring Device Manufacturing": {
        "name": "Current-Carrying Wiring Device Manufacturing",
        "code": 335931,
        "risk": "Low",
        "score": 1
    },
    "Curtain and Linen Mills": {
        "name": "Curtain and Linen Mills",
        "code": 314120,
        "risk": "Low",
        "score": 1
    },
    "Custom Architectural Woodwork and Millwork Manufacturing": {
        "name": "Custom Architectural Woodwork and Millwork Manufacturing",
        "code": 337212,
        "risk": "Low",
        "score": 1
    },
    "Custom Compounding of Purchased Resins": {
        "name": "Custom Compounding of Purchased Resins",
        "code": 325991,
        "risk": "Medium",
        "score": 3
    },
    "Custom Roll Forming": {
        "name": "Custom Roll Forming",
        "code": 332114,
        "risk": "Low",
        "score": 1
    },
    "Cut and Sew Apparel Contractors": {
        "name": "Cut and Sew Apparel Contractors",
        "code": 315210,
        "risk": "Medium",
        "score": 3
    },
    "Cut Stock, Resawing Lumber, and Planing": {
        "name": "Cut Stock, Resawing Lumber, and Planing",
        "code": 321912,
        "risk": "Medium",
        "score": 3
    },
    "Cut Stone and Cut Stone Product Manufacturing": {
        "name": "Cut Stone and Cut Stone Product Manufacturing",
        "code": 327991,
        "risk": "Low",
        "score": 1
    },
    "Cutting Tool and Machine Tool Accessory Manufacturing": {
        "name": "Cutting Tool and Machine Tool Accessory Manufacturing",
        "code": 333515,
        "risk": "Low",
        "score": 1
    },
    "Cyclic Crude, Intermediate, and Gum and Wood Chemical Manufacturing": {
        "name": "Cyclic Crude, Intermediate, and Gum and Wood Chemical Manufacturing",
        "code": 325194,
        "risk": "Low",
        "score": 1
    },
    "Dental Equipment and Supplies Manufacturing": {
        "name": "Dental Equipment and Supplies Manufacturing",
        "code": 339114,
        "risk": "Low",
        "score": 1
    },
    "Dental Laboratories": {
        "name": "Dental Laboratories",
        "code": 339116,
        "risk": "Low",
        "score": 1
    },
    "Distilleries": {
        "name": "Distilleries",
        "code": 312140,
        "risk": "Medium",
        "score": 3
    },
    "Dog and Cat Food Manufacturing": {
        "name": "Dog and Cat Food Manufacturing",
        "code": 311111,
        "risk": "Low",
        "score": 1
    },
    "Doll, Toy, and Game Manufacturing": {
        "name": "Doll, Toy, and Game Manufacturing",
        "code": 339930,
        "risk": "Low",
        "score": 1
    },
    "Dried and Dehydrated Food Manufacturing": {
        "name": "Dried and Dehydrated Food Manufacturing",
        "code": 311423,
        "risk": "Low",
        "score": 1
    },
    "Dry Pasta, Dough, and Flour Mixes Manufacturing from Purchased Flour": {
        "name": "Dry Pasta, Dough, and Flour Mixes Manufacturing from Purchased Flour",
        "code": 311824,
        "risk": "Low",
        "score": 1
    },
    "Dry, Condensed, and Evaporated Dairy Product Manufacturing": {
        "name": "Dry, Condensed, and Evaporated Dairy Product Manufacturing",
        "code": 311514,
        "risk": "Low",
        "score": 1
    },
    "Electric Lamp Bulb and Part Manufacturing": {
        "name": "Electric Lamp Bulb and Part Manufacturing",
        "code": 335110,
        "risk": "Low",
        "score": 1
    },
    "Electromedical and Electrotherapeutic Apparatus Manufacturing": {
        "name": "Electromedical and Electrotherapeutic Apparatus Manufacturing",
        "code": 334510,
        "risk": "Low",
        "score": 1
    },
    "Electronic Computer Manufacturing": {
        "name": "Electronic Computer Manufacturing",
        "code": 334111,
        "risk": "Low",
        "score": 1
    },
    "Electronic Connector Manufacturing": {
        "name": "Electronic Connector Manufacturing",
        "code": 334417,
        "risk": "Low",
        "score": 1
    },
    "Electroplating, Plating, Polishing, Anodizing, and Coloring": {
        "name": "Electroplating, Plating, Polishing, Anodizing, and Coloring",
        "code": 332813,
        "risk": "Low",
        "score": 1
    },
    "Elevator and Moving Stairway Manufacturing": {
        "name": "Elevator and Moving Stairway Manufacturing",
        "code": 333921,
        "risk": "Low",
        "score": 1
    },
    "Engineered Wood Member (except Truss) Manufacturing": {
        "name": "Engineered Wood Member (except Truss) Manufacturing",
        "code": 321213,
        "risk": "Medium",
        "score": 3
    },
    "Ethyl Alcohol Manufacturing": {
        "name": "Ethyl Alcohol Manufacturing",
        "code": 325193,
        "risk": "Low",
        "score": 1
    },
    "Explosives Manufacturing": {
        "name": "Explosives Manufacturing",
        "code": 325920,
        "risk": "High",
        "score": 5
    },
    "Fabric Coating Mills": {
        "name": "Fabric Coating Mills",
        "code": 313320,
        "risk": "Low",
        "score": 1
    },
    "Fabricated Pipe and Pipe Fitting Manufacturing": {
        "name": "Fabricated Pipe and Pipe Fitting Manufacturing",
        "code": 332996,
        "risk": "Low",
        "score": 1
    },
    "Fabricated Structural Metal Manufacturing": {
        "name": "Fabricated Structural Metal Manufacturing",
        "code": 332312,
        "risk": "Low",
        "score": 1
    },
    "Farm Machinery and Equipment Manufacturing": {
        "name": "Farm Machinery and Equipment Manufacturing",
        "code": 333111,
        "risk": "Low",
        "score": 1
    },
    "Fastener, Button, Needle, and Pin Manufacturing": {
        "name": "Fastener, Button, Needle, and Pin Manufacturing",
        "code": 339993,
        "risk": "Low",
        "score": 1
    },
    "Fats and Oils Refining and Blending": {
        "name": "Fats and Oils Refining and Blending",
        "code": 311225,
        "risk": "Low",
        "score": 1
    },
    "Fertilizer (Mixing Only) Manufacturing": {
        "name": "Fertilizer (Mixing Only) Manufacturing",
        "code": 325314,
        "risk": "Medium",
        "score": 3
    },
    "Fiber Optic Cable Manufacturing": {
        "name": "Fiber Optic Cable Manufacturing",
        "code": 335921,
        "risk": "Low",
        "score": 1
    },
    "Fiber, Yarn, and Thread Mills": {
        "name": "Fiber, Yarn, and Thread Mills",
        "code": 313110,
        "risk": "Low",
        "score": 1
    },
    "Flat Glass Manufacturing": {
        "name": "Flat Glass Manufacturing",
        "code": 327211,
        "risk": "Low",
        "score": 1
    },
    "Flavoring Syrup and Concentrate Manufacturing": {
        "name": "Flavoring Syrup and Concentrate Manufacturing",
        "code": 311930,
        "risk": "Low",
        "score": 1
    },
    "Flour Milling": {
        "name": "Flour Milling",
        "code": 311211,
        "risk": "Low",
        "score": 1
    },
    "Fluid Milk Manufacturing": {
        "name": "Fluid Milk Manufacturing",
        "code": 311511,
        "risk": "Low",
        "score": 1
    },
    "Fluid Power Cylinder and Actuator Manufacturing": {
        "name": "Fluid Power Cylinder and Actuator Manufacturing",
        "code": 333995,
        "risk": "Low",
        "score": 1
    },
    "Fluid Power Pump and Motor Manufacturing": {
        "name": "Fluid Power Pump and Motor Manufacturing",
        "code": 333996,
        "risk": "Low",
        "score": 1
    },
    "Fluid Power Valve and Hose Fitting Manufacturing": {
        "name": "Fluid Power Valve and Hose Fitting Manufacturing",
        "code": 332912,
        "risk": "Low",
        "score": 1
    },
    "Folding Paperboard Box Manufacturing": {
        "name": "Folding Paperboard Box Manufacturing",
        "code": 322212,
        "risk": "Low",
        "score": 1
    },
    "Food Product Machinery Manufacturing": {
        "name": "Food Product Machinery Manufacturing",
        "code": 333241,
        "risk": "Low",
        "score": 1
    },
    "Footwear Manufacturing": {
        "name": "Footwear Manufacturing",
        "code": 316210,
        "risk": "Medium",
        "score": 3
    },
    "Frozen Cakes, Pies, and Other Pastries Manufacturing": {
        "name": "Frozen Cakes, Pies, and Other Pastries Manufacturing",
        "code": 311813,
        "risk": "Low",
        "score": 1
    },
    "Frozen Fruit, Juice, and Vegetable Manufacturing": {
        "name": "Frozen Fruit, Juice, and Vegetable Manufacturing",
        "code": 311411,
        "risk": "Low",
        "score": 1
    },
    "Frozen Specialty Food Manufacturing": {
        "name": "Frozen Specialty Food Manufacturing",
        "code": 311412,
        "risk": "Low",
        "score": 1
    },
    "Fruit and Vegetable Canning": {
        "name": "Fruit and Vegetable Canning",
        "code": 311421,
        "risk": "Low",
        "score": 1
    },
    "Gasket, Packing, and Sealing Device Manufacturing": {
        "name": "Gasket, Packing, and Sealing Device Manufacturing",
        "code": 339991,
        "risk": "Low",
        "score": 1
    },
    "Glass Container Manufacturing": {
        "name": "Glass Container Manufacturing",
        "code": 327213,
        "risk": "Low",
        "score": 1
    },
    "Glass Product Manufacturing Made of Purchased Glass": {
        "name": "Glass Product Manufacturing Made of Purchased Glass",
        "code": 327215,
        "risk": "Low",
        "score": 1
    },
    "Ground or Treated Mineral and Earth Manufacturing": {
        "name": "Ground or Treated Mineral and Earth Manufacturing",
        "code": 327992,
        "risk": "Low",
        "score": 1
    },
    "Guided Missile and Space Vehicle Manufacturing": {
        "name": "Guided Missile and Space Vehicle Manufacturing",
        "code": 336414,
        "risk": "High",
        "score": 5
    },
    "Guided Missile and Space Vehicle Propulsion Unit and Propulsion Unit Parts Manufacturing": {
        "name": "Guided Missile and Space Vehicle Propulsion Unit and Propulsion Unit Parts Manufacturing",
        "code": 336415,
        "risk": "High",
        "score": 5
    },
    "Gypsum Product Manufacturing": {
        "name": "Gypsum Product Manufacturing",
        "code": 327420,
        "risk": "Medium",
        "score": 3
    },
    "Hardware Manufacturing": {
        "name": "Hardware Manufacturing",
        "code": 332510,
        "risk": "Low",
        "score": 1
    },
    "Hardwood Veneer and Plywood Manufacturing": {
        "name": "Hardwood Veneer and Plywood Manufacturing",
        "code": 321211,
        "risk": "Medium",
        "score": 3
    },
    "Heating Equipment (except Warm Air Furnaces) Manufacturing": {
        "name": "Heating Equipment (except Warm Air Furnaces) Manufacturing",
        "code": 333414,
        "risk": "Low",
        "score": 1
    },
    "Heavy Duty Truck Manufacturing": {
        "name": "Heavy Duty Truck Manufacturing",
        "code": 336120,
        "risk": "Medium",
        "score": 3
    },
    "Hosiery and Sock Mills": {
        "name": "Hosiery and Sock Mills",
        "code": 315110,
        "risk": "Low",
        "score": 1
    },
    "Household Cooking Appliance Manufacturing": {
        "name": "Household Cooking Appliance Manufacturing",
        "code": 335221,
        "risk": "Low",
        "score": 1
    },
    "Household Furniture (except Wood and Metal) Manufacturing": {
        "name": "Household Furniture (except Wood and Metal) Manufacturing",
        "code": 337125,
        "risk": "Low",
        "score": 1
    },
    "Household Laundry Equipment Manufacturing": {
        "name": "Household Laundry Equipment Manufacturing",
        "code": 335224,
        "risk": "Low",
        "score": 1
    },
    "Household Refrigerator and Home Freezer Manufacturing": {
        "name": "Household Refrigerator and Home Freezer Manufacturing",
        "code": 335222,
        "risk": "Low",
        "score": 1
    },
    "Ice Cream and Frozen Dessert Manufacturing": {
        "name": "Ice Cream and Frozen Dessert Manufacturing",
        "code": 311520,
        "risk": "Low",
        "score": 1
    },
    "Ice Manufacturing": {
        "name": "Ice Manufacturing",
        "code": 312113,
        "risk": "Medium",
        "score": 3
    },
    "Industrial and Commercial Fan and Blower and Air Purification Equipment Manufacturing": {
        "name": "Industrial and Commercial Fan and Blower and Air Purification Equipment Manufacturing",
        "code": 333413,
        "risk": "Low",
        "score": 1
    },
    "Industrial Gas Manufacturing": {
        "name": "Industrial Gas Manufacturing",
        "code": 325120,
        "risk": "Low",
        "score": 1
    },
    "Industrial Mold Manufacturing": {
        "name": "Industrial Mold Manufacturing",
        "code": 333511,
        "risk": "Low",
        "score": 1
    },
    "Industrial Process Furnace and Oven Manufacturing": {
        "name": "Industrial Process Furnace and Oven Manufacturing",
        "code": 333994,
        "risk": "Low",
        "score": 1
    },
    "Industrial Truck, Tractor, Trailer, and Stacker Machinery Manufacturing": {
        "name": "Industrial Truck, Tractor, Trailer, and Stacker Machinery Manufacturing",
        "code": 333924,
        "risk": "Low",
        "score": 1
    },
    "Industrial Valve Manufacturing": {
        "name": "Industrial Valve Manufacturing",
        "code": 332911,
        "risk": "Low",
        "score": 1
    },
    "Institutional Furniture Manufacturing": {
        "name": "Institutional Furniture Manufacturing",
        "code": 337127,
        "risk": "Low",
        "score": 1
    },
    "Instrument Manufacturing for Measuring and Testing Electricity and Electrical Signals": {
        "name": "Instrument Manufacturing for Measuring and Testing Electricity and Electrical Signals",
        "code": 334515,
        "risk": "Low",
        "score": 1
    },
    "Instruments and Related Products Manufacturing for Measuring, Displaying, and Controlling Industrial Process Variables": {
        "name": "Instruments and Related Products Manufacturing for Measuring, Displaying, and Controlling Industrial Process Variables",
        "code": 334513,
        "risk": "Low",
        "score": 1
    },
    "In-Vitro Diagnostic Substance Manufacturing": {
        "name": "In-Vitro Diagnostic Substance Manufacturing",
        "code": 325413,
        "risk": "Medium",
        "score": 3
    },
    "Iron and Steel Forging": {
        "name": "Iron and Steel Forging",
        "code": 332111,
        "risk": "Low",
        "score": 1
    },
    "Iron and Steel Mills and Ferroalloy Manufacturing": {
        "name": "Iron and Steel Mills and Ferroalloy Manufacturing",
        "code": 331110,
        "risk": "Low",
        "score": 1
    },
    "Iron and Steel Pipe and Tube Manufacturing from Purchased Steel": {
        "name": "Iron and Steel Pipe and Tube Manufacturing from Purchased Steel",
        "code": 331210,
        "risk": "Low",
        "score": 1
    },
    "Iron Foundries": {
        "name": "Iron Foundries",
        "code": 331511,
        "risk": "Low",
        "score": 1
    },
    "Irradiation Apparatus Manufacturing": {
        "name": "Irradiation Apparatus Manufacturing",
        "code": 334517,
        "risk": "Low",
        "score": 1
    },
    "Jewelry and Silverware Manufacturing": {
        "name": "Jewelry and Silverware Manufacturing",
        "code": 339910,
        "risk": "Medium",
        "score": 3
    },
    "Knit Fabric Mills": {
        "name": "Knit Fabric Mills",
        "code": 313240,
        "risk": "Low",
        "score": 1
    },
    "Laminated Plastics Plate, Sheet (except packaging), and Shape Manufacturing": {
        "name": "Laminated Plastics Plate, Sheet (except packaging), and Shape Manufacturing",
        "code": 326130,
        "risk": "Low",
        "score": 1
    },
    "Lawn and Garden Tractor and Home Lawn and Garden Equipment Manufacturing": {
        "name": "Lawn and Garden Tractor and Home Lawn and Garden Equipment Manufacturing",
        "code": 333112,
        "risk": "Low",
        "score": 1
    },
    "Leather and Hide Tanning and Finishing": {
        "name": "Leather and Hide Tanning and Finishing",
        "code": 316110,
        "risk": "Medium",
        "score": 3
    },
    "Light Truck and Utility Vehicle Manufacturing": {
        "name": "Light Truck and Utility Vehicle Manufacturing",
        "code": 336112,
        "risk": "Medium",
        "score": 3
    },
    "Lime Manufacturing": {
        "name": "Lime Manufacturing",
        "code": 327410,
        "risk": "Medium",
        "score": 3
    },
    "Machine Shops": {
        "name": "Machine Shops",
        "code": 332710,
        "risk": "Low",
        "score": 1
    },
    "Machine Tool Manufacturing": {
        "name": "Machine Tool Manufacturing",
        "code": 333517,
        "risk": "Low",
        "score": 1
    },
    "Malt Manufacturing": {
        "name": "Malt Manufacturing",
        "code": 311213,
        "risk": "Low",
        "score": 1
    },
    "Manufactured Home (Mobile Home) Manufacturing": {
        "name": "Manufactured Home (Mobile Home) Manufacturing",
        "code": 321991,
        "risk": "Medium",
        "score": 3
    },
    "Mattress Manufacturing": {
        "name": "Mattress Manufacturing",
        "code": 337910,
        "risk": "Low",
        "score": 1
    },
    "Mayonnaise, Dressing, and Other Prepared Sauce Manufacturing": {
        "name": "Mayonnaise, Dressing, and Other Prepared Sauce Manufacturing",
        "code": 311941,
        "risk": "Low",
        "score": 1
    },
    "Measuring and Dispensing Pump Manufacturing": {
        "name": "Measuring and Dispensing Pump Manufacturing",
        "code": 333913,
        "risk": "Low",
        "score": 1
    },
    "Meat Processed From Carcasses": {
        "name": "Meat Processed From Carcasses",
        "code": 311612,
        "risk": "Low",
        "score": 1
    },
    "Mechanical Power Transmission Equipment Manufacturing": {
        "name": "Mechanical Power Transmission Equipment Manufacturing",
        "code": 333613,
        "risk": "Medium",
        "score": 3
    },
    "Medicinal and Botanical Manufacturing": {
        "name": "Medicinal and Botanical Manufacturing",
        "code": 325411,
        "risk": "Medium",
        "score": 3
    },
    "Men's and Boys' Cut and Sew Apparel Manufacturing": {
        "name": "Men's and Boys' Cut and Sew Apparel Manufacturing",
        "code": 315220,
        "risk": "Medium",
        "score": 3
    },
    "Metal Can Manufacturing": {
        "name": "Metal Can Manufacturing",
        "code": 332431,
        "risk": "Low",
        "score": 1
    },
    "Metal Coating, Engraving (except Jewelry and Silverware), and Allied Services to Manufacturers": {
        "name": "Metal Coating, Engraving (except Jewelry and Silverware), and Allied Services to Manufacturers",
        "code": 332812,
        "risk": "Low",
        "score": 1
    },
    "Metal Crown, Closure, and Other Metal Stamping (except Automotive)": {
        "name": "Metal Crown, Closure, and Other Metal Stamping (except Automotive)",
        "code": 332119,
        "risk": "Low",
        "score": 1
    },
    "Metal Heat Treating": {
        "name": "Metal Heat Treating",
        "code": 332811,
        "risk": "Low",
        "score": 1
    },
    "Metal Household Furniture Manufacturing": {
        "name": "Metal Household Furniture Manufacturing",
        "code": 337124,
        "risk": "Low",
        "score": 1
    },
    "Metal Kitchen Cookware, Utensil, Cutlery, and Flatware (except Precious) Manufacturing": {
        "name": "Metal Kitchen Cookware, Utensil, Cutlery, and Flatware (except Precious) Manufacturing",
        "code": 332215,
        "risk": "Low",
        "score": 1
    },
    "Metal Tank (Heavy Gauge) Manufacturing": {
        "name": "Metal Tank (Heavy Gauge) Manufacturing",
        "code": 332420,
        "risk": "Low",
        "score": 1
    },
    "Metal Window and Door Manufacturing": {
        "name": "Metal Window and Door Manufacturing",
        "code": 332321,
        "risk": "Low",
        "score": 1
    },
    "Military Armored Vehicle, Tank, and Tank Component Manufacturing": {
        "name": "Military Armored Vehicle, Tank, and Tank Component Manufacturing",
        "code": 336992,
        "risk": "Medium",
        "score": 3
    },
    "Mineral Wool Manufacturing": {
        "name": "Mineral Wool Manufacturing",
        "code": 327993,
        "risk": "Low",
        "score": 1
    },
    "Mining Machinery and Equipment Manufacturing": {
        "name": "Mining Machinery and Equipment Manufacturing",
        "code": 333131,
        "risk": "Low",
        "score": 1
    },
    "Motor and Generator Manufacturing": {
        "name": "Motor and Generator Manufacturing",
        "code": 335312,
        "risk": "Low",
        "score": 1
    },
    "Motor Home Manufacturing": {
        "name": "Motor Home Manufacturing",
        "code": 336213,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Body Manufacturing": {
        "name": "Motor Vehicle Body Manufacturing",
        "code": 336211,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Brake System Manufacturing": {
        "name": "Motor Vehicle Brake System Manufacturing",
        "code": 336340,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Electrical and Electronic Equipment Manufacturing": {
        "name": "Motor Vehicle Electrical and Electronic Equipment Manufacturing",
        "code": 336320,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Gasoline Engine and Engine Parts Manufacturing": {
        "name": "Motor Vehicle Gasoline Engine and Engine Parts Manufacturing",
        "code": 336310,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Metal Stamping": {
        "name": "Motor Vehicle Metal Stamping",
        "code": 336370,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Seating and Interior Trim Manufacturing": {
        "name": "Motor Vehicle Seating and Interior Trim Manufacturing",
        "code": 336360,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Steering and Suspension Components (except Spring) Manufacturing": {
        "name": "Motor Vehicle Steering and Suspension Components (except Spring) Manufacturing",
        "code": 336330,
        "risk": "Medium",
        "score": 3
    },
    "Motor Vehicle Transmission and Power Train Parts Manufacturing": {
        "name": "Motor Vehicle Transmission and Power Train Parts Manufacturing",
        "code": 336350,
        "risk": "Medium",
        "score": 3
    },
    "Motorcycle, Bicycle, and Parts Manufacturing": {
        "name": "Motorcycle, Bicycle, and Parts Manufacturing",
        "code": 336991,
        "risk": "Medium",
        "score": 3
    },
    "Musical Instrument Manufacturing": {
        "name": "Musical Instrument Manufacturing",
        "code": 339992,
        "risk": "Low",
        "score": 1
    },
    "Narrow Fabric Mills and Schiffli Machine Embroidery": {
        "name": "Narrow Fabric Mills and Schiffli Machine Embroidery",
        "code": 313220,
        "risk": "Low",
        "score": 1
    },
    "Newsprint Mills": {
        "name": "Newsprint Mills",
        "code": 322122,
        "risk": "Low",
        "score": 1
    },
    "Nitrogenous Fertilizer Manufacturing": {
        "name": "Nitrogenous Fertilizer Manufacturing",
        "code": 325311,
        "risk": "Medium",
        "score": 3
    },
    "Nonchocolate Confectionery Manufacturing": {
        "name": "Nonchocolate Confectionery Manufacturing",
        "code": 311340,
        "risk": "Low",
        "score": 1
    },
    "Noncurrent-Carrying Wiring Device Manufacturing": {
        "name": "Noncurrent-Carrying Wiring Device Manufacturing",
        "code": 335932,
        "risk": "Low",
        "score": 1
    },
    "Nonferrous Forging": {
        "name": "Nonferrous Forging",
        "code": 332112,
        "risk": "Low",
        "score": 1
    },
    "Nonferrous Metal (except Aluminum) Smelting and Refining": {
        "name": "Nonferrous Metal (except Aluminum) Smelting and Refining",
        "code": 331410,
        "risk": "Low",
        "score": 1
    },
    "Nonferrous Metal (except Copper and Aluminum) Rolling, Drawing, and Extruding": {
        "name": "Nonferrous Metal (except Copper and Aluminum) Rolling, Drawing, and Extruding",
        "code": 331491,
        "risk": "Low",
        "score": 1
    },
    "Nonferrous Metal Die-Casting Foundries": {
        "name": "Nonferrous Metal Die-Casting Foundries",
        "code": 331523,
        "risk": "Low",
        "score": 1
    },
    "Nonupholstered Wood Household Furniture Manufacturing": {
        "name": "Nonupholstered Wood Household Furniture Manufacturing",
        "code": 337122,
        "risk": "Low",
        "score": 1
    },
    "Nonwoven Fabric Mills": {
        "name": "Nonwoven Fabric Mills",
        "code": 313230,
        "risk": "Low",
        "score": 1
    },
    "Office Furniture (except Wood) Manufacturing": {
        "name": "Office Furniture (except Wood) Manufacturing",
        "code": 337214,
        "risk": "Low",
        "score": 1
    },
    "Office Supplies (except Paper) Manufacturing": {
        "name": "Office Supplies (except Paper) Manufacturing",
        "code": 339940,
        "risk": "Low",
        "score": 1
    },
    "Oil and Gas Field Machinery and Equipment Manufacturing": {
        "name": "Oil and Gas Field Machinery and Equipment Manufacturing",
        "code": 333132,
        "risk": "Low",
        "score": 1
    },
    "Ophthalmic Goods Manufacturing": {
        "name": "Ophthalmic Goods Manufacturing",
        "code": 339115,
        "risk": "Low",
        "score": 1
    },
    "Optical Instrument and Lens Manufacturing": {
        "name": "Optical Instrument and Lens Manufacturing",
        "code": 333314,
        "risk": "Low",
        "score": 1
    },
    "Ornamental and Architectural Metal Work Manufacturing": {
        "name": "Ornamental and Architectural Metal Work Manufacturing",
        "code": 332323,
        "risk": "Low",
        "score": 1
    },
    "Other Aircraft Part and Auxiliary Equipment Manufacturing": {
        "name": "Other Aircraft Part and Auxiliary Equipment Manufacturing",
        "code": 336413,
        "risk": "Low",
        "score": 1
    },
    "Other Aluminum Rolling, Drawing, and Extruding": {
        "name": "Other Aluminum Rolling, Drawing, and Extruding",
        "code": 331318,
        "risk": "Low",
        "score": 1
    },
    "Other Animal Food Manufacturing": {
        "name": "Other Animal Food Manufacturing",
        "code": 311119,
        "risk": "Low",
        "score": 1
    },
    "Other Apparel Knitting Mills": {
        "name": "Other Apparel Knitting Mills",
        "code": 315190,
        "risk": "Low",
        "score": 1
    },
    "Other Basic Inorganic Chemical Manufacturing": {
        "name": "Other Basic Inorganic Chemical Manufacturing",
        "code": 325180,
        "risk": "Low",
        "score": 1
    },
    "Other Commercial and Service Industry Machinery Manufacturing": {
        "name": "Other Commercial and Service Industry Machinery Manufacturing",
        "code": 333318,
        "risk": "Low",
        "score": 1
    },
    "Other Communication and Energy Wire Manufacturing": {
        "name": "Other Communication and Energy Wire Manufacturing",
        "code": 335929,
        "risk": "Low",
        "score": 1
    },
    "Other Communications Equipment Manufacturing": {
        "name": "Other Communications Equipment Manufacturing",
        "code": 334290,
        "risk": "Low",
        "score": 1
    },
    "Other Concrete Product Manufacturing": {
        "name": "Other Concrete Product Manufacturing",
        "code": 327390,
        "risk": "Medium",
        "score": 3
    },
    "Other Cut and Sew Apparel Manufacturing": {
        "name": "Other Cut and Sew Apparel Manufacturing",
        "code": 315280,
        "risk": "Medium",
        "score": 3
    },
    "Other Electronic Component Manufacturing": {
        "name": "Other Electronic Component Manufacturing",
        "code": 334419,
        "risk": "Low",
        "score": 1
    },
    "Other Engine Equipment Manufacturing": {
        "name": "Other Engine Equipment Manufacturing",
        "code": 333618,
        "risk": "Medium",
        "score": 3
    },
    "Other Fabricated Wire Product Manufacturing": {
        "name": "Other Fabricated Wire Product Manufacturing",
        "code": 332618,
        "risk": "Low",
        "score": 1
    },
    "Other Guided Missile and Space Vehicle Parts and Auxiliary Equipment Manufacturing": {
        "name": "Other Guided Missile and Space Vehicle Parts and Auxiliary Equipment Manufacturing",
        "code": 336419,
        "risk": "High",
        "score": 5
    },
    "Other Industrial Machinery Manufacturing": {
        "name": "Other Industrial Machinery Manufacturing",
        "code": 333249,
        "risk": "Low",
        "score": 1
    },
    "Other Lighting Equipment Manufacturing": {
        "name": "Other Lighting Equipment Manufacturing",
        "code": 335129,
        "risk": "Low",
        "score": 1
    },
    "Other Major Household Appliance Manufacturing": {
        "name": "Other Major Household Appliance Manufacturing",
        "code": 335228,
        "risk": "Low",
        "score": 1
    },
    "Other Measuring and Controlling Device Manufacturing": {
        "name": "Other Measuring and Controlling Device Manufacturing",
        "code": 334519,
        "risk": "Low",
        "score": 1
    },
    "Other Metal Container Manufacturing": {
        "name": "Other Metal Container Manufacturing",
        "code": 332439,
        "risk": "Low",
        "score": 1
    },
    "Other Metal Valve and Pipe Fitting Manufacturing": {
        "name": "Other Metal Valve and Pipe Fitting Manufacturing",
        "code": 332919,
        "risk": "Low",
        "score": 1
    },
    "Other Millwork (including Flooring)": {
        "name": "Other Millwork (including Flooring)",
        "code": 321918,
        "risk": "Medium",
        "score": 3
    },
    "Other Motor Vehicle Parts Manufacturing": {
        "name": "Other Motor Vehicle Parts Manufacturing",
        "code": 336390,
        "risk": "Medium",
        "score": 3
    },
    "Other Nonferrous Metal Foundries (except Die-Casting)": {
        "name": "Other Nonferrous Metal Foundries (except Die-Casting)",
        "code": 331529,
        "risk": "Low",
        "score": 1
    },
    "Other Paperboard Container Manufacturing": {
        "name": "Other Paperboard Container Manufacturing",
        "code": 322219,
        "risk": "Low",
        "score": 1
    },
    "Other Pressed and Blown Glass and Glassware Manufacturing": {
        "name": "Other Pressed and Blown Glass and Glassware Manufacturing",
        "code": 327212,
        "risk": "Low",
        "score": 1
    },
    "Other Snack Food Manufacturing": {
        "name": "Other Snack Food Manufacturing",
        "code": 311919,
        "risk": "Low",
        "score": 1
    },
    "Overhead Traveling Crane, Hoist, and Monorail System Manufacturing": {
        "name": "Overhead Traveling Crane, Hoist, and Monorail System Manufacturing",
        "code": 333923,
        "risk": "Low",
        "score": 1
    },
    "Packaging Machinery Manufacturing": {
        "name": "Packaging Machinery Manufacturing",
        "code": 333993,
        "risk": "Low",
        "score": 1
    },
    "Paint and Coating Manufacturing": {
        "name": "Paint and Coating Manufacturing",
        "code": 325510,
        "risk": "Low",
        "score": 1
    },
    "Paper (except Newsprint) Mills": {
        "name": "Paper (except Newsprint) Mills",
        "code": 322121,
        "risk": "Low",
        "score": 1
    },
    "Paper Bag and Coated and Treated Paper Manufacturing": {
        "name": "Paper Bag and Coated and Treated Paper Manufacturing",
        "code": 322220,
        "risk": "Low",
        "score": 1
    },
    "Paperboard Mills": {
        "name": "Paperboard Mills",
        "code": 322130,
        "risk": "Low",
        "score": 1
    },
    "Perishable Prepared Food Manufacturing": {
        "name": "Perishable Prepared Food Manufacturing",
        "code": 311991,
        "risk": "Low",
        "score": 1
    },
    "Pesticide and Other Agricultural Chemical Manufacturing": {
        "name": "Pesticide and Other Agricultural Chemical Manufacturing",
        "code": 325320,
        "risk": "Medium",
        "score": 3
    },
    "Petrochemical Manufacturing": {
        "name": "Petrochemical Manufacturing",
        "code": 325110,
        "risk": "Low",
        "score": 1
    },
    "Petroleum Lubricating Oil and Grease Manufacturing": {
        "name": "Petroleum Lubricating Oil and Grease Manufacturing",
        "code": 324191,
        "risk": "Low",
        "score": 1
    },
    "Petroleum Refineries": {
        "name": "Petroleum Refineries",
        "code": 324110,
        "risk": "Low",
        "score": 1
    },
    "Pharmaceutical Preparation Manufacturing": {
        "name": "Pharmaceutical Preparation Manufacturing",
        "code": 325412,
        "risk": "Medium",
        "score": 3
    },
    "Phosphatic Fertilizer Manufacturing": {
        "name": "Phosphatic Fertilizer Manufacturing",
        "code": 325312,
        "risk": "Medium",
        "score": 3
    },
    "Photographic and Photocopying Equipment Manufacturing": {
        "name": "Photographic and Photocopying Equipment Manufacturing",
        "code": 333316,
        "risk": "Low",
        "score": 1
    },
    "Photographic Film, Paper, Plate, and Chemical Manufacturing": {
        "name": "Photographic Film, Paper, Plate, and Chemical Manufacturing",
        "code": 325992,
        "risk": "Medium",
        "score": 3
    },
    "Plastics Bag and Pouch Manufacturing": {
        "name": "Plastics Bag and Pouch Manufacturing",
        "code": 326111,
        "risk": "Low",
        "score": 1
    },
    "Plastics Bottle Manufacturing": {
        "name": "Plastics Bottle Manufacturing",
        "code": 326160,
        "risk": "Low",
        "score": 1
    },
    "Plastics Material and Resin Manufacturing": {
        "name": "Plastics Material and Resin Manufacturing",
        "code": 325211,
        "risk": "Low",
        "score": 1
    },
    "Plastics Packaging Film and Sheet (including Laminated) Manufacturing": {
        "name": "Plastics Packaging Film and Sheet (including Laminated) Manufacturing",
        "code": 326112,
        "risk": "Low",
        "score": 1
    },
    "Plastics Pipe and Pipe Fitting Manufacturing": {
        "name": "Plastics Pipe and Pipe Fitting Manufacturing",
        "code": 326122,
        "risk": "Low",
        "score": 1
    },
    "Plastics Plumbing Fixture Manufacturing": {
        "name": "Plastics Plumbing Fixture Manufacturing",
        "code": 326191,
        "risk": "Low",
        "score": 1
    },
    "Plate Work Manufacturing": {
        "name": "Plate Work Manufacturing",
        "code": 332313,
        "risk": "Low",
        "score": 1
    },
    "Plumbing Fixture Fitting and Trim Manufacturing": {
        "name": "Plumbing Fixture Fitting and Trim Manufacturing",
        "code": 332913,
        "risk": "Low",
        "score": 1
    },
    "Polish and Other Sanitation Good Manufacturing": {
        "name": "Polish and Other Sanitation Good Manufacturing",
        "code": 325612,
        "risk": "Low",
        "score": 1
    },
    "Polystyrene Foam Product Manufacturing": {
        "name": "Polystyrene Foam Product Manufacturing",
        "code": 326140,
        "risk": "Low",
        "score": 1
    },
    "Pottery, Ceramics, and Plumbing Fixture Manufacturing": {
        "name": "Pottery, Ceramics, and Plumbing Fixture Manufacturing",
        "code": 327110,
        "risk": "Low",
        "score": 1
    },
    "Poultry Processing": {
        "name": "Poultry Processing",
        "code": 311615,
        "risk": "Low",
        "score": 1
    },
    "Powder Metallurgy Part Manufacturing": {
        "name": "Powder Metallurgy Part Manufacturing",
        "code": 332117,
        "risk": "Low",
        "score": 1
    },
    "Power Boiler and Heat Exchanger Manufacturing": {
        "name": "Power Boiler and Heat Exchanger Manufacturing",
        "code": 332410,
        "risk": "Low",
        "score": 1
    },
    "Power, Distribution, and Specialty Transformer Manufacturing": {
        "name": "Power, Distribution, and Specialty Transformer Manufacturing",
        "code": 335311,
        "risk": "Low",
        "score": 1
    },
    "Power-Driven Handtool Manufacturing": {
        "name": "Power-Driven Handtool Manufacturing",
        "code": 333991,
        "risk": "Low",
        "score": 1
    },
    "Precision Turned Product Manufacturing": {
        "name": "Precision Turned Product Manufacturing",
        "code": 332721,
        "risk": "Low",
        "score": 1
    },
    "Prefabricated Metal Building and Component Manufacturing": {
        "name": "Prefabricated Metal Building and Component Manufacturing",
        "code": 332311,
        "risk": "Low",
        "score": 1
    },
    "Prefabricated Wood Building Manufacturing": {
        "name": "Prefabricated Wood Building Manufacturing",
        "code": 321992,
        "risk": "Medium",
        "score": 3
    },
    "Primary Battery Manufacturing": {
        "name": "Primary Battery Manufacturing",
        "code": 335912,
        "risk": "Low",
        "score": 1
    },
    "Printed Circuit Assembly (Electronic Assembly) Manufacturing": {
        "name": "Printed Circuit Assembly (Electronic Assembly) Manufacturing",
        "code": 334418,
        "risk": "Low",
        "score": 1
    },
    "Printing Ink Manufacturing": {
        "name": "Printing Ink Manufacturing",
        "code": 325910,
        "risk": "Medium",
        "score": 3
    },
    "Printing Machinery and Equipment Manufacturing": {
        "name": "Printing Machinery and Equipment Manufacturing",
        "code": 333244,
        "risk": "Low",
        "score": 1
    },
    "Pulp Mills": {
        "name": "Pulp Mills",
        "code": 322110,
        "risk": "Low",
        "score": 1
    },
    "Pump and Pumping Equipment Manufacturing": {
        "name": "Pump and Pumping Equipment Manufacturing",
        "code": 333911,
        "risk": "Low",
        "score": 1
    },
    "Radio and Television Broadcasting and Wireless Communications Equipment Manufacturing": {
        "name": "Radio and Television Broadcasting and Wireless Communications Equipment Manufacturing",
        "code": 334220,
        "risk": "Low",
        "score": 1
    },
    "Railroad Rolling Stock Manufacturing": {
        "name": "Railroad Rolling Stock Manufacturing",
        "code": 336510,
        "risk": "Low",
        "score": 1
    },
    "Ready-Mix Concrete Manufacturing": {
        "name": "Ready-Mix Concrete Manufacturing",
        "code": 327320,
        "risk": "Medium",
        "score": 3
    },
    "Reconstituted Wood Product Manufacturing": {
        "name": "Reconstituted Wood Product Manufacturing",
        "code": 321219,
        "risk": "Medium",
        "score": 3
    },
    "Relay and Industrial Control Manufacturing": {
        "name": "Relay and Industrial Control Manufacturing",
        "code": 335314,
        "risk": "Low",
        "score": 1
    },
    "Rendering and Meat Byproduct Processing": {
        "name": "Rendering and Meat Byproduct Processing",
        "code": 311613,
        "risk": "Low",
        "score": 1
    },
    "Residential Electric Lighting Fixture Manufacturing": {
        "name": "Residential Electric Lighting Fixture Manufacturing",
        "code": 335121,
        "risk": "Low",
        "score": 1
    },
    "Retail Bakeries": {
        "name": "Retail Bakeries",
        "code": 311811,
        "risk": "Low",
        "score": 1
    },
    "Rice Milling": {
        "name": "Rice Milling",
        "code": 311212,
        "risk": "Low",
        "score": 1
    },
    "Roasted Nuts and Peanut Butter Manufacturing": {
        "name": "Roasted Nuts and Peanut Butter Manufacturing",
        "code": 311911,
        "risk": "Low",
        "score": 1
    },
    "Rolled Steel Shape Manufacturing": {
        "name": "Rolled Steel Shape Manufacturing",
        "code": 331221,
        "risk": "Low",
        "score": 1
    },
    "Rolling Mill and Other Metalworking Machinery Manufacturing": {
        "name": "Rolling Mill and Other Metalworking Machinery Manufacturing",
        "code": 333519,
        "risk": "Low",
        "score": 1
    },
    "Rope, Cordage, Twine, Tire Cord, and Tire Fabric Mills": {
        "name": "Rope, Cordage, Twine, Tire Cord, and Tire Fabric Mills",
        "code": 314994,
        "risk": "Low",
        "score": 1
    },
    "Rubber and Plastics Hose and Belting Manufacturing": {
        "name": "Rubber and Plastics Hose and Belting Manufacturing",
        "code": 326220,
        "risk": "Low",
        "score": 1
    },
    "Rubber Product Manufacturing for Mechanical Use": {
        "name": "Rubber Product Manufacturing for Mechanical Use",
        "code": 326291,
        "risk": "Low",
        "score": 1
    },
    "Sanitary Paper Product Manufacturing": {
        "name": "Sanitary Paper Product Manufacturing",
        "code": 322291,
        "risk": "Low",
        "score": 1
    },
    "Saw Blade and Handtool Manufacturing": {
        "name": "Saw Blade and Handtool Manufacturing",
        "code": 332216,
        "risk": "Low",
        "score": 1
    },
    "Sawmill, Woodworking, and Paper Machinery Manufacturing": {
        "name": "Sawmill, Woodworking, and Paper Machinery Manufacturing",
        "code": 333243,
        "risk": "Low",
        "score": 1
    },
    "Sawmills": {
        "name": "Sawmills",
        "code": 321113,
        "risk": "Medium",
        "score": 3
    },
    "Scale and Balance Manufacturing": {
        "name": "Scale and Balance Manufacturing",
        "code": 333997,
        "risk": "Low",
        "score": 1
    },
    "Seafood Product Preparation and Packaging": {
        "name": "Seafood Product Preparation and Packaging",
        "code": 311710,
        "risk": "Low",
        "score": 1
    },
    "Search, Detection, Navigation, Guidance, Aeronautical, and Nautical System and Instrument Manufacturing": {
        "name": "Search, Detection, Navigation, Guidance, Aeronautical, and Nautical System and Instrument Manufacturing",
        "code": 334511,
        "risk": "Low",
        "score": 1
    },
    "Secondary Smelting and Alloying of Aluminum": {
        "name": "Secondary Smelting and Alloying of Aluminum",
        "code": 331314,
        "risk": "Low",
        "score": 1
    },
    "Secondary Smelting, Refining, and Alloying of Nonferrous Metal (except Copper and Aluminum)": {
        "name": "Secondary Smelting, Refining, and Alloying of Nonferrous Metal (except Copper and Aluminum)",
        "code": 331492,
        "risk": "Low",
        "score": 1
    },
    "Semiconductor and Related Device Manufacturing": {
        "name": "Semiconductor and Related Device Manufacturing",
        "code": 334413,
        "risk": "Low",
        "score": 1
    },
    "Semiconductor Machinery Manufacturing": {
        "name": "Semiconductor Machinery Manufacturing",
        "code": 333242,
        "risk": "Low",
        "score": 1
    },
    "Sheet Metal Work Manufacturing": {
        "name": "Sheet Metal Work Manufacturing",
        "code": 332322,
        "risk": "Low",
        "score": 1
    },
    "Ship Building and Repairing": {
        "name": "Ship Building and Repairing",
        "code": 336611,
        "risk": "Medium",
        "score": 3
    },
    "Showcase, Partition, Shelving, and Locker Manufacturing": {
        "name": "Showcase, Partition, Shelving, and Locker Manufacturing",
        "code": 337215,
        "risk": "Low",
        "score": 1
    },
    "Sign Manufacturing": {
        "name": "Sign Manufacturing",
        "code": 339950,
        "risk": "Low",
        "score": 1
    },
    "Small Arms Ammunition Manufacturing": {
        "name": "Small Arms Ammunition Manufacturing",
        "code": 332992,
        "risk": "Medium",
        "score": 3
    },
    "Small Arms, Ordnance, and Ordnance Accessories Manufacturing": {
        "name": "Small Arms, Ordnance, and Ordnance Accessories Manufacturing",
        "code": 332994,
        "risk": "Medium",
        "score": 3
    },
    "Small Electrical Appliance Manufacturing": {
        "name": "Small Electrical Appliance Manufacturing",
        "code": 335210,
        "risk": "Low",
        "score": 1
    },
    "Soap and Other Detergent Manufacturing": {
        "name": "Soap and Other Detergent Manufacturing",
        "code": 325611,
        "risk": "Low",
        "score": 1
    },
    "Soft Drink Manufacturing": {
        "name": "Soft Drink Manufacturing",
        "code": 312111,
        "risk": "Medium",
        "score": 3
    },
    "Software and Other Prerecorded Compact Disc, Tape, and Record Reproducing": {
        "name": "Software and Other Prerecorded Compact Disc, Tape, and Record Reproducing",
        "code": 334614,
        "risk": "Medium",
        "score": 3
    },
    "Softwood Veneer and Plywood Manufacturing": {
        "name": "Softwood Veneer and Plywood Manufacturing",
        "code": 321212,
        "risk": "Medium",
        "score": 3
    },
    "Soybean and Other Oilseed Processing": {
        "name": "Soybean and Other Oilseed Processing",
        "code": 311224,
        "risk": "Low",
        "score": 1
    },
    "Special Die and Tool, Die Set, Jig, and Fixture Manufacturing": {
        "name": "Special Die and Tool, Die Set, Jig, and Fixture Manufacturing",
        "code": 333514,
        "risk": "Low",
        "score": 1
    },
    "Specialty Canning": {
        "name": "Specialty Canning",
        "code": 311422,
        "risk": "Low",
        "score": 1
    },
    "Speed Changer, Industrial High-Speed Drive, and Gear Manufacturing": {
        "name": "Speed Changer, Industrial High-Speed Drive, and Gear Manufacturing",
        "code": 333612,
        "risk": "Medium",
        "score": 3
    },
    "Spice and Extract Manufacturing": {
        "name": "Spice and Extract Manufacturing",
        "code": 311942,
        "risk": "Low",
        "score": 1
    },
    "Sporting and Athletic Goods Manufacturing": {
        "name": "Sporting and Athletic Goods Manufacturing",
        "code": 339920,
        "risk": "Low",
        "score": 1
    },
    "Spring Manufacturing": {
        "name": "Spring Manufacturing",
        "code": 332613,
        "risk": "Low",
        "score": 1
    },
    "Stationery Product Manufacturing": {
        "name": "Stationery Product Manufacturing",
        "code": 322230,
        "risk": "Low",
        "score": 1
    },
    "Steel Foundries (except Investment)": {
        "name": "Steel Foundries (except Investment)",
        "code": 331513,
        "risk": "Low",
        "score": 1
    },
    "Steel Investment Foundries": {
        "name": "Steel Investment Foundries",
        "code": 331512,
        "risk": "Low",
        "score": 1
    },
    "Steel Wire Drawing": {
        "name": "Steel Wire Drawing",
        "code": 331222,
        "risk": "Low",
        "score": 1
    },
    "Storage Battery Manufacturing": {
        "name": "Storage Battery Manufacturing",
        "code": 335911,
        "risk": "Low",
        "score": 1
    },
    "Support Activities for Printing": {
        "name": "Support Activities for Printing",
        "code": 323120,
        "risk": "Low",
        "score": 1
    },
    "Surface Active Agent Manufacturing": {
        "name": "Surface Active Agent Manufacturing",
        "code": 325613,
        "risk": "Low",
        "score": 1
    },
    "Surgical and Medical Instrument Manufacturing": {
        "name": "Surgical and Medical Instrument Manufacturing",
        "code": 339112,
        "risk": "Low",
        "score": 1
    },
    "Surgical Appliance and Supplies Manufacturing": {
        "name": "Surgical Appliance and Supplies Manufacturing",
        "code": 339113,
        "risk": "Low",
        "score": 1
    },
    "Switchgear and Switchboard Apparatus Manufacturing": {
        "name": "Switchgear and Switchboard Apparatus Manufacturing",
        "code": 335313,
        "risk": "Low",
        "score": 1
    },
    "Synthetic Dye and Pigment Manufacturing": {
        "name": "Synthetic Dye and Pigment Manufacturing",
        "code": 325130,
        "risk": "Low",
        "score": 1
    },
    "Synthetic Rubber Manufacturing": {
        "name": "Synthetic Rubber Manufacturing",
        "code": 325212,
        "risk": "Low",
        "score": 1
    },
    "Telephone Apparatus Manufacturing": {
        "name": "Telephone Apparatus Manufacturing",
        "code": 334210,
        "risk": "Low",
        "score": 1
    },
    "Textile and Fabric Finishing Mills": {
        "name": "Textile and Fabric Finishing Mills",
        "code": 313310,
        "risk": "Low",
        "score": 1
    },
    "Textile Bag and Canvas Mills": {
        "name": "Textile Bag and Canvas Mills",
        "code": 314910,
        "risk": "Low",
        "score": 1
    },
    "Tire Manufacturing (except Retreading)": {
        "name": "Tire Manufacturing (except Retreading)",
        "code": 326211,
        "risk": "Low",
        "score": 1
    },
    "Tire Retreading": {
        "name": "Tire Retreading",
        "code": 326212,
        "risk": "Medium",
        "score": 3
    },
    "Tobacco Manufacturing": {
        "name": "Tobacco Manufacturing",
        "code": 312230,
        "risk": "Medium",
        "score": 3
    },
    "Toilet Preparation Manufacturing": {
        "name": "Toilet Preparation Manufacturing",
        "code": 325620,
        "risk": "Low",
        "score": 1
    },
    "Tortilla Manufacturing": {
        "name": "Tortilla Manufacturing",
        "code": 311830,
        "risk": "Low",
        "score": 1
    },
    "Totalizing Fluid Meter and Counting Device Manufacturing": {
        "name": "Totalizing Fluid Meter and Counting Device Manufacturing",
        "code": 334514,
        "risk": "Low",
        "score": 1
    },
    "Travel Trailer and Camper Manufacturing": {
        "name": "Travel Trailer and Camper Manufacturing",
        "code": 336214,
        "risk": "Medium",
        "score": 3
    },
    "Truck Trailer Manufacturing": {
        "name": "Truck Trailer Manufacturing",
        "code": 336212,
        "risk": "Medium",
        "score": 3
    },
    "Truss Manufacturing": {
        "name": "Truss Manufacturing",
        "code": 321214,
        "risk": "Medium",
        "score": 3
    },
    "Turbine and Turbine Generator Set Units Manufacturing": {
        "name": "Turbine and Turbine Generator Set Units Manufacturing",
        "code": 333611,
        "risk": "Medium",
        "score": 3
    },
    "Unlaminated Plastics Film and Sheet (except Packaging) Manufacturing": {
        "name": "Unlaminated Plastics Film and Sheet (except Packaging) Manufacturing",
        "code": 326113,
        "risk": "Low",
        "score": 1
    },
    "Unlaminated Plastics Profile Shape Manufacturing": {
        "name": "Unlaminated Plastics Profile Shape Manufacturing",
        "code": 326121,
        "risk": "Low",
        "score": 1
    },
    "Upholstered Household Furniture Manufacturing": {
        "name": "Upholstered Household Furniture Manufacturing",
        "code": 337121,
        "risk": "Low",
        "score": 1
    },
    "Urethane and Other Foam Product (except Polystyrene) Manufacturing": {
        "name": "Urethane and Other Foam Product (except Polystyrene) Manufacturing",
        "code": 326150,
        "risk": "Low",
        "score": 1
    },
    "Welding and Soldering Equipment Manufacturing": {
        "name": "Welding and Soldering Equipment Manufacturing",
        "code": 333992,
        "risk": "Low",
        "score": 1
    },
    "Wet Corn Milling": {
        "name": "Wet Corn Milling",
        "code": 311221,
        "risk": "Low",
        "score": 1
    },
    "Wineries": {
        "name": "Wineries",
        "code": 312130,
        "risk": "Medium",
        "score": 3
    },
    "Women's Handbag and Purse Manufacturing": {
        "name": "Women's Handbag and Purse Manufacturing",
        "code": 316992,
        "risk": "Medium",
        "score": 3
    },
    "Women's, Girls', and Infants' Cut and Sew Apparel Manufacturing": {
        "name": "Women's, Girls', and Infants' Cut and Sew Apparel Manufacturing",
        "code": 315240,
        "risk": "Medium",
        "score": 3
    },
    "Wood Container and Pallet Manufacturing": {
        "name": "Wood Container and Pallet Manufacturing",
        "code": 321920,
        "risk": "Medium",
        "score": 3
    },
    "Wood Kitchen Cabinet and Counter Top Manufacturing": {
        "name": "Wood Kitchen Cabinet and Counter Top Manufacturing",
        "code": 337110,
        "risk": "Low",
        "score": 1
    },
    "Wood Office Furniture Manufacturing": {
        "name": "Wood Office Furniture Manufacturing",
        "code": 337211,
        "risk": "Low",
        "score": 1
    },
    "Wood Preservation": {
        "name": "Wood Preservation",
        "code": 321114,
        "risk": "Medium",
        "score": 3
    },
    "Wood Window and Door Manufacturing": {
        "name": "Wood Window and Door Manufacturing",
        "code": 321911,
        "risk": "Medium",
        "score": 3
    },
    "All Other Metal Ore Mining": {
        "name": "All Other Metal Ore Mining",
        "code": 212299,
        "risk": "Low",
        "score": 1
    },
    "All Other Nonmetallic Mineral Mining": {
        "name": "All Other Nonmetallic Mineral Mining",
        "code": 212399,
        "risk": "Low",
        "score": 1
    },
    "Anthracite Mining": {
        "name": "Anthracite Mining",
        "code": 212113,
        "risk": "Low",
        "score": 1
    },
    "Bituminous Coal and Lignite Surface Mining": {
        "name": "Bituminous Coal and Lignite Surface Mining",
        "code": 212111,
        "risk": "Low",
        "score": 1
    },
    "Bituminous Coal Underground Mining": {
        "name": "Bituminous Coal Underground Mining",
        "code": 212112,
        "risk": "Low",
        "score": 1
    },
    "Clay and Ceramic and Refractory Minerals Mining": {
        "name": "Clay and Ceramic and Refractory Minerals Mining",
        "code": 212325,
        "risk": "Low",
        "score": 1
    },
    "Construction Sand and Gravel Mining": {
        "name": "Construction Sand and Gravel Mining",
        "code": 212321,
        "risk": "Low",
        "score": 1
    },
    "Copper Ore and Nickel Ore Mining": {
        "name": "Copper Ore and Nickel Ore Mining",
        "code": 212234,
        "risk": "Low",
        "score": 1
    },
    "Crude Petroleum and Natural Gas Extraction": {
        "name": "Crude Petroleum and Natural Gas Extraction",
        "code": 211111,
        "risk": "Low",
        "score": 1
    },
    "Crushed and Broken Granite Mining and Quarrying": {
        "name": "Crushed and Broken Granite Mining and Quarrying",
        "code": 212313,
        "risk": "Low",
        "score": 1
    },
    "Crushed and Broken Limestone Mining and Quarrying": {
        "name": "Crushed and Broken Limestone Mining and Quarrying",
        "code": 212312,
        "risk": "Low",
        "score": 1
    },
    "Dimension Stone Mining and Quarrying": {
        "name": "Dimension Stone Mining and Quarrying",
        "code": 212311,
        "risk": "Low",
        "score": 1
    },
    "Drilling Oil and Gas Wells": {
        "name": "Drilling Oil and Gas Wells",
        "code": 213111,
        "risk": "Low",
        "score": 1
    },
    "Gold Ore Mining": {
        "name": "Gold Ore Mining",
        "code": 212221,
        "risk": "Low",
        "score": 1
    },
    "Industrial Sand Mining": {
        "name": "Industrial Sand Mining",
        "code": 212322,
        "risk": "Low",
        "score": 1
    },
    "Iron Ore Mining": {
        "name": "Iron Ore Mining",
        "code": 212210,
        "risk": "Low",
        "score": 1
    },
    "Kaolin and Ball Clay Mining": {
        "name": "Kaolin and Ball Clay Mining",
        "code": 212324,
        "risk": "Low",
        "score": 1
    },
    "Lead Ore and Zinc Ore Mining": {
        "name": "Lead Ore and Zinc Ore Mining",
        "code": 212231,
        "risk": "Low",
        "score": 1
    },
    "Natural Gas Liquid Extraction": {
        "name": "Natural Gas Liquid Extraction",
        "code": 211112,
        "risk": "Low",
        "score": 1
    },
    "Other Chemical and Fertilizer Mineral Mining": {
        "name": "Other Chemical and Fertilizer Mineral Mining",
        "code": 212393,
        "risk": "Low",
        "score": 1
    },
    "Other Crushed and Broken Stone Mining and Quarrying": {
        "name": "Other Crushed and Broken Stone Mining and Quarrying",
        "code": 212319,
        "risk": "Low",
        "score": 1
    },
    "Phosphate Rock Mining": {
        "name": "Phosphate Rock Mining",
        "code": 212392,
        "risk": "Low",
        "score": 1
    },
    "Potash, Soda, and Borate Mineral Mining": {
        "name": "Potash, Soda, and Borate Mineral Mining",
        "code": 212391,
        "risk": "Low",
        "score": 1
    },
    "Silver Ore Mining": {
        "name": "Silver Ore Mining",
        "code": 212222,
        "risk": "Low",
        "score": 1
    },
    "Support Activities for Coal Mining": {
        "name": "Support Activities for Coal Mining",
        "code": 213113,
        "risk": "Low",
        "score": 1
    },
    "Support Activities for Metal Mining": {
        "name": "Support Activities for Metal Mining",
        "code": 213114,
        "risk": "Low",
        "score": 1
    },
    "Support Activities for Nonmetallic Minerals (except Fuels) Mining": {
        "name": "Support Activities for Nonmetallic Minerals (except Fuels) Mining",
        "code": 213115,
        "risk": "Low",
        "score": 1
    },
    "Support Activities for Oil and Gas Operations": {
        "name": "Support Activities for Oil and Gas Operations",
        "code": 213112,
        "risk": "Low",
        "score": 1
    },
    "Uranium-Radium-Vanadium Ore Mining": {
        "name": "Uranium-Radium-Vanadium Ore Mining",
        "code": 212291,
        "risk": "Low",
        "score": 1
    },
    "All Other Automotive Repair and Maintenance": {
        "name": "All Other Automotive Repair and Maintenance",
        "code": 811198,
        "risk": "High",
        "score": 5
    },
    "All Other Personal Services": {
        "name": "All Other Personal Services",
        "code": 812990,
        "risk": "Medium",
        "score": 3
    },
    "Appliance Repair and Maintenance": {
        "name": "Appliance Repair and Maintenance",
        "code": 811412,
        "risk": "Medium",
        "score": 3
    },
    "Automotive Body, Paint, and Interior Repair and Maintenance": {
        "name": "Automotive Body, Paint, and Interior Repair and Maintenance",
        "code": 811121,
        "risk": "High",
        "score": 5
    },
    "Automotive Exhaust System Repair": {
        "name": "Automotive Exhaust System Repair",
        "code": 811112,
        "risk": "High",
        "score": 5
    },
    "Automotive Glass Replacement Shops": {
        "name": "Automotive Glass Replacement Shops",
        "code": 811122,
        "risk": "High",
        "score": 5
    },
    "Automotive Oil Change and Lubrication Shops": {
        "name": "Automotive Oil Change and Lubrication Shops",
        "code": 811191,
        "risk": "High",
        "score": 5
    },
    "Automotive Transmission Repair": {
        "name": "Automotive Transmission Repair",
        "code": 811113,
        "risk": "High",
        "score": 5
    },
    "Barber Shops": {
        "name": "Barber Shops",
        "code": 812111,
        "risk": "Medium",
        "score": 3
    },
    "Beauty Salons": {
        "name": "Beauty Salons",
        "code": 812112,
        "risk": "Medium",
        "score": 3
    },
    "Business Associations": {
        "name": "Business Associations",
        "code": 813910,
        "risk": "Medium",
        "score": 3
    },
    "Car Washes": {
        "name": "Car Washes",
        "code": 811192,
        "risk": "High",
        "score": 5
    },
    "Cemeteries and Crematories": {
        "name": "Cemeteries and Crematories",
        "code": 812220,
        "risk": "Medium",
        "score": 3
    },
    "Civic and Social Organizations": {
        "name": "Civic and Social Organizations",
        "code": 813410,
        "risk": "High",
        "score": 5
    },
    "Coin-Operated Laundries and Drycleaners": {
        "name": "Coin-Operated Laundries and Drycleaners",
        "code": 812310,
        "risk": "High",
        "score": 5
    },
    "Commercial and Industrial Machinery and Equipment (except Automotive and Electronic) Repair and Maintenance": {
        "name": "Commercial and Industrial Machinery and Equipment (except Automotive and Electronic) Repair and Maintenance",
        "code": 811310,
        "risk": "Medium",
        "score": 3
    },
    "Communication Equipment Repair and Maintenance": {
        "name": "Communication Equipment Repair and Maintenance",
        "code": 811213,
        "risk": "Medium",
        "score": 3
    },
    "Computer and Office Machine Repair and Maintenance": {
        "name": "Computer and Office Machine Repair and Maintenance",
        "code": 811212,
        "risk": "Medium",
        "score": 3
    },
    "Consumer Electronics Repair and Maintenance": {
        "name": "Consumer Electronics Repair and Maintenance",
        "code": 811211,
        "risk": "Medium",
        "score": 3
    },
    "Diet and Weight Reducing Centers": {
        "name": "Diet and Weight Reducing Centers",
        "code": 812191,
        "risk": "Medium",
        "score": 3
    },
    "Drycleaning and Laundry Services (except Coin-Operated)": {
        "name": "Drycleaning and Laundry Services (except Coin-Operated)",
        "code": 812320,
        "risk": "High",
        "score": 5
    },
    "Environment, Conservation and Wildlife Organizations": {
        "name": "Environment, Conservation and Wildlife Organizations",
        "code": 813312,
        "risk": "High",
        "score": 5
    },
    "Footwear and Leather Goods Repair": {
        "name": "Footwear and Leather Goods Repair",
        "code": 811430,
        "risk": "Medium",
        "score": 3
    },
    "Funeral Homes and Funeral Services": {
        "name": "Funeral Homes and Funeral Services",
        "code": 812210,
        "risk": "Medium",
        "score": 3
    },
    "General Automotive Repair": {
        "name": "General Automotive Repair",
        "code": 811111,
        "risk": "High",
        "score": 5
    },
    "Grantmaking Foundations": {
        "name": "Grantmaking Foundations",
        "code": 813211,
        "risk": "High",
        "score": 5
    },
    "Home and Garden Equipment Repair and Maintenance": {
        "name": "Home and Garden Equipment Repair and Maintenance",
        "code": 811411,
        "risk": "Medium",
        "score": 3
    },
    "Human Rights Organizations": {
        "name": "Human Rights Organizations",
        "code": 813311,
        "risk": "High",
        "score": 5
    },
    "Industrial Launderers": {
        "name": "Industrial Launderers",
        "code": 812332,
        "risk": "Medium",
        "score": 3
    },
    "Labor Unions and Similar Labor Organizations": {
        "name": "Labor Unions and Similar Labor Organizations",
        "code": 813930,
        "risk": "Medium",
        "score": 3
    },
    "Linen Supply": {
        "name": "Linen Supply",
        "code": 812331,
        "risk": "Medium",
        "score": 3
    },
    "Nail Salons": {
        "name": "Nail Salons",
        "code": 812113,
        "risk": "Medium",
        "score": 3
    },
    "One-Hour Photofinishing": {
        "name": "One-Hour Photofinishing",
        "code": 812922,
        "risk": "Medium",
        "score": 3
    },
    "Other Automotive Mechanical and Electrical Repair and Maintenance": {
        "name": "Other Automotive Mechanical and Electrical Repair and Maintenance",
        "code": 811118,
        "risk": "High",
        "score": 5
    },
    "Other Electronic and Precision Equipment Repair and Maintenance": {
        "name": "Other Electronic and Precision Equipment Repair and Maintenance",
        "code": 811219,
        "risk": "Medium",
        "score": 3
    },
    "Other Grantmaking and Giving Services": {
        "name": "Other Grantmaking and Giving Services",
        "code": 813219,
        "risk": "High",
        "score": 5
    },
    "Other Personal and Household Goods Repair and Maintenance": {
        "name": "Other Personal and Household Goods Repair and Maintenance",
        "code": 811490,
        "risk": "Medium",
        "score": 3
    },
    "Other Personal Care Services": {
        "name": "Other Personal Care Services",
        "code": 812199,
        "risk": "Medium",
        "score": 3
    },
    "Other Similar Organizations (except Business, Professional, Labor, and Political Organizations)": {
        "name": "Other Similar Organizations (except Business, Professional, Labor, and Political Organizations)",
        "code": 813990,
        "risk": "Medium",
        "score": 3
    },
    "Other Social Advocacy Organizations": {
        "name": "Other Social Advocacy Organizations",
        "code": 813319,
        "risk": "High",
        "score": 5
    },
    "Parking Lots and Garages": {
        "name": "Parking Lots and Garages",
        "code": 812930,
        "risk": "High",
        "score": 5
    },
    "Pet Care (except Veterinary) Services": {
        "name": "Pet Care (except Veterinary) Services",
        "code": 812910,
        "risk": "Medium",
        "score": 3
    },
    "Photofinishing Laboratories (except One-Hour)": {
        "name": "Photofinishing Laboratories (except One-Hour)",
        "code": 812921,
        "risk": "Medium",
        "score": 3
    },
    "Political Organizations": {
        "name": "Political Organizations",
        "code": 813940,
        "risk": "High",
        "score": 5
    },
    "Private Households": {
        "name": "Private Households",
        "code": 814110,
        "risk": "Medium",
        "score": 3
    },
    "Professional Organizations": {
        "name": "Professional Organizations",
        "code": 813920,
        "risk": "Medium",
        "score": 3
    },
    "Religious Organizations": {
        "name": "Religious Organizations",
        "code": 813110,
        "risk": "High",
        "score": 5
    },
    "Reupholstery and Furniture Repair": {
        "name": "Reupholstery and Furniture Repair",
        "code": 811420,
        "risk": "Medium",
        "score": 3
    },
    "Voluntary Health Organizations": {
        "name": "Voluntary Health Organizations",
        "code": 813212,
        "risk": "High",
        "score": 5
    },
    "Administrative Management and General Management Consulting Services": {
        "name": "Administrative Management and General Management Consulting Services",
        "code": 541611,
        "risk": "Low",
        "score": 1
    },
    "Advertising Agencies": {
        "name": "Advertising Agencies",
        "code": 541810,
        "risk": "Medium",
        "score": 3
    },
    "Advertising Material Distribution Services": {
        "name": "Advertising Material Distribution Services",
        "code": 541870,
        "risk": "Medium",
        "score": 3
    },
    "All Other Legal Services": {
        "name": "All Other Legal Services",
        "code": 541199,
        "risk": "High",
        "score": 5
    },
    "All Other Professional, Scientific, and Technical Services": {
        "name": "All Other Professional, Scientific, and Technical Services",
        "code": 541990,
        "risk": "Medium",
        "score": 3
    },
    "Architectural Services": {
        "name": "Architectural Services",
        "code": 541310,
        "risk": "Low",
        "score": 1
    },
    "Building Inspection Services": {
        "name": "Building Inspection Services",
        "code": 541350,
        "risk": "Low",
        "score": 1
    },
    "Commercial Photography": {
        "name": "Commercial Photography",
        "code": 541922,
        "risk": "Medium",
        "score": 3
    },
    "Computer Facilities Management Services": {
        "name": "Computer Facilities Management Services",
        "code": 541513,
        "risk": "Low",
        "score": 1
    },
    "Computer Systems Design Services": {
        "name": "Computer Systems Design Services",
        "code": 541512,
        "risk": "Low",
        "score": 1
    },
    "Custom Computer Programming Services": {
        "name": "Custom Computer Programming Services",
        "code": 541511,
        "risk": "Low",
        "score": 1
    },
    "Direct Mail Advertising": {
        "name": "Direct Mail Advertising",
        "code": 541860,
        "risk": "Medium",
        "score": 3
    },
    "Drafting Services": {
        "name": "Drafting Services",
        "code": 541340,
        "risk": "Low",
        "score": 1
    },
    "Engineering Services": {
        "name": "Engineering Services",
        "code": 541330,
        "risk": "Low",
        "score": 1
    },
    "Environmental Consulting Services": {
        "name": "Environmental Consulting Services",
        "code": 541620,
        "risk": "Low",
        "score": 1
    },
    "Geophysical Surveying and Mapping Services": {
        "name": "Geophysical Surveying and Mapping Services",
        "code": 541360,
        "risk": "Low",
        "score": 1
    },
    "Graphic Design Services": {
        "name": "Graphic Design Services",
        "code": 541430,
        "risk": "Low",
        "score": 1
    },
    "Human Resources Consulting Services": {
        "name": "Human Resources Consulting Services",
        "code": 541612,
        "risk": "Low",
        "score": 1
    },
    "Industrial Design Services": {
        "name": "Industrial Design Services",
        "code": 541420,
        "risk": "Low",
        "score": 1
    },
    "Interior Design Services": {
        "name": "Interior Design Services",
        "code": 541410,
        "risk": "Low",
        "score": 1
    },
    "Landscape Architectural Services": {
        "name": "Landscape Architectural Services",
        "code": 541320,
        "risk": "Low",
        "score": 1
    },
    "Marketing Consulting Services": {
        "name": "Marketing Consulting Services",
        "code": 541613,
        "risk": "Low",
        "score": 1
    },
    "Marketing Research and Public Opinion Polling": {
        "name": "Marketing Research and Public Opinion Polling",
        "code": 541910,
        "risk": "Medium",
        "score": 3
    },
    "Media Buying Agencies": {
        "name": "Media Buying Agencies",
        "code": 541830,
        "risk": "Medium",
        "score": 3
    },
    "Media Representatives": {
        "name": "Media Representatives",
        "code": 541840,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Certified Public Accountants": {
        "name": "Offices of Certified Public Accountants",
        "code": 541211,
        "risk": "High",
        "score": 5
    },
    "Offices of Lawyers": {
        "name": "Offices of Lawyers",
        "code": 541110,
        "risk": "High",
        "score": 5
    },
    "Offices of Notaries": {
        "name": "Offices of Notaries",
        "code": 541120,
        "risk": "High",
        "score": 5
    },
    "Other Accounting Services": {
        "name": "Other Accounting Services",
        "code": 541219,
        "risk": "High",
        "score": 5
    },
    "Other Computer Related Services": {
        "name": "Other Computer Related Services",
        "code": 541519,
        "risk": "Low",
        "score": 1
    },
    "Other Management Consulting Services": {
        "name": "Other Management Consulting Services",
        "code": 541618,
        "risk": "Low",
        "score": 1
    },
    "Other Scientific and Technical Consulting Services": {
        "name": "Other Scientific and Technical Consulting Services",
        "code": 541690,
        "risk": "Low",
        "score": 1
    },
    "Other Services Related to Advertising": {
        "name": "Other Services Related to Advertising",
        "code": 541890,
        "risk": "Medium",
        "score": 3
    },
    "Other Specialized Design Services": {
        "name": "Other Specialized Design Services",
        "code": 541490,
        "risk": "Low",
        "score": 1
    },
    "Outdoor Advertising": {
        "name": "Outdoor Advertising",
        "code": 541850,
        "risk": "Medium",
        "score": 3
    },
    "Payroll Services": {
        "name": "Payroll Services",
        "code": 541214,
        "risk": "High",
        "score": 5
    },
    "Photography Studios, Portrait": {
        "name": "Photography Studios, Portrait",
        "code": 541921,
        "risk": "Medium",
        "score": 3
    },
    "Process, Physical Distribution, and Logistics Consulting Services": {
        "name": "Process, Physical Distribution, and Logistics Consulting Services",
        "code": 541614,
        "risk": "Low",
        "score": 1
    },
    "Public Relations Agencies": {
        "name": "Public Relations Agencies",
        "code": 541820,
        "risk": "Medium",
        "score": 3
    },
    "Research and Development in Biotechnology": {
        "name": "Research and Development in Biotechnology",
        "code": 541711,
        "risk": "Low",
        "score": 1
    },
    "Research and Development in the Physical, Engineering, and Life Sciences (except Biotechnology)": {
        "name": "Research and Development in the Physical, Engineering, and Life Sciences (except Biotechnology)",
        "code": 541712,
        "risk": "Low",
        "score": 1
    },
    "Research and Development in the Social Sciences and Humanities": {
        "name": "Research and Development in the Social Sciences and Humanities",
        "code": 541720,
        "risk": "Low",
        "score": 1
    },
    "Surveying and Mapping (except Geophysical) Services": {
        "name": "Surveying and Mapping (except Geophysical) Services",
        "code": 541370,
        "risk": "Low",
        "score": 1
    },
    "Tax Preparation Services": {
        "name": "Tax Preparation Services",
        "code": 541213,
        "risk": "High",
        "score": 5
    },
    "Testing Laboratories": {
        "name": "Testing Laboratories",
        "code": 541380,
        "risk": "Low",
        "score": 1
    },
    "Title Abstract and Settlement Offices": {
        "name": "Title Abstract and Settlement Offices",
        "code": 541191,
        "risk": "High",
        "score": 5
    },
    "Translation and Interpretation Services": {
        "name": "Translation and Interpretation Services",
        "code": 541930,
        "risk": "Medium",
        "score": 3
    },
    "Veterinary Services": {
        "name": "Veterinary Services",
        "code": 541940,
        "risk": "Low",
        "score": 1
    },
    "Administration of Air and Water Resource and Solid Waste Management Programs": {
        "name": "Administration of Air and Water Resource and Solid Waste Management Programs",
        "code": 924110,
        "risk": "Medium",
        "score": 3
    },
    "Administration of Conservation Programs": {
        "name": "Administration of Conservation Programs",
        "code": 924120,
        "risk": "Medium",
        "score": 3
    },
    "Administration of Education Programs": {
        "name": "Administration of Education Programs",
        "code": 923110,
        "risk": "Medium",
        "score": 3
    },
    "Administration of General Economic Programs": {
        "name": "Administration of General Economic Programs",
        "code": 926110,
        "risk": "Medium",
        "score": 3
    },
    "Administration of Housing Programs": {
        "name": "Administration of Housing Programs",
        "code": 925110,
        "risk": "Medium",
        "score": 3
    },
    "Administration of Human Resource Programs (except Education, Public Health, and Veterans' Affairs Programs)": {
        "name": "Administration of Human Resource Programs (except Education, Public Health, and Veterans' Affairs Programs)",
        "code": 923130,
        "risk": "Medium",
        "score": 3
    },
    "Administration of Public Health Programs": {
        "name": "Administration of Public Health Programs",
        "code": 923120,
        "risk": "Medium",
        "score": 3
    },
    "Administration of Urban Planning and Community and Rural Development": {
        "name": "Administration of Urban Planning and Community and Rural Development",
        "code": 925120,
        "risk": "Medium",
        "score": 3
    },
    "Administration of Veterans' Affairs": {
        "name": "Administration of Veterans' Affairs",
        "code": 923140,
        "risk": "Medium",
        "score": 3
    },
    "American Indian and Alaska Native Tribal Governments": {
        "name": "American Indian and Alaska Native Tribal Governments",
        "code": 921150,
        "risk": "Medium",
        "score": 3
    },
    "Correctional Institutions": {
        "name": "Correctional Institutions",
        "code": 922140,
        "risk": "Medium",
        "score": 3
    },
    "Courts": {
        "name": "Courts",
        "code": 922110,
        "risk": "Medium",
        "score": 3
    },
    "Executive and Legislative Offices, Combined": {
        "name": "Executive and Legislative Offices, Combined",
        "code": 921140,
        "risk": "Medium",
        "score": 3
    },
    "Executive Offices": {
        "name": "Executive Offices",
        "code": 921110,
        "risk": "Medium",
        "score": 3
    },
    "Fire Protection": {
        "name": "Fire Protection",
        "code": 922160,
        "risk": "Medium",
        "score": 3
    },
    "International Affairs": {
        "name": "International Affairs",
        "code": 928120,
        "risk": "High",
        "score": 5
    },
    "Legal Counsel and Prosecution": {
        "name": "Legal Counsel and Prosecution",
        "code": 922130,
        "risk": "Medium",
        "score": 3
    },
    "Legislative Bodies": {
        "name": "Legislative Bodies",
        "code": 921120,
        "risk": "Medium",
        "score": 3
    },
    "National Security": {
        "name": "National Security",
        "code": 928110,
        "risk": "Medium",
        "score": 3
    },
    "Other General Government Support": {
        "name": "Other General Government Support",
        "code": 921190,
        "risk": "Medium",
        "score": 3
    },
    "Other Justice, Public Order, and Safety Activities": {
        "name": "Other Justice, Public Order, and Safety Activities",
        "code": 922190,
        "risk": "Medium",
        "score": 3
    },
    "Parole Offices and Probation Offices": {
        "name": "Parole Offices and Probation Offices",
        "code": 922150,
        "risk": "Medium",
        "score": 3
    },
    "Police Protection": {
        "name": "Police Protection",
        "code": 922120,
        "risk": "Medium",
        "score": 3
    },
    "Public Finance Activities": {
        "name": "Public Finance Activities",
        "code": 921130,
        "risk": "Medium",
        "score": 3
    },
    "Regulation and Administration of Communications, Electric, Gas, and Other Utilities": {
        "name": "Regulation and Administration of Communications, Electric, Gas, and Other Utilities",
        "code": 926130,
        "risk": "Medium",
        "score": 3
    },
    "Regulation and Administration of Transportation Programs": {
        "name": "Regulation and Administration of Transportation Programs",
        "code": 926120,
        "risk": "Medium",
        "score": 3
    },
    "Regulation of Agricultural Marketing and Commodities": {
        "name": "Regulation of Agricultural Marketing and Commodities",
        "code": 926140,
        "risk": "Medium",
        "score": 3
    },
    "Regulation, Licensing, and Inspection of Miscellaneous Commercial Sectors": {
        "name": "Regulation, Licensing, and Inspection of Miscellaneous Commercial Sectors",
        "code": 926150,
        "risk": "Medium",
        "score": 3
    },
    "Space Research and Technology": {
        "name": "Space Research and Technology",
        "code": 927110,
        "risk": "Medium",
        "score": 3
    },
    "All Other Consumer Goods Rental": {
        "name": "All Other Consumer Goods Rental",
        "code": 532299,
        "risk": "Low",
        "score": 1
    },
    "Commercial Air, Rail, and Water Transportation Equipment Rental and Leasing": {
        "name": "Commercial Air, Rail, and Water Transportation Equipment Rental and Leasing",
        "code": 532411,
        "risk": "Low",
        "score": 1
    },
    "Construction, Mining, and Forestry Machinery and Equipment Rental and Leasing": {
        "name": "Construction, Mining, and Forestry Machinery and Equipment Rental and Leasing",
        "code": 532412,
        "risk": "Low",
        "score": 1
    },
    "Consumer Electronics and Appliances Rental": {
        "name": "Consumer Electronics and Appliances Rental",
        "code": 532210,
        "risk": "Low",
        "score": 1
    },
    "Formal Wear and Costume Rental": {
        "name": "Formal Wear and Costume Rental",
        "code": 532220,
        "risk": "Low",
        "score": 1
    },
    "General Rental Centers": {
        "name": "General Rental Centers",
        "code": 532310,
        "risk": "Low",
        "score": 1
    },
    "Home Health Equipment Rental": {
        "name": "Home Health Equipment Rental",
        "code": 532291,
        "risk": "Low",
        "score": 1
    },
    "Lessors of Miniwarehouses and Self-Storage Units": {
        "name": "Lessors of Miniwarehouses and Self-Storage Units",
        "code": 531130,
        "risk": "High",
        "score": 5
    },
    "Lessors of Nonfinancial Intangible Assets (except Copyrighted Works)": {
        "name": "Lessors of Nonfinancial Intangible Assets (except Copyrighted Works)",
        "code": 533110,
        "risk": "Low",
        "score": 1
    },
    "Lessors of Nonresidential Buildings (except Miniwarehouses)": {
        "name": "Lessors of Nonresidential Buildings (except Miniwarehouses)",
        "code": 531120,
        "risk": "Medium",
        "score": 3
    },
    "Lessors of Other Real Estate Property": {
        "name": "Lessors of Other Real Estate Property",
        "code": 531190,
        "risk": "Medium",
        "score": 3
    },
    "Lessors of Residential Buildings and Dwellings": {
        "name": "Lessors of Residential Buildings and Dwellings",
        "code": 531110,
        "risk": "Medium",
        "score": 3
    },
    "Nonresidential Property Managers": {
        "name": "Nonresidential Property Managers",
        "code": 531312,
        "risk": "Medium",
        "score": 3
    },
    "Office Machinery and Equipment Rental and Leasing": {
        "name": "Office Machinery and Equipment Rental and Leasing",
        "code": 532420,
        "risk": "Low",
        "score": 1
    },
    "Offices of Real Estate Agents and Brokers": {
        "name": "Offices of Real Estate Agents and Brokers",
        "code": 531210,
        "risk": "Medium",
        "score": 3
    },
    "Offices of Real Estate Appraisers": {
        "name": "Offices of Real Estate Appraisers",
        "code": 531320,
        "risk": "Medium",
        "score": 3
    },
    "Other Activities Related to Real Estate": {
        "name": "Other Activities Related to Real Estate",
        "code": 531390,
        "risk": "Medium",
        "score": 3
    },
    "Other Commercial and Industrial Machinery and Equipment Rental and Leasing": {
        "name": "Other Commercial and Industrial Machinery and Equipment Rental and Leasing",
        "code": 532490,
        "risk": "Low",
        "score": 1
    },
    "Passenger Car Leasing": {
        "name": "Passenger Car Leasing",
        "code": 532112,
        "risk": "High",
        "score": 5
    },
    "Passenger Car Rental": {
        "name": "Passenger Car Rental",
        "code": 532111,
        "risk": "High",
        "score": 5
    },
    "Recreational Goods Rental": {
        "name": "Recreational Goods Rental",
        "code": 532292,
        "risk": "Low",
        "score": 1
    },
    "Residential Property Managers": {
        "name": "Residential Property Managers",
        "code": 531311,
        "risk": "Medium",
        "score": 3
    },
    "Truck, Utility Trailer, and RV (Recreational Vehicle) Rental and Leasing": {
        "name": "Truck, Utility Trailer, and RV (Recreational Vehicle) Rental and Leasing",
        "code": 532120,
        "risk": "High",
        "score": 5
    },
    "Video Tape and Disc Rental": {
        "name": "Video Tape and Disc Rental",
        "code": 532230,
        "risk": "Low",
        "score": 1
    },
    "All Other General Merchandise Stores": {
        "name": "All Other General Merchandise Stores",
        "code": 452990,
        "risk": "Medium",
        "score": 3
    },
    "All Other Health and Personal Care Stores": {
        "name": "All Other Health and Personal Care Stores",
        "code": 446199,
        "risk": "Medium",
        "score": 3
    },
    "All Other Home Furnishings Stores": {
        "name": "All Other Home Furnishings Stores",
        "code": 442299,
        "risk": "Medium",
        "score": 3
    },
    "All Other Miscellaneous Store Retailers (except Tobacco Stores)": {
        "name": "All Other Miscellaneous Store Retailers (except Tobacco Stores)",
        "code": 453998,
        "risk": "Medium",
        "score": 3
    },
    "All Other Specialty Food Stores": {
        "name": "All Other Specialty Food Stores",
        "code": 445299,
        "risk": "High",
        "score": 5
    },
    "Art Dealers": {
        "name": "Art Dealers",
        "code": 453920,
        "risk": "High",
        "score": 5
    },
    "Automotive Parts and Accessories Stores": {
        "name": "Automotive Parts and Accessories Stores",
        "code": 441310,
        "risk": "High",
        "score": 5
    },
    "Baked Goods Stores": {
        "name": "Baked Goods Stores",
        "code": 445291,
        "risk": "Medium",
        "score": 3
    },
    "Beer, Wine, and Liquor Stores": {
        "name": "Beer, Wine, and Liquor Stores",
        "code": 445310,
        "risk": "High",
        "score": 5
    },
    "Boat Dealers": {
        "name": "Boat Dealers",
        "code": 441222,
        "risk": "High",
        "score": 5
    },
    "Book Stores": {
        "name": "Book Stores",
        "code": 451211,
        "risk": "High",
        "score": 5
    },
    "Children's and Infants' Clothing Stores": {
        "name": "Children's and Infants' Clothing Stores",
        "code": 448130,
        "risk": "High",
        "score": 5
    },
    "Clothing Accessories Stores": {
        "name": "Clothing Accessories Stores",
        "code": 448150,
        "risk": "High",
        "score": 5
    },
    "Confectionery and Nut Stores": {
        "name": "Confectionery and Nut Stores",
        "code": 445292,
        "risk": "High",
        "score": 5
    },
    "Convenience Stores": {
        "name": "Convenience Stores",
        "code": 445120,
        "risk": "High",
        "score": 5
    },
    "Cosmetics, Beauty Supplies, and Perfume Stores": {
        "name": "Cosmetics, Beauty Supplies, and Perfume Stores",
        "code": 446120,
        "risk": "Medium",
        "score": 3
    },
    "Department Stores (except Discount Department Stores)": {
        "name": "Department Stores (except Discount Department Stores)",
        "code": 452111,
        "risk": "Medium",
        "score": 3
    },
    "Discount Department Stores": {
        "name": "Discount Department Stores",
        "code": 452112,
        "risk": "Medium",
        "score": 3
    },
    "Electronic Auctions": {
        "name": "Electronic Auctions",
        "code": 454112,
        "risk": "High",
        "score": 5
    },
    "Electronic Shopping": {
        "name": "Electronic Shopping",
        "code": 454111,
        "risk": "High",
        "score": 5
    },
    "Electronics Stores": {
        "name": "Electronics Stores",
        "code": 443142,
        "risk": "Medium",
        "score": 3
    },
    "Family Clothing Stores": {
        "name": "Family Clothing Stores",
        "code": 448140,
        "risk": "High",
        "score": 5
    },
    "Fish and Seafood Markets": {
        "name": "Fish and Seafood Markets",
        "code": 445220,
        "risk": "High",
        "score": 5
    },
    "Floor Covering Stores": {
        "name": "Floor Covering Stores",
        "code": 442210,
        "risk": "Medium",
        "score": 3
    },
    "Florists": {
        "name": "Florists",
        "code": 453110,
        "risk": "High",
        "score": 5
    },
    "Food (Health) Supplement Stores": {
        "name": "Food (Health) Supplement Stores",
        "code": 446191,
        "risk": "High",
        "score": 5
    },
    "Fruit and Vegetable Markets": {
        "name": "Fruit and Vegetable Markets",
        "code": 445230,
        "risk": "High",
        "score": 5
    },
    "Fuel Dealers": {
        "name": "Fuel Dealers",
        "code": 454310,
        "risk": "High",
        "score": 5
    },
    "Furniture Stores": {
        "name": "Furniture Stores",
        "code": 442110,
        "risk": "Medium",
        "score": 3
    },
    "Gasoline Stations with Convenience Stores": {
        "name": "Gasoline Stations with Convenience Stores",
        "code": 447110,
        "risk": "High",
        "score": 5
    },
    "Gift, Novelty, and Souvenir Stores": {
        "name": "Gift, Novelty, and Souvenir Stores",
        "code": 453220,
        "risk": "High",
        "score": 5
    },
    "Hardware Stores": {
        "name": "Hardware Stores",
        "code": 444130,
        "risk": "Medium",
        "score": 3
    },
    "Hobby, Toy, and Game Stores": {
        "name": "Hobby, Toy, and Game Stores",
        "code": 451120,
        "risk": "High",
        "score": 5
    },
    "Home Centers": {
        "name": "Home Centers",
        "code": 444110,
        "risk": "Medium",
        "score": 3
    },
    "Household Appliance Stores": {
        "name": "Household Appliance Stores",
        "code": 443141,
        "risk": "Medium",
        "score": 3
    },
    "Jewelry Stores": {
        "name": "Jewelry Stores",
        "code": 448310,
        "risk": "High",
        "score": 5
    },
    "Luggage and Leather Goods Stores": {
        "name": "Luggage and Leather Goods Stores",
        "code": 448320,
        "risk": "High",
        "score": 5
    },
    "Mail-Order Houses": {
        "name": "Mail-Order Houses",
        "code": 454113,
        "risk": "High",
        "score": 5
    },
    "Manufactured (Mobile) Home Dealers": {
        "name": "Manufactured (Mobile) Home Dealers",
        "code": 453930,
        "risk": "High",
        "score": 5
    },
    "Meat Markets": {
        "name": "Meat Markets",
        "code": 445210,
        "risk": "High",
        "score": 5
    },
    "Men's Clothing Stores": {
        "name": "Men's Clothing Stores",
        "code": 448110,
        "risk": "High",
        "score": 5
    },
    "Motorcycle, ATV, and All Other Motor Vehicle Dealers": {
        "name": "Motorcycle, ATV, and All Other Motor Vehicle Dealers",
        "code": 441228,
        "risk": "High",
        "score": 5
    },
    "Musical Instrument and Supplies Stores": {
        "name": "Musical Instrument and Supplies Stores",
        "code": 451140,
        "risk": "Medium",
        "score": 3
    },
    "New Car Dealers": {
        "name": "New Car Dealers",
        "code": 441110,
        "risk": "High",
        "score": 5
    },
    "News Dealers and Newsstands": {
        "name": "News Dealers and Newsstands",
        "code": 451212,
        "risk": "High",
        "score": 5
    },
    "Nursery, and Garden Center, and Farm Supply Stores": {
        "name": "Nursery, and Garden Center, and Farm Supply Stores",
        "code": 444220,
        "risk": "Medium",
        "score": 3
    },
    "Office Supplies and Stationery Stores": {
        "name": "Office Supplies and Stationery Stores",
        "code": 453210,
        "risk": "High",
        "score": 5
    },
    "Optical Goods Stores": {
        "name": "Optical Goods Stores",
        "code": 446130,
        "risk": "Medium",
        "score": 3
    },
    "Other Building Material Dealers": {
        "name": "Other Building Material Dealers",
        "code": 444190,
        "risk": "Medium",
        "score": 3
    },
    "Other Clothing Stores": {
        "name": "Other Clothing Stores",
        "code": 448190,
        "risk": "High",
        "score": 5
    },
    "Other Direct Selling Establishments": {
        "name": "Other Direct Selling Establishments",
        "code": 454390,
        "risk": "High",
        "score": 5
    },
    "Other Gasoline Stations": {
        "name": "Other Gasoline Stations",
        "code": 447190,
        "risk": "High",
        "score": 5
    },
    "Outdoor Power Equipment Stores": {
        "name": "Outdoor Power Equipment Stores",
        "code": 444210,
        "risk": "High",
        "score": 5
    },
    "Paint and Wallpaper Stores": {
        "name": "Paint and Wallpaper Stores",
        "code": 444120,
        "risk": "Medium",
        "score": 3
    },
    "Pet and Pet Supplies Stores": {
        "name": "Pet and Pet Supplies Stores",
        "code": 453910,
        "risk": "Medium",
        "score": 3
    },
    "Pharmacies and Drug Stores": {
        "name": "Pharmacies and Drug Stores",
        "code": 446110,
        "risk": "Medium",
        "score": 3
    },
    "Recreational Vehicle Dealers": {
        "name": "Recreational Vehicle Dealers",
        "code": 441210,
        "risk": "High",
        "score": 5
    },
    "Sewing, Needlework, and Piece Goods Stores": {
        "name": "Sewing, Needlework, and Piece Goods Stores",
        "code": 451130,
        "risk": "High",
        "score": 5
    },
    "Shoe Stores": {
        "name": "Shoe Stores",
        "code": 448210,
        "risk": "High",
        "score": 5
    },
    "Sporting Goods Stores": {
        "name": "Sporting Goods Stores",
        "code": 451110,
        "risk": "High",
        "score": 5
    },
    "Supermarkets and Other Grocery (except Convenience) Stores": {
        "name": "Supermarkets and Other Grocery (except Convenience) Stores",
        "code": 445110,
        "risk": "High",
        "score": 5
    },
    "Tire Dealers": {
        "name": "Tire Dealers",
        "code": 441320,
        "risk": "High",
        "score": 5
    },
    "Tobacco Stores": {
        "name": "Tobacco Stores",
        "code": 453991,
        "risk": "High",
        "score": 5
    },
    "Used Car Dealers": {
        "name": "Used Car Dealers",
        "code": 441120,
        "risk": "High",
        "score": 5
    },
    "Used Merchandise Stores": {
        "name": "Used Merchandise Stores",
        "code": 453310,
        "risk": "High",
        "score": 5
    },
    "Vending Machine Operators": {
        "name": "Vending Machine Operators",
        "code": 454210,
        "risk": "High",
        "score": 5
    },
    "Warehouse Clubs and Supercenters": {
        "name": "Warehouse Clubs and Supercenters",
        "code": 452910,
        "risk": "Medium",
        "score": 3
    },
    "Window Treatment Stores": {
        "name": "Window Treatment Stores",
        "code": 442291,
        "risk": "Medium",
        "score": 3
    },
    "Women's Clothing Stores": {
        "name": "Women's Clothing Stores",
        "code": 448120,
        "risk": "High",
        "score": 5
    },
    "Air Traffic Control": {
        "name": "Air Traffic Control",
        "code": 488111,
        "risk": "Medium",
        "score": 3
    },
    "All Other Pipeline Transportation": {
        "name": "All Other Pipeline Transportation",
        "code": 486990,
        "risk": "High",
        "score": 5
    },
    "All Other Support Activities for Transportation": {
        "name": "All Other Support Activities for Transportation",
        "code": 488999,
        "risk": "High",
        "score": 5
    },
    "All Other Transit and Ground Passenger Transportation": {
        "name": "All Other Transit and Ground Passenger Transportation",
        "code": 485999,
        "risk": "High",
        "score": 5
    },
    "Bus and Other Motor Vehicle Transit Systems": {
        "name": "Bus and Other Motor Vehicle Transit Systems",
        "code": 485113,
        "risk": "High",
        "score": 5
    },
    "Charter Bus Industry": {
        "name": "Charter Bus Industry",
        "code": 485510,
        "risk": "High",
        "score": 5
    },
    "Coastal and Great Lakes Freight Transportation": {
        "name": "Coastal and Great Lakes Freight Transportation",
        "code": 483113,
        "risk": "High",
        "score": 5
    },
    "Coastal and Great Lakes Passenger Transportation": {
        "name": "Coastal and Great Lakes Passenger Transportation",
        "code": 483114,
        "risk": "High",
        "score": 5
    },
    "Commuter Rail Systems": {
        "name": "Commuter Rail Systems",
        "code": 485112,
        "risk": "High",
        "score": 5
    },
    "Couriers": {
        "name": "Couriers",
        "code": 492110,
        "risk": "High",
        "score": 5
    },
    "Deep Sea Freight Transportation": {
        "name": "Deep Sea Freight Transportation",
        "code": 483111,
        "risk": "High",
        "score": 5
    },
    "Deep Sea Passenger Transportation": {
        "name": "Deep Sea Passenger Transportation",
        "code": 483112,
        "risk": "High",
        "score": 5
    },
    "Farm Product Warehousing and Storage": {
        "name": "Farm Product Warehousing and Storage",
        "code": 493130,
        "risk": "Medium",
        "score": 3
    },
    "Freight Transportation Arrangement": {
        "name": "Freight Transportation Arrangement",
        "code": 488510,
        "risk": "High",
        "score": 5
    },
    "General Freight Trucking, Local": {
        "name": "General Freight Trucking, Local",
        "code": 484110,
        "risk": "High",
        "score": 5
    },
    "General Freight Trucking, Long-Distance, Less than Truckload": {
        "name": "General Freight Trucking, Long-Distance, Less than Truckload",
        "code": 484122,
        "risk": "High",
        "score": 5
    },
    "General Freight Trucking, Long-Distance, Truckload": {
        "name": "General Freight Trucking, Long-Distance, Truckload",
        "code": 484121,
        "risk": "High",
        "score": 5
    },
    "General Warehousing and Storage": {
        "name": "General Warehousing and Storage",
        "code": 493110,
        "risk": "High",
        "score": 5
    },
    "Inland Water Freight Transportation": {
        "name": "Inland Water Freight Transportation",
        "code": 483211,
        "risk": "High",
        "score": 5
    },
    "Inland Water Passenger Transportation": {
        "name": "Inland Water Passenger Transportation",
        "code": 483212,
        "risk": "High",
        "score": 5
    },
    "Interurban and Rural Bus Transportation": {
        "name": "Interurban and Rural Bus Transportation",
        "code": 485210,
        "risk": "High",
        "score": 5
    },
    "Limousine Service": {
        "name": "Limousine Service",
        "code": 485320,
        "risk": "High",
        "score": 5
    },
    "Line-Haul Railroads": {
        "name": "Line-Haul Railroads",
        "code": 482111,
        "risk": "High",
        "score": 5
    },
    "Local Messengers and Local Delivery": {
        "name": "Local Messengers and Local Delivery",
        "code": 492210,
        "risk": "High",
        "score": 5
    },
    "Marine Cargo Handling": {
        "name": "Marine Cargo Handling",
        "code": 488320,
        "risk": "High",
        "score": 5
    },
    "Mixed Mode Transit Systems": {
        "name": "Mixed Mode Transit Systems",
        "code": 485111,
        "risk": "High",
        "score": 5
    },
    "Motor Vehicle Towing": {
        "name": "Motor Vehicle Towing",
        "code": 488410,
        "risk": "High",
        "score": 5
    },
    "Navigational Services to Shipping": {
        "name": "Navigational Services to Shipping",
        "code": 488330,
        "risk": "High",
        "score": 5
    },
    "Nonscheduled Chartered Freight Air Transportation": {
        "name": "Nonscheduled Chartered Freight Air Transportation",
        "code": 481212,
        "risk": "High",
        "score": 5
    },
    "Nonscheduled Chartered Passenger Air Transportation": {
        "name": "Nonscheduled Chartered Passenger Air Transportation",
        "code": 481211,
        "risk": "High",
        "score": 5
    },
    "Other Airport Operations": {
        "name": "Other Airport Operations",
        "code": 488119,
        "risk": "High",
        "score": 5
    },
    "Other Nonscheduled Air Transportation": {
        "name": "Other Nonscheduled Air Transportation",
        "code": 481219,
        "risk": "High",
        "score": 5
    },
    "Other Support Activities for Air Transportation": {
        "name": "Other Support Activities for Air Transportation",
        "code": 488190,
        "risk": "High",
        "score": 5
    },
    "Other Support Activities for Road Transportation": {
        "name": "Other Support Activities for Road Transportation",
        "code": 488490,
        "risk": "High",
        "score": 5
    },
    "Other Support Activities for Water Transportation": {
        "name": "Other Support Activities for Water Transportation",
        "code": 488390,
        "risk": "High",
        "score": 5
    },
    "Other Urban Transit Systems": {
        "name": "Other Urban Transit Systems",
        "code": 485119,
        "risk": "High",
        "score": 5
    },
    "Other Warehousing and Storage": {
        "name": "Other Warehousing and Storage",
        "code": 493190,
        "risk": "High",
        "score": 5
    },
    "Packing and Crating": {
        "name": "Packing and Crating",
        "code": 488991,
        "risk": "High",
        "score": 5
    },
    "Pipeline Transportation of Crude Oil": {
        "name": "Pipeline Transportation of Crude Oil",
        "code": 486110,
        "risk": "High",
        "score": 5
    },
    "Pipeline Transportation of Natural Gas": {
        "name": "Pipeline Transportation of Natural Gas",
        "code": 486210,
        "risk": "High",
        "score": 5
    },
    "Pipeline Transportation of Refined Petroleum Products": {
        "name": "Pipeline Transportation of Refined Petroleum Products",
        "code": 486910,
        "risk": "High",
        "score": 5
    },
    "Port and Harbor Operations": {
        "name": "Port and Harbor Operations",
        "code": 488310,
        "risk": "High",
        "score": 5
    },
    "Postal Service": {
        "name": "Postal Service",
        "code": 491110,
        "risk": "High",
        "score": 5
    },
    "Refrigerated Warehousing and Storage": {
        "name": "Refrigerated Warehousing and Storage",
        "code": 493120,
        "risk": "High",
        "score": 5
    },
    "Scenic and Sightseeing Transportation, Land": {
        "name": "Scenic and Sightseeing Transportation, Land",
        "code": 487110,
        "risk": "High",
        "score": 5
    },
    "Scenic and Sightseeing Transportation, Other": {
        "name": "Scenic and Sightseeing Transportation, Other",
        "code": 487990,
        "risk": "High",
        "score": 5
    },
    "Scenic and Sightseeing Transportation, Water": {
        "name": "Scenic and Sightseeing Transportation, Water",
        "code": 487210,
        "risk": "High",
        "score": 5
    },
    "Scheduled Freight Air Transportation": {
        "name": "Scheduled Freight Air Transportation",
        "code": 481112,
        "risk": "High",
        "score": 5
    },
    "Scheduled Passenger Air Transportation": {
        "name": "Scheduled Passenger Air Transportation",
        "code": 481111,
        "risk": "High",
        "score": 5
    },
    "School and Employee Bus Transportation": {
        "name": "School and Employee Bus Transportation",
        "code": 485410,
        "risk": "High",
        "score": 5
    },
    "Short Line Railroads": {
        "name": "Short Line Railroads",
        "code": 482112,
        "risk": "High",
        "score": 5
    },
    "Special Needs Transportation": {
        "name": "Special Needs Transportation",
        "code": 485991,
        "risk": "High",
        "score": 5
    },
    "Specialized Freight (except Used Goods) Trucking, Local": {
        "name": "Specialized Freight (except Used Goods) Trucking, Local",
        "code": 484220,
        "risk": "High",
        "score": 5
    },
    "Specialized Freight (except Used Goods) Trucking, Long-Distance": {
        "name": "Specialized Freight (except Used Goods) Trucking, Long-Distance",
        "code": 484230,
        "risk": "High",
        "score": 5
    },
    "Support Activities for Rail Transportation": {
        "name": "Support Activities for Rail Transportation",
        "code": 488210,
        "risk": "High",
        "score": 5
    },
    "Taxi Service": {
        "name": "Taxi Service",
        "code": 485310,
        "risk": "High",
        "score": 5
    },
    "Used Household and Office Goods Moving": {
        "name": "Used Household and Office Goods Moving",
        "code": 484210,
        "risk": "High",
        "score": 5
    },
    "Biomass Electric Power Generation": {
        "name": "Biomass Electric Power Generation",
        "code": 221117,
        "risk": "Low",
        "score": 1
    },
    "Electric Bulk Power Transmission and Control": {
        "name": "Electric Bulk Power Transmission and Control",
        "code": 221121,
        "risk": "Low",
        "score": 1
    },
    "Electric Power Distribution": {
        "name": "Electric Power Distribution",
        "code": 221122,
        "risk": "Low",
        "score": 1
    },
    "Fossil Fuel Electric Power Generation": {
        "name": "Fossil Fuel Electric Power Generation",
        "code": 221112,
        "risk": "Low",
        "score": 1
    },
    "Geothermal Electric Power Generation": {
        "name": "Geothermal Electric Power Generation",
        "code": 221116,
        "risk": "Low",
        "score": 1
    },
    "Hydroelectric Power Generation": {
        "name": "Hydroelectric Power Generation",
        "code": 221111,
        "risk": "Low",
        "score": 1
    },
    "Natural Gas Distribution": {
        "name": "Natural Gas Distribution",
        "code": 221210,
        "risk": "Low",
        "score": 1
    },
    "Nuclear Electric Power Generation": {
        "name": "Nuclear Electric Power Generation",
        "code": 221113,
        "risk": "Low",
        "score": 1
    },
    "Other Electric Power Generation": {
        "name": "Other Electric Power Generation",
        "code": 221118,
        "risk": "Low",
        "score": 1
    },
    "Sewage Treatment Facilities": {
        "name": "Sewage Treatment Facilities",
        "code": 221320,
        "risk": "Low",
        "score": 1
    },
    "Solar Electric Power Generation": {
        "name": "Solar Electric Power Generation",
        "code": 221114,
        "risk": "Low",
        "score": 1
    },
    "Steam and Air-Conditioning Supply": {
        "name": "Steam and Air-Conditioning Supply",
        "code": 221330,
        "risk": "Low",
        "score": 1
    },
    "Water Supply and Irrigation Systems": {
        "name": "Water Supply and Irrigation Systems",
        "code": 221310,
        "risk": "Low",
        "score": 1
    },
    "Wind Electric Power Generation": {
        "name": "Wind Electric Power Generation",
        "code": 221115,
        "risk": "Low",
        "score": 1
    },
    "Automobile and Other Motor Vehicle Merchant Wholesalers": {
        "name": "Automobile and Other Motor Vehicle Merchant Wholesalers",
        "code": 423110,
        "risk": "High",
        "score": 5
    },
    "Beer and Ale Merchant Wholesalers": {
        "name": "Beer and Ale Merchant Wholesalers",
        "code": 424810,
        "risk": "High",
        "score": 5
    },
    "Book, Periodical, and Newspaper Merchant Wholesalers": {
        "name": "Book, Periodical, and Newspaper Merchant Wholesalers",
        "code": 424920,
        "risk": "Medium",
        "score": 3
    },
    "Brick, Stone, and Related Construction Material Merchant Wholesalers": {
        "name": "Brick, Stone, and Related Construction Material Merchant Wholesalers",
        "code": 423320,
        "risk": "Medium",
        "score": 3
    },
    "Business to Business Electronic Markets": {
        "name": "Business to Business Electronic Markets",
        "code": 425110,
        "risk": "High",
        "score": 5
    },
    "Coal and Other Mineral and Ore Merchant Wholesalers": {
        "name": "Coal and Other Mineral and Ore Merchant Wholesalers",
        "code": 423520,
        "risk": "High",
        "score": 5
    },
    "Computer and Computer Peripheral Equipment and Software Merchant Wholesalers": {
        "name": "Computer and Computer Peripheral Equipment and Software Merchant Wholesalers",
        "code": 423430,
        "risk": "Medium",
        "score": 3
    },
    "Confectionery Merchant Wholesalers": {
        "name": "Confectionery Merchant Wholesalers",
        "code": 424450,
        "risk": "Medium",
        "score": 3
    },
    "Construction and Mining (except Oil Well) Machinery and Equipment Merchant Wholesalers": {
        "name": "Construction and Mining (except Oil Well) Machinery and Equipment Merchant Wholesalers",
        "code": 423810,
        "risk": "Medium",
        "score": 3
    },
    "Dairy Product (except Dried or Canned) Merchant Wholesalers": {
        "name": "Dairy Product (except Dried or Canned) Merchant Wholesalers",
        "code": 424430,
        "risk": "Medium",
        "score": 3
    },
    "Drugs and Druggists' Sundries Merchant Wholesalers": {
        "name": "Drugs and Druggists' Sundries Merchant Wholesalers",
        "code": 424210,
        "risk": "Medium",
        "score": 3
    },
    "Electrical Apparatus and Equipment, Wiring Supplies, and Related Equipment Merchant Wholesalers": {
        "name": "Electrical Apparatus and Equipment, Wiring Supplies, and Related Equipment Merchant Wholesalers",
        "code": 423610,
        "risk": "Medium",
        "score": 3
    },
    "Farm and Garden Machinery and Equipment Merchant Wholesalers": {
        "name": "Farm and Garden Machinery and Equipment Merchant Wholesalers",
        "code": 423820,
        "risk": "Medium",
        "score": 3
    },
    "Farm Supplies Merchant Wholesalers": {
        "name": "Farm Supplies Merchant Wholesalers",
        "code": 424910,
        "risk": "Medium",
        "score": 3
    },
    "Fish and Seafood Merchant Wholesalers": {
        "name": "Fish and Seafood Merchant Wholesalers",
        "code": 424460,
        "risk": "Medium",
        "score": 3
    },
    "Flower, Nursery Stock, and Florists' Supplies Merchant Wholesalers": {
        "name": "Flower, Nursery Stock, and Florists' Supplies Merchant Wholesalers",
        "code": 424930,
        "risk": "Medium",
        "score": 3
    },
    "Footwear Merchant Wholesalers": {
        "name": "Footwear Merchant Wholesalers",
        "code": 424340,
        "risk": "Medium",
        "score": 3
    },
    "Fresh Fruit and Vegetable Merchant Wholesalers": {
        "name": "Fresh Fruit and Vegetable Merchant Wholesalers",
        "code": 424480,
        "risk": "Medium",
        "score": 3
    },
    "Furniture Merchant Wholesalers": {
        "name": "Furniture Merchant Wholesalers",
        "code": 423210,
        "risk": "Medium",
        "score": 3
    },
    "General Line Grocery Merchant Wholesalers": {
        "name": "General Line Grocery Merchant Wholesalers",
        "code": 424410,
        "risk": "Medium",
        "score": 3
    },
    "Grain and Field Bean Merchant Wholesalers": {
        "name": "Grain and Field Bean Merchant Wholesalers",
        "code": 424510,
        "risk": "Medium",
        "score": 3
    },
    "Hardware Merchant Wholesalers": {
        "name": "Hardware Merchant Wholesalers",
        "code": 423710,
        "risk": "Medium",
        "score": 3
    },
    "Home Furnishing Merchant Wholesalers": {
        "name": "Home Furnishing Merchant Wholesalers",
        "code": 423220,
        "risk": "Medium",
        "score": 3
    },
    "Household Appliances, Electric Housewares, and Consumer Electronics Merchant Wholesalers": {
        "name": "Household Appliances, Electric Housewares, and Consumer Electronics Merchant Wholesalers",
        "code": 423620,
        "risk": "Medium",
        "score": 3
    },
    "Industrial and Personal Service Paper Merchant Wholesalers": {
        "name": "Industrial and Personal Service Paper Merchant Wholesalers",
        "code": 424130,
        "risk": "Medium",
        "score": 3
    },
    "Industrial Machinery and Equipment Merchant Wholesalers": {
        "name": "Industrial Machinery and Equipment Merchant Wholesalers",
        "code": 423830,
        "risk": "Medium",
        "score": 3
    },
    "Industrial Supplies Merchant Wholesalers": {
        "name": "Industrial Supplies Merchant Wholesalers",
        "code": 423840,
        "risk": "Medium",
        "score": 3
    },
    "Jewelry, Watch, Precious Stone, and Precious Metal Merchant Wholesalers": {
        "name": "Jewelry, Watch, Precious Stone, and Precious Metal Merchant Wholesalers",
        "code": 423940,
        "risk": "High",
        "score": 5
    },
    "Livestock Merchant Wholesalers": {
        "name": "Livestock Merchant Wholesalers",
        "code": 424520,
        "risk": "Medium",
        "score": 3
    },
    "Lumber, Plywood, Millwork, and Wood Panel Merchant Wholesalers": {
        "name": "Lumber, Plywood, Millwork, and Wood Panel Merchant Wholesalers",
        "code": 423310,
        "risk": "Medium",
        "score": 3
    },
    "Meat and Meat Product Merchant Wholesalers": {
        "name": "Meat and Meat Product Merchant Wholesalers",
        "code": 424470,
        "risk": "Medium",
        "score": 3
    },
    "Medical, Dental, and Hospital Equipment and Supplies Merchant Wholesalers": {
        "name": "Medical, Dental, and Hospital Equipment and Supplies Merchant Wholesalers",
        "code": 423450,
        "risk": "Medium",
        "score": 3
    },
    "Men's and Boys' Clothing and Furnishings Merchant Wholesalers": {
        "name": "Men's and Boys' Clothing and Furnishings Merchant Wholesalers",
        "code": 424320,
        "risk": "Medium",
        "score": 3
    },
    "Metal Service Centers and Other Metal Merchant Wholesalers": {
        "name": "Metal Service Centers and Other Metal Merchant Wholesalers",
        "code": 423510,
        "risk": "High",
        "score": 5
    },
    "Motor Vehicle Parts (Used) Merchant Wholesalers": {
        "name": "Motor Vehicle Parts (Used) Merchant Wholesalers",
        "code": 423140,
        "risk": "High",
        "score": 5
    },
    "Motor Vehicle Supplies and New Parts Merchant Wholesalers": {
        "name": "Motor Vehicle Supplies and New Parts Merchant Wholesalers",
        "code": 423120,
        "risk": "High",
        "score": 5
    },
    "Office Equipment Merchant Wholesalers": {
        "name": "Office Equipment Merchant Wholesalers",
        "code": 423420,
        "risk": "Medium",
        "score": 3
    },
    "Ophthalmic Goods Merchant Wholesalers": {
        "name": "Ophthalmic Goods Merchant Wholesalers",
        "code": 423460,
        "risk": "Medium",
        "score": 3
    },
    "Other Chemical and Allied Products Merchant Wholesalers": {
        "name": "Other Chemical and Allied Products Merchant Wholesalers",
        "code": 424690,
        "risk": "Medium",
        "score": 3
    },
    "Other Commercial Equipment Merchant Wholesalers": {
        "name": "Other Commercial Equipment Merchant Wholesalers",
        "code": 423440,
        "risk": "Medium",
        "score": 3
    },
    "Other Construction Material Merchant Wholesalers": {
        "name": "Other Construction Material Merchant Wholesalers",
        "code": 423390,
        "risk": "Medium",
        "score": 3
    },
    "Other Electronic Parts and Equipment Merchant Wholesalers": {
        "name": "Other Electronic Parts and Equipment Merchant Wholesalers",
        "code": 423690,
        "risk": "Medium",
        "score": 3
    },
    "Other Farm Product Raw Material Merchant Wholesalers": {
        "name": "Other Farm Product Raw Material Merchant Wholesalers",
        "code": 424590,
        "risk": "Medium",
        "score": 3
    },
    "Other Grocery and Related Products Merchant Wholesalers": {
        "name": "Other Grocery and Related Products Merchant Wholesalers",
        "code": 424490,
        "risk": "Medium",
        "score": 3
    },
    "Other Miscellaneous Durable Goods Merchant Wholesalers": {
        "name": "Other Miscellaneous Durable Goods Merchant Wholesalers",
        "code": 423990,
        "risk": "Medium",
        "score": 3
    },
    "Other Miscellaneous Nondurable Goods Merchant Wholesalers": {
        "name": "Other Miscellaneous Nondurable Goods Merchant Wholesalers",
        "code": 424990,
        "risk": "Medium",
        "score": 3
    },
    "Other Professional Equipment and Supplies Merchant Wholesalers": {
        "name": "Other Professional Equipment and Supplies Merchant Wholesalers",
        "code": 423490,
        "risk": "Medium",
        "score": 3
    },
    "Packaged Frozen Food Merchant Wholesalers": {
        "name": "Packaged Frozen Food Merchant Wholesalers",
        "code": 424420,
        "risk": "Medium",
        "score": 3
    },
    "Paint, Varnish, and Supplies Merchant Wholesalers": {
        "name": "Paint, Varnish, and Supplies Merchant Wholesalers",
        "code": 424950,
        "risk": "Medium",
        "score": 3
    },
    "Petroleum and Petroleum Products Merchant Wholesalers (except Bulk Stations and Terminals)": {
        "name": "Petroleum and Petroleum Products Merchant Wholesalers (except Bulk Stations and Terminals)",
        "code": 424720,
        "risk": "High",
        "score": 5
    },
    "Petroleum Bulk Stations and Terminals": {
        "name": "Petroleum Bulk Stations and Terminals",
        "code": 424710,
        "risk": "High",
        "score": 5
    },
    "Photographic Equipment and Supplies Merchant Wholesalers": {
        "name": "Photographic Equipment and Supplies Merchant Wholesalers",
        "code": 423410,
        "risk": "Medium",
        "score": 3
    },
    "Piece Goods, Notions, and Other Dry Goods Merchant Wholesalers": {
        "name": "Piece Goods, Notions, and Other Dry Goods Merchant Wholesalers",
        "code": 424310,
        "risk": "Medium",
        "score": 3
    },
    "Plastics Materials and Basic Forms and Shapes Merchant Wholesalers": {
        "name": "Plastics Materials and Basic Forms and Shapes Merchant Wholesalers",
        "code": 424610,
        "risk": "Medium",
        "score": 3
    },
    "Plumbing and Heating Equipment and Supplies (Hydronics) Merchant Wholesalers": {
        "name": "Plumbing and Heating Equipment and Supplies (Hydronics) Merchant Wholesalers",
        "code": 423720,
        "risk": "Medium",
        "score": 3
    },
    "Poultry and Poultry Product Merchant Wholesalers": {
        "name": "Poultry and Poultry Product Merchant Wholesalers",
        "code": 424440,
        "risk": "Medium",
        "score": 3
    },
    "Printing and Writing Paper Wholesalers": {
        "name": "Printing and Writing Paper Wholesalers",
        "code": 424110,
        "risk": "Medium",
        "score": 3
    },
    "Recyclable Material Merchant Wholesalers": {
        "name": "Recyclable Material Merchant Wholesalers",
        "code": 423930,
        "risk": "High",
        "score": 5
    },
    "Refrigeration Equipment and Supplies Merchant Wholesalers": {
        "name": "Refrigeration Equipment and Supplies Merchant Wholesalers",
        "code": 423740,
        "risk": "Medium",
        "score": 3
    },
    "Roofing, Siding, and Insulation Material Merchant Wholesalers": {
        "name": "Roofing, Siding, and Insulation Material Merchant Wholesalers",
        "code": 423330,
        "risk": "Medium",
        "score": 3
    },
    "Service Establishment Equipment and Supplies Merchant Wholesalers": {
        "name": "Service Establishment Equipment and Supplies Merchant Wholesalers",
        "code": 423850,
        "risk": "Medium",
        "score": 3
    },
    "Sporting and Recreational Goods and Supplies Merchant Wholesalers": {
        "name": "Sporting and Recreational Goods and Supplies Merchant Wholesalers",
        "code": 423910,
        "risk": "Medium",
        "score": 3
    },
    "Stationery and Office Supplies Merchant Wholesalers": {
        "name": "Stationery and Office Supplies Merchant Wholesalers",
        "code": 424120,
        "risk": "Medium",
        "score": 3
    },
    "Tire and Tube Merchant Wholesalers": {
        "name": "Tire and Tube Merchant Wholesalers",
        "code": 423130,
        "risk": "High",
        "score": 5
    },
    "Tobacco and Tobacco Product Merchant Wholesalers": {
        "name": "Tobacco and Tobacco Product Merchant Wholesalers",
        "code": 424940,
        "risk": "High",
        "score": 5
    },
    "Toy and Hobby Goods and Supplies Merchant Wholesalers": {
        "name": "Toy and Hobby Goods and Supplies Merchant Wholesalers",
        "code": 423920,
        "risk": "Medium",
        "score": 3
    },
    "Transportation Equipment and Supplies (except Motor Vehicle) Merchant Wholesalers": {
        "name": "Transportation Equipment and Supplies (except Motor Vehicle) Merchant Wholesalers",
        "code": 423860,
        "risk": "High",
        "score": 5
    },
    "Warm Air Heating and Air-Conditioning Equipment and Supplies Merchant Wholesalers": {
        "name": "Warm Air Heating and Air-Conditioning Equipment and Supplies Merchant Wholesalers",
        "code": 423730,
        "risk": "Medium",
        "score": 3
    },
    "Wholesale Trade Agents and Brokers": {
        "name": "Wholesale Trade Agents and Brokers",
        "code": 425120,
        "risk": "High",
        "score": 5
    },
    "Wine and Distilled Alcoholic Beverage Merchant Wholesalers": {
        "name": "Wine and Distilled Alcoholic Beverage Merchant Wholesalers",
        "code": 424820,
        "risk": "High",
        "score": 5
    },
    "Women's, Children's, and Infants' Clothing and Accessories Merchant Wholesalers": {
        "name": "Women's, Children's, and Infants' Clothing and Accessories Merchant Wholesalers",
        "code": 424330,
        "risk": "Medium",
        "score": 3
    },
    "default": {
        "name": "",
        "code": 424330,
        "risk": "Medium",
        "score": 3
    }
}


pep_dict = {
    "no-pep-not-relevant-list": {
        "name": "Screened, PEP not identified, not on relevant lists",
        "risk": "low",
        "score": 0
    },
    "pep-not-relevant-list": {
        "name": "Screened, PEP identified, not on relevant lists",
        "risk": "medium",
        "score": 3
    },
    "no-pep-on-relevant-list": {
        "name": "Screened, PEP not identified, on relevant lists",
        "risk": "high",
        "score": 5
    },
    "pep-on-relevant-list": {
        "name": "Screened, PEP identified, on relevant lists ",
        "risk": "high",
        "score": 5
    },
    "no-pep-no-screening": {
        "name": "Not Screened ",
        "risk": "high",
        "score": 5
    }
}


score_legend = {
    "low": {
        "min": 1,
        "max": 1.9
    },
    "medium": {
        "min": 2,
        "max": 3.4
    },
    "high": {
        "min": 3.5,
        "max": 5
    }
}


def __get_score(score, min, max):
    return ((score - min) * (score - max) <= 0)


def __compute_rating(score):
    for key in score_legend:
        truthy = __get_score(
            score, score_legend[key]['min'], score_legend[key]['max'])
        if truthy:
            return {
                "risk": key,
                "score": score
            }


def calculate_risk_score(payload: dict):

    nationality_rating = country_of_nationality_dict[payload.get(
        'country_of_nationality')]
    residence_rating = country_of_residence_dict[payload.get(
        'country_of_residence')]
    occupation_rating = industry_dict[payload.get('occupation', 'default')]
    wealth_rating = source_of_wealth_dict[payload.get(
        'source_of_wealth', 'employment')]
    risk_transaction_rating = high_risk_transaction_dict[payload.get(
        'high_risk_transaction', 'no')]
    pep_rating = pep_dict[payload.get('pep', 'no-pep-not-relevant-list')]

    score = nationality_rating['score'] + residence_rating['score'] + occupation_rating['score'] + \
        wealth_rating['score'] + \
        risk_transaction_rating['score'] + pep_rating['score']

    return __compute_rating(score / len(payload))
